@@ -12,13 +12,11 @@
  *    -rewritten to use FILE * instead of binfile
  */
 
-#define NO_CPDLL_IMPORT
 #include "config.h"
 #include <fcntl.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <sys/param.h>
 #include <unistd.h>
 #include "types.h"
 #include "binfpak.h"
@@ -27,9 +25,9 @@
 
 struct __attribute__((packed)) packdirentry
 {
-  char name[0x38];
-  long off;
-  long len;
+	char name[0x38];
+	uint32_t off;
+	uint32_t len;
 };
 
 static int nfiles;
@@ -40,7 +38,7 @@ FILE *pakfOpen(char *name)
 {
 	int i;
 	FILE *retval;
-	char *tmpname;
+	char *tmp;
 	if (!packfile)
 		return NULL;
 	for (i=0;i<nfiles;i++)
@@ -49,14 +47,15 @@ FILE *pakfOpen(char *name)
 	if (i==nfiles)
 		return NULL;
 	fseek(packfile, dir[i].off, SEEK_SET);
-	retval=fopen(tmpname=tmpnam(NULL), "w+");
-	if (!retval)
+	if  ( ! ( retval = tmpfile () ) )
+	{
+		perror ("tempfile()");
 		return NULL;
-	unlink(tmpname);
-	tmpname=malloc(dir[i].len);
-	fread(tmpname, dir[i].len, 1, packfile);
-	fwrite(tmpname, dir[i].len, 1, retval);
-	free(tmpname);
+	}
+	tmp=malloc(dir[i].len);
+	fread(tmp, dir[i].len, 1, packfile);
+	fwrite(tmp, dir[i].len, 1, retval);
+	free(tmp);
 	fseek(retval, 0, SEEK_SET);
 	return retval;
 }
@@ -64,27 +63,28 @@ FILE *pakfOpen(char *name)
 int pakfInit(void)
 {
 	char path[PATH_MAX+1];
-	int tmp;
+	uint32_t tmp;
 	int o;
 	int i,j;
 
-	strcpy(path, cfDataDir);
-	strcat(path, "cp.pak");
+	snprintf(path, sizeof(path), "%s%s", cfDataDir, "ocp.pak");
 	nfiles=0;
 	dir=0;
 	if (!(packfile=fopen(path, "r")))
 	{
 		perror("fopen()");
-		fprintf(stderr, "cp.pak: failed to open: %s\n", path);
+		fprintf(stderr, "ocp.pak: failed to open: %s\n", path);
 		return errOk;
 	}
-	fread(&tmp, sizeof(tmp), 1, packfile);
-	if (tmp!=0x4B434150)
+	fread(&tmp, sizeof(uint32_t), 1, packfile);
+	if ( tmp != uint32_little (0x4B434150) )
 		goto error_out;
 	if (!fread(&o, sizeof(o), 1, packfile))
 		goto error_out;
+	o = uint32_little (o);
 	if (!fread(&nfiles, sizeof(nfiles), 1, packfile))
 		goto error_out;
+	nfiles = uint32_little (nfiles);
 	nfiles/=0x40;
 	if (!nfiles)
 		goto error_out;
@@ -93,16 +93,19 @@ int pakfInit(void)
 	fread(dir, sizeof(dir[0]), nfiles, packfile);
 	for (i=0; i<nfiles; i++)
 	{
+		dir[i].off = uint32_little (dir[i].off);
+		dir[i].len = uint32_little (dir[i].len);
 		for (j=0; j<0x38; j++)
 			if (dir[i].name[j]=='\\')   /* we are hardcore unix folks */
 				dir[i].name[j]='/';
+
 	}
 	if (fcntl(fileno(packfile), F_SETFD, FD_CLOEXEC))
 		perror("fcntl(fileno, F_SETFD, FD_CLOEXEC)");
 
 	return errOk;
 error_out:
-	fprintf(stderr, "cp.pak invalid\n");
+	fprintf(stderr, "ocp.pak invalid\n");
 	fclose(packfile);
 	packfile=NULL;
 	return errOk;
