@@ -24,6 +24,7 @@
  */
 
 #include "config.h"
+#include <dirent.h>
 #include <dlfcn.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -36,7 +37,6 @@
 #include "psetting.h"
 #include "plinkman.h"
 
-
 static int handlecounter;
 struct dll_handle loadlist[MAXDLLLIST];
 int loadlist_n;
@@ -94,7 +94,6 @@ char *_lnkReadInfoReg(const char *key)
 	int i;
 	char **pi;
 	*reglist=0;
-/*	for (i=loadlist_n-1;i>=0;i--) */
 	for (i=0;i<loadlist_n;i++)
 		if ((pi=dlsym(loadlist[i].handle, "dllinfo")))
 			parseinfo(*pi, key);
@@ -104,7 +103,6 @@ char *_lnkReadInfoReg(const char *key)
 }
 
 
-/*char *lnkReadInfoReg(const char *name, const char *key)*/
 char *lnkReadInfoReg(const int id, const char *key)
 {
 	char **pi=0;
@@ -113,72 +111,153 @@ char *lnkReadInfoReg(const int id, const char *key)
 	*reglist=0;
 
 	for (i=loadlist_n-1;i>=0;i--)
-/*		if (strcasecmp(loadlist[i].dllname, name))*/
 		if (loadlist[i].id==id)
 			if ((pi=dlsym(loadlist[i].handle, "dllinfo")))
 				parseinfo(*pi, key);
-/*	if (pi)
-		parseinfo(*pi,key);*/
-
 	if (*reglist)
 		reglist[strlen(reglist)-1]=0;
 
 	return reglist;
 }
 
-static int lnkDoLoad(const char *file)
+static int _lnkDoLoad(const char *file)
 {
-	char buffer[PATH_MAX+1];
-
-	char *handle;
-
 	if (loadlist_n>=MAXDLLLIST)
 	{
 		fprintf(stderr, "Too many open shared objects\n");
 		return -1;
 	}
 
+	if (!(loadlist[loadlist_n].handle=dlopen(file, RTLD_NOW|RTLD_GLOBAL)))
+	{
+		fprintf(stderr, "%s\n", dlerror());
+		return -1;
+	}
+
+	loadlist[loadlist_n].id=++handlecounter;
+
+	if (!(loadlist[loadlist_n].info=(struct linkinfostruct *)dlsym(loadlist[loadlist_n].handle, "dllextinfo")))
+	{
+		fprintf(stderr, "lnkDoLoad(%s): dlsym(dllextinfo): %s\n", file, dlerror());
+		return -1;
+	}
+
+	{
+		struct stat st;
+		if (stat(file, &st))
+			st.st_size=0;
+		loadlist[loadlist_n].info->size=st.st_size;
+	}
+
+	loadlist_n++;
+
+	return handlecounter;
+}
+
+static int lnkDoLoad(const char *file)
+{
+	char buffer[PATH_MAX+1];
+
 #ifdef LD_DEBUG
 	fprintf(stderr, "Request to load %s\n", file);
 #endif
-	if ((strlen(cfProgramDir)+strlen(file)+3)>PATH_MAX)
+	if ((strlen(cfProgramDir)+strlen(file)+strlen(LIB_SUFFIX))>PATH_MAX)
 	{
-#ifdef LD_DEBUG
-		fprintf(stderr, "File path to long\n");
-#endif
+		fprintf(stderr, "File path to long %s%s%s\n", cfProgramDir, file, LIB_SUFFIX);
 		return -1;
 	}
 	strcat(strcat(strcpy(buffer, cfProgramDir), file), LIB_SUFFIX);
 #ifdef LD_DEBUG
 	fprintf(stderr, "Attempting to load %s\n", buffer);
 #endif
+	return _lnkDoLoad(buffer);
+}
 
-	if (!(handle=dlopen(buffer, RTLD_NOW|RTLD_GLOBAL)))
-	{
-		fprintf(stderr, "%s\n", dlerror());
-		return -1;
-	}
-	strncpy(loadlist[loadlist_n].dllname, file, 15);
-	loadlist[loadlist_n].handle=handle;
-	loadlist[loadlist_n].id=++handlecounter;
-	if (!(loadlist[loadlist_n].info=(struct linkinfostruct *)dlsym(handle, "dllextinfo")))
-	{
-		fprintf(stderr, "lnkDoLoad(%s): dlsym(dllextinfo): %s\n", file, dlerror());
-		return -1;
-	}
-
-#if 0
-	loadlist[loadlist_n].info->size=(char *)loadlist[loadlist_n].info->stop-(char *)loadlist[loadlist_n].info->start;
+#ifdef HAVE_QSORT
+static int cmpstringp(const void *p1, const void *p2)
+{
+	return strcmp(*(char * const *)p1, *(char * const *)p2);
+}
 #else
+static void bsort(char **files, int n)
+{
+	/* old classic bouble sort */
+	int m;
+	int c;
+
+	if (n<=1)
+		return;
+	c=1;
+	n--;
+	while (c)
 	{
-		struct stat st;
-		if (stat(buffer, &st))
-			st.st_size=0;
-		loadlist[loadlist_n].info->size=st.st_size;
+		c=0;
+		for (m=0;m<n;m++)
+		{
+			if (strcmp(files[m], files[m+1])>0)
+			{
+				char *t = files[m];
+				files[m]=files[m+1];
+				files[m+1]=t;
+				c=1;
+			}
+		}
 	}
+}
 #endif
-	loadlist_n++;
-	return handlecounter;
+
+int lnkLinkDir(const char *dir)
+{
+	DIR *d;
+	struct dirent *de;
+	char *filenames[1024];
+	char buffer[PATH_MAX+1];
+	int files=0;
+	int n;
+	if (!(d=opendir(dir)))
+	{
+		perror("opendir()");
+		return -1;
+	}
+	while ((de=readdir(d)))
+	{
+		int len=strlen(de->d_name);
+		if (len<strlen(LIB_SUFFIX))
+			continue;
+		if (strcmp(de->d_name+len-strlen(LIB_SUFFIX), LIB_SUFFIX))
+			continue;
+		if (files>=1024)
+		{
+			fprintf(stderr, "lnkLinkDir: Too many libraries in directory %s\n", dir);
+			return -1;
+		}
+		filenames[files++]=strdup(de->d_name);
+	}
+	if (!files)
+		return 0;
+#ifdef HAVE_QSORT
+	qsort(filenames, files, sizeof(char *), cmpstringp);
+#else
+	bsort(filenames, files);
+#endif
+	for (n=0;n<files;n++)
+	{
+		if (snprintf(buffer, sizeof(buffer), "%s%s", dir, filenames[n])>=sizeof(buffer))
+		{
+			fprintf(stderr, "lnkLinkDir: path too long %s%s\n", dir, filenames[n]);
+			for (;n<files;n++)
+				free(filenames[n]);
+			return -1;
+		}
+		if (_lnkDoLoad(buffer)<0)
+		{
+			for (;n<files;n++)
+				free(filenames[n]);
+			return -1;
+		}
+		free(filenames[n]);
+	}
+	return 0; /* all okey */
 }
 
 int lnkLink(const char *files)
