@@ -44,31 +44,23 @@
 #include "plinkman.h"
 #include "psetting.h"
 
-static struct initcloseregstruct *plInitClose = 0;
-
-static int plRegisterInitClose(struct initcloseregstruct *r)
-{
-	if (r->Init)
-	{
-		int ret=r->Init();
-		if (ret<0)
-			return ret;
-	}
-	if (r->Close)
-	{
-		r->next=plInitClose;
-		plInitClose=r;
-	}
-	return 0;
-}
+struct mainstruct *ocpmain = 0;
 
 static void plCloseAll(void)
 {
-	while (plInitClose)
-	{
-		plInitClose->Close();
-		plInitClose=plInitClose->next;
-	}
+	int i;
+
+	for (i=0;i<loadlist_n;i++)
+		if (loadlist[i].info->PreClose)
+			loadlist[i].info->PreClose();
+
+	for (i=0;i<loadlist_n;i++)
+		if (loadlist[i].info->Close)
+			loadlist[i].info->Close();
+
+	for (i=0;i<loadlist_n;i++)
+		if (loadlist[i].info->LateClose)
+			loadlist[i].info->LateClose();
 }
 
 static int cmdhlp(void)
@@ -101,6 +93,10 @@ static int cmdhlp(void)
 		printf("     8            : play/sample/mix as 8bit\n");
 		printf("     m            : play/sample/mix mono\n");
 		printf("-p                : quit when playlist is empty\n");
+		printf("-d : force display driver\n");
+		printf("     curses       : ncurses driver\n");
+		printf("     x11          : x11 driver\n");
+		printf("     vcsa         : vcsa/fb linux console driver\n");
 		printf("\nExample : ocp -fl0,r1 -vp75,f2 -spdevpdisk -sr48000 ftstar.xm\n");
 		printf("          (for nice HD rendering of modules)\n");
 		return errHelpPrinted;
@@ -113,24 +109,40 @@ extern char compiledate[], compiletime[]/*, compiledby[]*/;
 
 static int init_modules(int argc, char *argv[])
 {
-	char regname[50];
-	char regsline[1024];
-	char const *regs;
-
-	void *reg;
-	struct mainstruct *regmain;
 	int ret;
+	int i;
 
 	if ((ret=cmdhlp()))
 		return ret;
 
+	if (!geteuid())
+		if (getuid())
+		{
+			fprintf(stderr, "Changing user to non-root\n");
+			if (seteuid(getuid()))
+			{
+				perror("seteuid()");
+				return errGen;
+			}
+		}
+	if (!getegid())
+		if (getgid())
+		{
+			fprintf(stderr, "Changing group to non-root\n");
+			if (setegid(getgid()))
+			{
+				perror("setegid()");
+				return errGen;
+			}
+		}
+
 	lnkInit();
 
 	fprintf(stderr, "linking default objects...\n");
 
 	cfConfigSec="defaultconfig";
 
-	if (cfGetProfileInt("version", "epoch", 0, 10)!=20060815)
+	if (cfGetProfileInt("version", "epoch", 0, 10)!=20070712)
 	{
 
 		if (isatty(2))
@@ -149,7 +161,13 @@ static int init_modules(int argc, char *argv[])
 	lnkLink(cfGetProfileString2(cfConfigSec, "defaultconfig", "prelink", ""));
 	lnkLink(cfGetProfileString("general", "prelink", ""));
 
-	if ((lnkLink(cfGetProfileString("general", "link", ""))<0))
+	if (lnkLinkDir(cfGetProfileString("general", "autoload", ""))<0)
+	{
+		fprintf(stderr, "could not autoload directory: %s\n", cfGetProfileString("general", "autoload", "unset"));
+		return -1;
+	}
+
+	if (lnkLink(cfGetProfileString("general", "link", ""))<0)
 	{
 		fprintf(stderr, "could not link default objects!\n");
 		return -1;
@@ -166,87 +184,27 @@ static int init_modules(int argc, char *argv[])
 
 	fprintf(stderr, "running initializers...\n");
 
-	strcpy(regsline, _lnkReadInfoReg("preinitclose"));
-	regs=regsline;
-	while (cfGetSpaceListEntry(regname, &regs, 49))
-	{
-#ifdef LD_DEBUG
-		fprintf(stderr, "symbol: %s\n", regname);
-#endif
-		reg=_lnkGetSymbol(regname);
-		ret=errSymSym;
-		if (reg)
-			ret=plRegisterInitClose((struct initcloseregstruct *)reg);
-		else
-			fprintf(stderr, "Error finding symbol %s\n", regname);
-		if (ret<0)
-			return errGen;
-	}
-
-	strcpy(regsline, _lnkReadInfoReg("initclose"));
-	regs=regsline;
-	while (cfGetSpaceListEntry(regname, &regs, 49))
-	{
-#ifdef LD_DEBUG
-		fprintf(stderr, "symbol: %s\n", regname);
-#endif
-		reg=_lnkGetSymbol(regname);
-		ret=errSymSym;
-		if (reg)
-			ret=plRegisterInitClose((struct initcloseregstruct *)reg);
-		else
-			fprintf(stderr, "Error finding symbol %s\n", regname);
-
-		if (ret<0)
-			return errGen;
-	}
-
-	strcpy(regsline, _lnkReadInfoReg("initcloseafter"));
-	regs=regsline;
-	while (cfGetSpaceListEntry(regname, &regs, 49))
-	{
-#ifdef LD_DEBUG
-		fprintf(stderr, "symbol: %s\n", regname);
-#endif
-		reg=_lnkGetSymbol(regname);
-		ret=errSymSym;
-		if (reg)
-			ret=plRegisterInitClose((struct initcloseregstruct *)reg);
-		else
-			fprintf(stderr, "Error finding symbol %s\n", regname);
-		if (ret<0)
-			return errGen;
-	}
-	if (!geteuid())
-		if (getuid())
-		{
-			fprintf(stderr, "Changing user to non-root\n");
-			if (seteuid(getuid()))
-			{
-				perror("seteuid()");
+	for (i=0;i<loadlist_n;i++)
+		if (loadlist[i].info->PreInit)
+			if (loadlist[i].info->PreInit()<0)
 				return errGen;
-			}
-		}
 
-	strcpy(regsline, _lnkReadInfoReg("main"));
-	regs=regsline;
-	if (!strlen(regs))
+	for (i=0;i<loadlist_n;i++)
+		if (loadlist[i].info->Init)
+			if (loadlist[i].info->Init()<0)
+				return errGen;
+
+	for (i=0;i<loadlist_n;i++)
+		if (loadlist[i].info->LateInit)
+			if (loadlist[i].info->LateInit()<0)
+				return errGen;
+
+	if (!ocpmain)
 	{
 		fprintf(stderr, "ERROR - No main specified in libraries\n");
-		return 99999;
+		return errGen;
 	}
-	if (strchr(regs,' '))
-	{
-		fprintf(stderr, "WARNING - multiple main functions found, using first one\n");
-		*strchr(regs,' ')=0;
-	}
-
-	reg=_lnkGetSymbol(regs);
-	if (!reg)
-		return errSymSym;
-
-	regmain=reg;
-	if (regmain->main(argc, argv)<0)
+	if (ocpmain->main(argc, argv)<0)
 		return errGen;
 
 	plSetTextMode(255);
@@ -289,5 +247,3 @@ static int _bootup(int argc, char *argv[])
 }
 
 struct mainstruct bootup = { _bootup };
-
-
