@@ -620,9 +620,10 @@ int cfStoreConfig(void)
 			strcat(buffer, cfINIApps[i].app);
 			strcat(buffer, "]");
 			if (cfINIApps[i].comment)
-				{
-				while (strlen(buffer)<32)
-					strcat(buffer, " ");
+			{
+				int n=strlen(buffer)-32;
+				if (n>0)
+					strncat(buffer, "                                ", n);
 				strcat(buffer, cfINIApps[i].comment);
 			}
 			strcat(buffer, "\n");
