@@ -188,8 +188,14 @@ static int AnalIProcessKey(uint16_t key)
 {
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp('a', "Activate analalyzer mode");
+			cpiKeyHelp('A', "Activate analalyzer mode");
+			return 0;
 		case 'a': case 'A':
+			analactive=1;
 			cpiTextSetMode("anal");
+			return 1; /* do swallow */
 			break;
 		case 'x': case 'X':
 			analactive=1;
@@ -207,6 +213,15 @@ static int AnalAProcessKey(uint16_t key)
 {
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp('A', "Change analyzer orientations");
+			cpiKeyHelp('a', "Toggle analyzer off");
+			cpiKeyHelp(KEY_PPAGE, "Change analyzer frequenzy space down");
+			cpiKeyHelp(KEY_NPAGE, "Change analyzer frequenzy space up");
+			cpiKeyHelp(KEY_HOME, "Reset analyzer settings");
+			cpiKeyHelp(KEY_ALT_A, "Change analyzer channel mode");
+			cpiKeyHelp(KEY_TAB, "Change the analyzer color");
+			return 0;
 		case 'A':
 			plAnalFlip=(plAnalFlip+1)&3;
 			break;
@@ -239,7 +254,7 @@ static int AnalAProcessKey(uint16_t key)
 		case KEY_ALT_A: /* ALT A, is escaped, so we have control A for now TODO-KEYS*/
 			plAnalChan=(plAnalChan+1)%3;
 			break;
-		case 9: /* tab */
+		case KEY_TAB: /* tab */
 		/*  case 0x0F00: // shift-tab*/
 			plAnalCol=(plAnalCol+1)%4;
 			break;
@@ -296,4 +311,14 @@ static int AnalEvent(int ev)
 }
 
 
-struct cpitextmoderegstruct cpiTModeAnal = {"anal", AnalGetWin, AnalSetWin, AnalDraw, AnalIProcessKey, AnalAProcessKey, AnalEvent};
+static struct cpitextmoderegstruct cpiTModeAnal = {"anal", AnalGetWin, AnalSetWin, AnalDraw, AnalIProcessKey, AnalAProcessKey, AnalEvent};
+
+static void __attribute__((constructor))init(void)
+{
+	cpiTextRegisterDefMode(&cpiTModeAnal);
+}
+
+static void __attribute__((destructor))done(void)
+{
+	cpiTextUnregisterDefMode(&cpiTModeAnal);
+} 
