@@ -151,25 +151,34 @@ static int ChanIProcessKey(uint16_t key)
 {
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp('c', "Activate channel viewer");
+			cpiKeyHelp('C', "Activate channel viewer");
+			return 0;
 		case 'c': case 'C':
+			if (!plChannelType)
+				plChannelType=(plChannelType+1)%4;
 			cpiTextSetMode("chan");
-			break;
+			return 1;
 		case 'x': case 'X':
 			plChannelType=3;
 			return 0;
-/* TODO-KEYS*/	case 0x2d00: /*alt-x */
+		case KEY_ALT_X:
 			plChannelType=2;
  			return 0;
 		default:
 			return 0;
 	}
-	return 1;
 }
 
 static int ChanAProcessKey(uint16_t key)
 {
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp('c', "Change channel view mode");
+			cpiKeyHelp('C', "Change channel view mode");
+			return 0;
 		case 'c': case 'C':
 			plChannelType=(plChannelType+1)%4;
 			cpiTextRecalc();
@@ -191,8 +200,7 @@ static int ChanEvent(int ev)
 	return 1;
 }
 
-struct cpitextmoderegstruct cpiTModeChan = {"chan", ChanGetWin, ChanSetWin, ChanDraw, ChanIProcessKey, ChanAProcessKey, ChanEvent};
-
+static struct cpitextmoderegstruct cpiTModeChan = {"chan", ChanGetWin, ChanSetWin, ChanDraw, ChanIProcessKey, ChanAProcessKey, ChanEvent};
 
 void plUseChannels(void (*Display)(uint16_t *buf, int len, int i))
 {
@@ -201,3 +209,4 @@ void plUseChannels(void (*Display)(uint16_t *buf, int len, int i))
 		return;
 	cpiTextRegisterMode(&cpiTModeChan);
 }
+
