@@ -28,11 +28,10 @@
 #define MAXPCHAN 64
 #define MAXVIEWCHAN 32
 
-static int dotsinited=0;
 static int (*plGetDots)(struct notedotsdata *, int);
 
-static int plDotsMiddle;
-static int plDotsScale;
+static int plDotsMiddle = 72*256;
+static int plDotsScale = 32;
 static unsigned char plDotsType;
 
 static struct notedotsdata dotdata[MAXPCHAN];
@@ -53,18 +52,13 @@ static unsigned char dotcirctab[17][16];
 
 static void drawbox(uint16_t y, int16_t x)
 {
-	int scrpos=96*640+y*dothgt*640+x*32;
-	unsigned char page=scrpos>>16;
+	char *scrpos=(char *)plVidMem+96*640+y*dothgt*640+x*32;
 	int j;
 
-	plSetGraphPage(page);
-	scrpos=((int)plVidMem)+(scrpos&0xFFFF);
 	for (j=0; j<dothgt; j++)
 	{
-		memcpy((void*)scrpos, dotbuf[j]+32, 32);
+		memcpy(scrpos, dotbuf[j]+32, 32);
 		scrpos+=640;
-		if ((scrpos-(int)plVidMem)>=0x10000)
-			scrpos-=plSetGraphPage(++page);
 	}
 }
 
@@ -356,16 +350,7 @@ static void plPrepareDots()
 
 	if (plOpenCPPict)
 	{
-		plSetGraphPage(0);
-		memcpy((char*)plVidMem+96*640, plOpenCPPict, 4096);
-		plSetGraphPage(1);
-		memcpy((char*)plVidMem, plOpenCPPict+4096, 65536);
-		plSetGraphPage(2);
-		memcpy((char*)plVidMem, plOpenCPPict+69632, 65536);
-		plSetGraphPage(3);
-		memcpy((char*)plVidMem, plOpenCPPict+135168, 65536);
-		plSetGraphPage(4);
-		memcpy((char*)plVidMem, plOpenCPPict+200704, 45056);
+		memcpy((char*)plVidMem+96*640, plOpenCPPict, (480-96)*640 );
 	}
 
 	for (i=0; i<65; i++)
@@ -385,13 +370,18 @@ static int plDotsKey(uint16_t key)
 {
 	switch (key)
 	{
-		/*case 0x4900: //pgup*/
+		case KEY_ALT_K:
+			cpiKeyHelp('n', "Change note dots type");
+			cpiKeyHelp('N', "Change note dots type");
+			cpiKeyHelp(KEY_PPAGE, "Change note dots range down");
+			cpiKeyHelp(KEY_NPAGE, "Change note dots range up");
+			cpiKeyHelp(KEY_HOME, "Reset note dots range");
+			return 0;
 		case KEY_PPAGE:
 			plDotsMiddle-=128;
 			if (plDotsMiddle<48*256)
 				plDotsMiddle=48*256;
 			break;
-		/*case 0x5100: //pgdn*/
 		case KEY_NPAGE:
 			plDotsMiddle+=128;
 			if (plDotsMiddle>96*256)
@@ -422,13 +412,6 @@ static int plDotsKey(uint16_t key)
 	return 1;
 }
 
-static void plDotsInit(void)
-{
-	plDotsMiddle=72*256;
-	plDotsScale=32;
-}
-
-
 static void dotDraw(void)
 {
 	cpiDrawGStrings();
@@ -447,6 +430,10 @@ static int dotIProcessKey(uint16_t key)
 {
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp('n', "Activate note dots mode");
+			cpiKeyHelp('N', "Activate note dots mode");
+			return 0;
 		case 'n': case 'N':
 			cpiSetMode("dots");
 			break;
@@ -467,11 +454,6 @@ void plUseDots(int (*get)(struct notedotsdata *, int))
 {
 	if (plVidType==vidNorm)
 		return;
-	if (!dotsinited)
-	{
-		dotsinited=1;
-		plDotsInit();
-	}
 	plGetDots=get;
 	cpiRegisterMode(&plDotsMode);
 }
