@@ -46,7 +46,6 @@
 #include "filesel/mdb.h"
 #include "filesel/pfilesel.h"
 #include "boot/plinkman.h"
-#include "boot/pmain.h"
 #include "stuff/poutput.h"
 #include "boot/psetting.h"
 #include "stuff/framelock.h"
@@ -60,6 +59,8 @@
 
 #define MAXLCHAN 64
 
+extern struct mdbreadinforegstruct cpiReadInfoReg;
+
 void (*plGetRealMasterVolume)(int *l, int *r);
 
 extern struct cpimoderegstruct cpiModeText;
@@ -115,7 +116,7 @@ void cpiSetTextMode(int size)
 void cpiDrawGStrings()
 {
 	char *verstr="  opencp v" VERSION;
-	char *author="(c) 1994-2006 Stian Skjelstad ";
+	char *author="(c) 1994-2007 Stian Skjelstad ";
 	char tstr[CONSOLE_MAX_X+1];
 
 #ifdef DEBUG
@@ -259,7 +260,8 @@ void cpiDrawGStrings()
 
 void cpiResetScreen(void)
 {
-	curmode->SetMode();
+	if (curmode)
+		curmode->SetMode();
 }
 
 static void cpiChangeMode(struct cpimoderegstruct *m)
@@ -299,38 +301,109 @@ void cpiRegisterMode(struct cpimoderegstruct *m)
 	cpiModes=m;
 }
 
-static void cpiRegisterDefMode(struct cpimoderegstruct *m)
+void cpiUnregisterMode(struct cpimoderegstruct *m)
+{
+	if (cpiModes==m)
+	{
+		cpiModes=m->next;
+		return;
+	} else {
+		struct cpimoderegstruct *p = cpiModes;
+		while (p)
+		{
+			if (p->next==m)
+			{
+				p->next=m->next;
+				return;
+			}
+			p=p->next;
+		}
+	}
+}
+
+void cpiRegisterDefMode(struct cpimoderegstruct *m)
 {
-	if (m->Event)
-		if (!m->Event(cpievInitAll))
-			return;
 	m->nextdef=cpiDefModes;
 	cpiDefModes=m;
 }
 
+static void cpiVerifyDefModes(void)
+{
+	struct cpimoderegstruct *p;
+
+	while (cpiDefModes)
+	{
+		if (cpiDefModes->Event&&!cpiDefModes->Event(cpievInitAll))
+			cpiDefModes=cpiDefModes->nextdef;
+		else
+			break;
+	}
+	p = cpiDefModes;
+	while (p)
+	{
+		if (p->nextdef)
+		{
+			if (p->nextdef->Event&&!p->nextdef->Event(cpievInitAll))
+				p->nextdef=p->nextdef->nextdef;
+			else
+				p=p->nextdef;
+		} else
+			break;
+	}
+}
+
+static void cpiInitAllModes(void)
+{
+	struct cpimoderegstruct *p;
+
+	for (p=cpiModes;p;p=p->next)
+		if (p->Event)
+			p->Event(cpievInit);
+}
+
+void cpiUnregisterDefMode(struct cpimoderegstruct *m)
+{
+	if (cpiDefModes==m)
+	{
+		cpiDefModes=m->next;
+		return;
+	} else {
+		struct cpimoderegstruct *p = cpiDefModes;
+		while (p)
+		{
+			if (p->nextdef==m)
+			{
+				p->nextdef=m->nextdef;
+				return;
+			}
+			p=p->nextdef;
+		}
+	}
+}
+
 static int plmpInit(void)
 {
-	char regname[50];
-	const char *regs;
-
 	plCompoMode=cfGetProfileBool2(cfScreenSec, "screen", "compomode", 0, 0);
 	strncpy(curmodehandle, cfGetProfileString2(cfScreenSec, "screen", "startupmode", "text"), 8);
 	curmodehandle[8]=0;
 
-	regs=_lnkReadInfoReg("defmodes");
-	while (cfGetSpaceListEntry(regname, &regs, 49))
-	{
-		void *reg=_lnkGetSymbol(regname);
-		if (reg)
-			cpiRegisterDefMode((struct cpimoderegstruct*)reg);
-	}
+	mdbRegisterReadInfo(&cpiReadInfoReg);
+
 	cpiRegisterDefMode(&cpiModeText);
 
+	cpiVerifyDefModes();
+
+	cpiInitAllModes();
+
+	cpiKeyHelpReset = cpiResetScreen;
+
 	return errOk;
 }
 
 static void plmpClose(void)
 {
+	mdbUnregisterReadInfo(&cpiReadInfoReg);
+
 	while (cpiDefModes)
 	{
 		if (cpiDefModes->Event)
@@ -463,6 +536,28 @@ static int cpiChanProcessKey(uint16_t key)
 	switch (key)
 	{
 		/*case 0x4b00: //left*/
+		case KEY_ALT_K:
+			cpiKeyHelp(KEY_LEFT, "Select previous channel");
+			cpiKeyHelp(KEY_UP, "Select next channel (and wrap)");
+			cpiKeyHelp(KEY_RIGHT, "Select next channel");
+			cpiKeyHelp(KEY_DOWN, "Select previous channel (and wrap)");
+			cpiKeyHelp('1', "Select and toggle channel 1 on/off");
+			cpiKeyHelp('2', "Select and toggle channel 2 on/off");
+			cpiKeyHelp('3', "Select and toggle channel 3 on/off");
+			cpiKeyHelp('4', "Select and toggle channel 4 on/off");
+			cpiKeyHelp('5', "Select and toggle channel 5 on/off");
+			cpiKeyHelp('6', "Select and toggle channel 6 on/off");
+			cpiKeyHelp('7', "Select and toggle channel 7 on/off");
+			cpiKeyHelp('8', "Select and toggle channel 8 on/off");
+			cpiKeyHelp('9', "Select and toggle channel 9 on/off");
+			cpiKeyHelp('0', "Select and toggle channel 10 on/off");
+			cpiKeyHelp('Q', "Toggle selected channel 10 on/off");
+			cpiKeyHelp('q', "Toggle selected channel 10 on/off");
+			cpiKeyHelp('s', "Toggle solo on selected channel on/off");
+			cpiKeyHelp('S', "Toggle solo on selected channel on/off");
+			cpiKeyHelp(KEY_CTRL_S, "Enable all channels");
+			cpiKeyHelp(KEY_CTRL_Q, "Enable all channels");
+			return 0;
 		case KEY_LEFT:
 			if (plSelCh)
 			{
@@ -498,10 +593,10 @@ static int cpiChanProcessKey(uint16_t key)
 			if (key=='0')
 				key=9;
 			else
-				if (key<='9')
+/*				if (key<='9')*/
 					key-='1';
-				else
-					key=(key>>8)-0x78+10;
+/*				else
+					key=(key>>8)-0x78+10;*/
 			if (key>=plNLChan)
 				break;
 			plSelCh=key;
@@ -532,7 +627,7 @@ static int cpiChanProcessKey(uint16_t key)
 			plChanChanged=1;
 			break;
 
-		case 17: case 19: /* TODO-keys*/
+		case KEY_CTRL_Q: case KEY_CTRL_S: /* TODO-keys*/
 			for (i=0; i<plNLChan; i++)
 			{
 				plMuteCh[i]=0;
@@ -567,16 +662,16 @@ int plmpProcessKey(uint16_t key)
 }
 */
 
-static int plmpDrawScreen(void)
+static interfaceReturnEnum plmpDrawScreen(void)
 {
+	int needdraw=1;
 	struct cpimoderegstruct *mod;
 
-	curmode->Draw();
 	plChanChanged=0;
 
 	if (plIsEnd)
 		if (plIsEnd())
-			return 1;
+			return interfaceReturnNextAuto;
 
 	if (plIdle)
 		plIdle();
@@ -594,11 +689,13 @@ static int plmpDrawScreen(void)
 			key&=0xFF00;
 		if (key&0xFF)
 			key&=0x00FF;*/
+		needdraw=0;
+
 		if (plEscTick)
 		{
 			plEscTick=0;
-			if (key==27)
-				return 2;
+			if (key==KEY_ESC)
+				return interfaceReturnQuit;
 		}
 
 #ifdef DEBUG
@@ -606,24 +703,26 @@ static int plmpDrawScreen(void)
 #endif
 
 		if (curmode->AProcessKey(key))
+		{
+			curmode->Draw();
 			continue;
+		}
 
 		switch (key)
 		{
 			struct cpimoderegstruct *mod;
-			case 27:
+			case KEY_ESC:
 				plEscTick=dos_clock();
 				break;
-			case 13:
-				return 3;
+			case _KEY_ENTER:
+				return interfaceReturnNextManuel;
 			case 'f': case 'F':/* case 0x5200: TODO-keys*/
-				return 4;
-			case 'd': case 'D': case 4: /* case 0x6f00: TODO-keys*/
-				return 5;
-			case 10:
-				return 1;
-  
-			case 12: /* CTRL+l */
+				return interfaceReturnCallFs;
+			case 'd': case 'D': case KEY_CTRL_D: /* case 0x6f00: TODO-keys*/
+				return interfaceReturnDosShell;
+			case KEY_CTRL_J:
+				return interfaceReturnNextAuto;
+			case KEY_CTRL_L:
 				fsLoopMods=!fsLoopMods;
 				break;
 			case KEY_ALT_C:
@@ -646,36 +745,52 @@ static int plmpDrawScreen(void)
 				Screenshot();
 				break;
 			#endif
+			case KEY_ALT_K:
+				cpiKeyHelp(KEY_ESC, "Exit");
+				cpiKeyHelp(_KEY_ENTER, "Next song");
+				cpiKeyHelp('f', "Open file selector");
+				cpiKeyHelp('F', "Open file selector");
+				cpiKeyHelp('d', "Open a shell");
+				cpiKeyHelp('D', "Open a shell");
+				cpiKeyHelp(KEY_CTRL_D, "Open a shell");
+				cpiKeyHelp(KEY_CTRL_J, "Next song (forced)");
+				cpiKeyHelp(KEY_CTRL_L, "Toggle song looping (ALT-C setting)");
+				cpiKeyHelp(KEY_ALT_C, "Open setup dialog");
+				/*return 0;*/
 			default:
-			for (mod=cpiModes; mod; mod=mod->next)
-				if (mod->IProcessKey(key))
-					goto fertigmitkeys;
-			if (plNLChan)
-				if (cpiChanProcessKey(key))
-					goto fertigmitkeys;
-			if (plProcessKey)
-				plProcessKey(key);
+				for (mod=cpiModes; mod; mod=mod->next)
+					if (mod->IProcessKey(key))
+						goto fertigmitkeys;
+				if (plNLChan)
+					if (cpiChanProcessKey(key))
+						goto fertigmitkeys;
+				if (plProcessKey)
+					plProcessKey(key);
+				cpiKeyHelpDisplay();
 			fertigmitkeys: ;
 		}
+		curmode->Draw();
 	}
+
+	if (needdraw)
+		curmode->Draw();
 	framelock();
-	return 0;
+
+	return interfaceReturnContinue;
 }
 
-static int plmpCallBack(void)
+static interfaceReturnEnum plmpCallBack(void)
 {
-	int stop;
+	interfaceReturnEnum stop;
 
 	plmpOpenScreen();
-	stop=0;
+	stop=interfaceReturnContinue;
 	while (!stop)
 		stop=plmpDrawScreen();
 	plmpCloseScreen();
 	return stop;
 }
 
-
-
 char plNoteStr[132][4]=
 {
 	"c-1","c#1","d-1","d#1","e-1","f-1","f#1","g-1","g#1","a-1","a#1","b-1",
@@ -691,10 +806,7 @@ char plNoteStr[132][4]=
 	"C-9","C#9","D-9","D#9","E-9","F-9","F#9","G-9","G#9","A-9","A#9","B-9"
 };
 
-struct initcloseregstruct plCPReg = {plmpInit, plmpClose};
 struct interfacestruct plOpenCP = {plmpOpenFile, plmpCallBack, plmpCloseFile};
-char *dllinfo = "initcloseafter plCPReg; interface plOpenCP; defmodes "
-  "cpiModeScope cpiModeGraph cpiModePhase "
-  "cpiModeWuerfel "
-  "cpiModeLinks; deftmodes cpiVolCtrl cpiTModeAnal cpiTModeMVol cpiTModeChan cpiTModeInst cpiTModeTrack; readinfos cpiReadInfoReg";
-struct linkinfostruct dllextinfo = {"cpiface", "OpenCP Interface (c) 1994-04 Niklas Beisert, Tammo Hinrichs, Stian Skjelstad", DLLVERSION, 0};
+char *dllinfo = "";
+struct linkinfostruct dllextinfo = {"cpiface", "OpenCP Interface (c) 1994-04 Niklas Beisert, Tammo Hinrichs, Stian Skjelstad", DLLVERSION, 0, LateInit: plmpInit, PreClose: plmpClose};
+/* OpenCP Module Player */
