@@ -46,6 +46,10 @@ extern void (*plSetMute)(int i, int m);
 extern int (*plGetLChanSample)(int ch, int16_t *, int len, uint32_t rate, int opt);
 extern int (*plGetPChanSample)(int ch, int16_t *, int len, uint32_t rate, int opt);
 
+extern void cpiKeyHelp(uint16_t key, const char *shorthelp);
+extern void cpiKeyHelpDisplay(void);
+extern void (*cpiKeyHelpReset)(void); /* internal use only */
+
 struct cpimoderegstruct
 {
   char handle[9];
@@ -89,7 +93,9 @@ struct cpitextmoderegstruct
 
 enum
 {
-  cpievOpen, cpievClose, cpievInit, cpievDone, cpievInitAll, cpievDoneAll,
+  cpievOpen, cpievClose,
+  cpievInit, cpievDone,       /* used to test if you can be added to Mode list (called on every song) */
+  cpievInitAll, cpievDoneAll, /* used to test if you can be added to DefMode list (called by cpiRegisterDefMode) */
   cpievGetFocus, cpievLoseFocus, cpievSetMode,
   cpievKeepalive=42
 };
@@ -98,10 +104,18 @@ extern void cpiDrawGStrings(void);
 extern void cpiSetGraphMode(int big);
 extern void cpiSetTextMode(int size);
 extern void cpiResetScreen(void);
-extern void cpiRegisterMode(struct cpimoderegstruct *m);
+extern void cpiRegisterDefMode(struct cpimoderegstruct *m); /* this are stuck until unregister is called */
+extern void cpiUnregisterDefMode(struct cpimoderegstruct *m);
+extern void cpiRegisterMode(struct cpimoderegstruct *m); /* This list is cleared automatically on song close, and deflist is appended on load */
+extern void cpiUnregisterMode(struct cpimoderegstruct *m);
+
+
 extern void cpiSetMode(const char *hand);
 extern void cpiGetMode(char *hand);
 extern void cpiTextRegisterMode(struct cpitextmoderegstruct *mode);
+extern void cpiTextUnregisterMode(struct cpitextmoderegstruct *m);
+extern void cpiTextRegisterDefMode(struct cpitextmoderegstruct *mode);
+extern void cpiTextUnregisterDefMode(struct cpitextmoderegstruct *m);
 extern void cpiTextSetMode(const char *name);
 extern void cpiTextRecalc(void);
 
@@ -161,11 +175,4 @@ extern void mcpSetFadePars(int i);
 extern uint16_t globalmcpspeed;
 extern uint16_t globalmcppitch;
 
-#ifdef DEBUG
- #define DEBUGINT(i) debugint=i
- #define DEBUGSTR(s) strcpy(debugstr,s)
- extern int debugint;
- extern char debugstr[128];
-#endif
-
 #endif
