@@ -58,7 +58,7 @@ static void plSetStripePals(int a, int b)
 			for (i=0; i<32; i++)
 				gupdatepal(index++, 0, 63, 2*i);
 			for (i=0; i<32; i++)
-				gupdatepal(index++, 0, 64-2*i, 63);
+				gupdatepal(index++, 0, 63-2*i, 63);
 			break;
 		case 2:
 			for (i=0; i<64; i++)
@@ -140,53 +140,37 @@ static void plPrepareStripes(void)
 	{
 		int i;
 
-		plSetGraphPage(1);
 		memset((char*)plVidMem+32*1024, 128, 32*1024);
-		for (i=2; i<10; i++)
-		{
-			plSetGraphPage(i);
-			memset((char*)plVidMem, 128, 65536);
-		}
+		memset((char*)plVidMem + 128 * 1024, 128, 512 * 1024 );
 		gdrawstr(42, 1, "scale: ", 7, 0x09, 0);
-		plSetGraphPage(10);
-
 		for (i=0; i<256; i++)
 		{
 			int j;
 			for (j=0; j<16; j++)
-				*(unsigned char*)(plVidMem+32768+j*plScrLineBytes+64+i)=(i>>1)+128;
+				*(unsigned char*)(plVidMem+672*1024 +j*plScrLineBytes+64+i)=(i>>1)+128;
 		}
 		for (i=0; i<128; i++)
 		{
 			int j;
 			for (j=0; j<16; j++)
-				*(unsigned char*)(plVidMem+32768+j*plScrLineBytes+352+i)=(i>>1)+64;
+				*(unsigned char*)(plVidMem+672*1024+j*plScrLineBytes+352+i)=(i>>1)+64;
 
 		}
 	} else {
 		int i;
-		plSetGraphPage(0);
-		memset((char*)plVidMem+96*640, 128, 4096);
-		plSetGraphPage(1);
-		memset((char*)plVidMem, 128, 65536);
-		plSetGraphPage(2);
-		memset((char*)plVidMem, 128, 65536);
-		plSetGraphPage(3);
-		memset((char*)plVidMem, 128, 38912);
-
+		memset((char*)plVidMem+96*640, 128, 170 * 1024);
 		gdrawstr(24, 1, "scale: ", 7, 0x09, 0);
-		plSetGraphPage(3);
 		for (i=0; i<128; i++)
 		{
 			int j;
 			for (j=0; j<16; j++)
-				*(unsigned char*)(plVidMem+384*640+64-3*65536+i+j*640)=i+128;
+				*(unsigned char*)(plVidMem+384*640+64+i+j*640)=i+128;
 		}
 		for (i=0; i<64; i++)
 		{
 			int j;
 			for (j=0; j<16; j++)
-				*(unsigned char*)(plVidMem+384*640+232-3*65536+i+j*640)=i+64;
+				*(unsigned char*)(plVidMem+384*640+232+i+j*640)=i+64;
 		}
 	}
 }
@@ -266,12 +250,10 @@ void drawgbar(unsigned long x, unsigned char h);
 #endif
   
 void drawgbar(unsigned long x, unsigned char h)
-{ /* TODO needs more updates for plScrLineBytes */
+{
 	char *vmx, *pos;
 	short value;
 
-	/* On unix we assume linear buffers. Makes life much easier */
-	plSetGraphPage(0);
 	vmx=plVidMem+(479-0x40)*plScrLineBytes;
 	pos=plVidMem+x+479*plScrLineBytes;
 	value=0x4040;
@@ -321,9 +303,6 @@ void drawgbarb(unsigned long x, unsigned char h)
 	char *vmx, *pos;
 	char value=0x40;
 
-	/* On unix we assume linear buffers. Makes life much easier */
-	plSetGraphPage(0);
-
 	vmx=plVidMem+(768-0x40)*plScrLineBytes;
 	pos=plVidMem+x+767*plScrLineBytes;
 
@@ -346,11 +325,9 @@ void drawgbarb(unsigned long x, unsigned char h)
   
 static void plDrawStripes(void)
 {
-	int i;
+	int i, j;
 	unsigned char *sp;
 	static unsigned char linebuf[1088];
-	int pos[4];
-	unsigned char pg;
 
 	if (plPause)
 		return;
@@ -424,24 +401,22 @@ static void plDrawStripes(void)
 					*sp--=ana[i];
 			}
 		}
-		pos[0]=plStripePos;
-		pos[1]=(plStripePos+12)%1024;
-		pos[2]=(plStripePos+20)%1024;
-		pos[3]=(plStripePos+32)%1024;
 
-		pg=1;
-		plSetGraphPage(1);
-		sp=(unsigned char *)(plVidMem+32*plScrLineBytes);
+		sp=(unsigned char *)(plVidMem+96*plScrLineBytes);
 		for (i=0; i<544; i++, sp+=plScrLineBytes)
 		{
-			if ((sp-(unsigned char*)plVidMem)>=0x10000)
-				sp-=plSetGraphPage(++pg);
-			sp[pos[0]]=(linebuf[2*i]+linebuf[2*i+1])>>1;
-			sp[pos[1]]=(sp[pos[1]]>>1)+64;
-			sp[pos[2]]=(sp[pos[2]]>>1)+64;
-			sp[pos[3]]=(sp[pos[3]]>>1)+64;
+			sp[plStripePos]=(linebuf[2*i]+linebuf[2*i+1])>>1;
+			for (j=1;j<32;j++)
+			{
+				int p = (plStripePos+j)%1024;
+				unsigned char b = sp[p];
+				if (b<133)
+					b=128;
+				else
+					b-=4;
+				sp[p] = b;
+			}
 		}
-		plSetGraphPage(11);
 		if (!plAnalChan)
 		{
 			for (i=0; i<504; i++)
@@ -522,44 +497,22 @@ static void plDrawStripes(void)
 			}
 		}
 
-    		pg=0;
-		plSetGraphPage(0);
-		sp=(unsigned char *)(plVidMem+96*plScrLineBytes+plStripePos);
+		sp=(unsigned char *)(plVidMem+96*plScrLineBytes);
 		for (i=0; i<272; i++, sp+=plScrLineBytes)
 		{
-			if ((sp-(unsigned char*)plVidMem)>=0x10000)
-				sp-=plSetGraphPage(++pg);
-			*sp=linebuf[i];
-		}
-		pg=0;
-		plSetGraphPage(0);
-		sp=(unsigned char *)(plVidMem+96*plScrLineBytes+(plStripePos+12)%plScrLineBytes);
-		for (i=0; i<272; i++, sp+=plScrLineBytes)
-		{
-			if ((sp-(unsigned char*)plVidMem)>=0x10000)
-				sp-=plSetGraphPage(++pg);
-			*sp=(*sp>>1)+64;
-		}
-		pg=0;
-		plSetGraphPage(0);
-		sp=(unsigned char *)(plVidMem+96*plScrLineBytes+(plStripePos+20)%plScrLineBytes);
-		for (i=0; i<272; i++, sp+=plScrLineBytes)
-		{
-			if ((sp-(unsigned char*)plVidMem)>=0x10000)
-				sp-=plSetGraphPage(++pg);
-			*sp=(*sp>>1)+64;
-		}
-		pg=0;
-		plSetGraphPage(0);
-		sp=(unsigned char *)(plVidMem+96*plScrLineBytes+(plStripePos+32)%plScrLineBytes);
-		for (i=0; i<272; i++, sp+=plScrLineBytes)
-		{
-			if ((sp-(unsigned char*)plVidMem)>=0x10000)
-				sp-=plSetGraphPage(++pg);
-			*sp=(*sp>>1)+64;
+			sp[plStripePos]=linebuf[i];
+			for (j=1;j<32;j++)
+			{
+				int p = (plStripePos+j)%640;
+				unsigned char b = sp[p];
+				if (b<133)
+					b=128;
+				else
+					b-=4;
+				sp[p] = b;
+			}
 		}
 
-		plSetGraphPage(4);
 		if (!plAnalChan)
 		{
 			for (i=0; i<128; i++)
@@ -586,7 +539,16 @@ static int plStripeKey(uint16_t key)
 {
 	switch (key)
 	{
-		/*case 0x4900: //pgup*/
+		case KEY_ALT_K:
+			cpiKeyHelp(KEY_PPAGE, "Reduce frequency space for graphical spectrum analyzer");
+			cpiKeyHelp(KEY_PPAGE, "Increase frequency space for graphical spectrum analyzer");
+			cpiKeyHelp(KEY_HOME, "Reset settings for graphical spectrum analyzer");
+			cpiKeyHelp(KEY_TAB, "Cycle palette for graphical spectrum analyzer");
+			cpiKeyHelp(KEY_SHIFT_TAB, "Cycle palette for mini graphical spectrum analyzer");
+			cpiKeyHelp(KEY_ALT_G, "Toggle stripe speed");
+			cpiKeyHelp('g', "Toggle which channel to analyze");
+			cpiKeyHelp('G', "Toggle resolution");
+			return 0;
 		case KEY_PPAGE:
 			plAnalRate=plAnalRate*30/32;
 			plAnalRate=(plAnalRate>=64000)?64000:(plAnalRate<1024)?1024:plAnalRate;
@@ -610,15 +572,15 @@ static int plStripeKey(uint16_t key)
 			plAnalScale=2048;
 			plAnalChan=0;
 			break;
-		case 9: /* tab */
+		case KEY_TAB:
 			plSetStripePals(plStripePal1+1, plStripePal2);
 			break;
 /*TODO-keys	case 0xA500: // alt-tab
 			plSetStripePals(plStripePal1-1, plStripePal2);
-			break;
-		case 0x0F00: // shift-tab
-			plSetStripePals(plStripePal1, plStripePal2+1);
 			break; */
+		case KEY_SHIFT_TAB:
+			plSetStripePals(plStripePal1, plStripePal2+1);
+			break;
 		case KEY_ALT_G: /*0x2200*/
 			plStripeSpeed=!plStripeSpeed;
 			break;
@@ -664,6 +626,10 @@ static int strIProcessKey(uint16_t key)
 {
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp('g', "Enable graphical analyzer in low-res");
+			cpiKeyHelp('G', "Enable graphical analyzer in high-res");
+			return 0;
 		case 'g': case 'G':
 			plStripeBig=(key=='G');
 			cpiSetMode("graph");
@@ -686,4 +652,14 @@ static int strEvent(int ev)
 	return 1;
 }
 
-struct cpimoderegstruct cpiModeGraph = {"graph", strSetMode, strDraw, strIProcessKey, plStripeKey, strEvent};
+static struct cpimoderegstruct cpiModeGraph = {"graph", strSetMode, strDraw, strIProcessKey, plStripeKey, strEvent};
+
+static void __attribute__((constructor))init(void)
+{
+	cpiRegisterDefMode(&cpiModeGraph);
+}
+
+static void __attribute__((destructor))done(void)
+{
+	cpiUnregisterDefMode(&cpiModeGraph);
+}
