@@ -20,7 +20,6 @@
 #include <unistd.h>
 #include "types.h"
 #include "stuff/poutput.h"
-#include "boot/pmain.h"
 #include "cpiface.h"
 #include "stuff/timer.h"
 #include "boot/psetting.h"
@@ -385,8 +384,6 @@ static void wuerfelDraw(void)
 		wuerfelpos++;
 	else
 		wuerfelpos=wuerfelstframes+(wuerfelpos-wuerfelstframes+(plWuerfelDirect?(wuerfelframes-1):1))%wuerfelframes;
-
-	plSetGraphPage(0);
 }
 
 static int wuerfelKey(uint16_t key)
@@ -434,6 +431,10 @@ static int wuerfelIProcessKey(uint16_t key)
 {
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp('w', "Enable wurfel mode");
+			cpiKeyHelp('W', "Enable wurfel mode");
+			return 0;
 		case 'w': case 'W':
 			if (_vga13)
 				cpiSetMode("wuerfel2");
@@ -442,4 +443,14 @@ static int wuerfelIProcessKey(uint16_t key)
 	return 0;
 }
 
-struct cpimoderegstruct cpiModeWuerfel = {"wuerfel2", wuerfelSetMode, wuerfelDraw, wuerfelIProcessKey, wuerfelKey, wuerfelEvent};
+static struct cpimoderegstruct cpiModeWuerfel = {"wuerfel2", wuerfelSetMode, wuerfelDraw, wuerfelIProcessKey, wuerfelKey, wuerfelEvent};
+
+static void __attribute__((constructor))init(void)
+{
+	cpiRegisterDefMode(&cpiModeWuerfel);
+}
+
+static void __attribute__((destructor))done(void)
+{
+	cpiUnregisterDefMode(&cpiModeWuerfel);
+}
