@@ -89,7 +89,14 @@ static int plHelpKey(uint16_t key)
 {
 	switch (key)
 	{
-		case 9:
+		case KEY_ALT_K:
+			cpiKeyHelp(KEY_PPAGE, "Scroll up");
+			cpiKeyHelp(KEY_NPAGE, "Scroll down");
+			cpiKeyHelp(KEY_HOME, "Scroll to to the first line");
+			cpiKeyHelp(KEY_END, "Scroll to to the last line");
+			cpiKeyHelp(KEY_TAB, "Toggle copyright on/off");
+			return 0;
+		case KEY_TAB:
 			if (mode)
 				plHelpScroll/=2;
 			else
@@ -145,6 +152,9 @@ static int hlpIProcessKey(uint16_t key)
 {
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp('\'', "View loaded dll/plugins");
+			return 0;
 		case '\'':
 			cpiSetMode("links");
 			break;
@@ -159,4 +169,14 @@ static int hlpEvent(int ignore)
 	return 1;
 }
 
-struct cpimoderegstruct cpiModeLinks = {"links", hlpSetMode, hlpDraw, hlpIProcessKey, plHelpKey, hlpEvent};
+static struct cpimoderegstruct cpiModeLinks = {"links", hlpSetMode, hlpDraw, hlpIProcessKey, plHelpKey, hlpEvent};
+
+static void __attribute__((constructor))init(void)
+{
+	cpiRegisterDefMode(&cpiModeLinks);
+}
+
+static void __attribute__((destructor))done(void)
+{
+	cpiUnregisterDefMode(&cpiModeLinks);
+}
