@@ -50,6 +50,12 @@ static int plMsgKey(uint16_t key)
 {
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp(KEY_PPAGE, "Scroll up");
+			cpiKeyHelp(KEY_NPAGE, "Scroll down");
+			cpiKeyHelp(KEY_HOME, "Scroll to to the first line");
+			cpiKeyHelp(KEY_END, "Scroll to to the last line");
+			return 0;
 		/*case 0x4900: //pgup*/
 		case KEY_PPAGE:
 			plMsgScroll--;
@@ -99,6 +105,9 @@ static int msgIProcessKey(uint16_t key)
 {
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp('|', "View file messages");
+			return 0;
 		case '|':
 /* TODO-keys	case 0x7000: // ALT+F9 */
 			cpiSetMode("msg");
