@@ -18,6 +18,7 @@
 #include "cpiface.h"
 
 #define COLTEXT 0x07
+#define COLTITLEH 0x09
 #define COLMUTE 0x08
 const uint16_t STRLS[] = {0x0ffe, 0x0ffe, 0x0bfe, 0x0bfe, 0x0bfe, 0x0bfe, 0x09fe, 0x09fe, 0x09fe, 0x09fe, 0x01fe, 0x01fe, 0x01fe, 0x01fe, 0x01fe, 0x01fe};
 const uint16_t STRRS[] = {0x01fe, 0x01fe, 0x01fe, 0x01fe, 0x01fe, 0x01fe, 0x09fe, 0x09fe, 0x09fe, 0x09fe, 0x0bfe, 0x0bfe, 0x0bfe, 0x0bfe, 0x0ffe, 0x0ffe};
@@ -101,7 +102,7 @@ static void drawbigpeakpower(int y, int x)
 		displaystrattr(y+1, x, strbuf, 80);
 }
 
-static void MVolDraw(int _ignore)
+static void MVolDraw(int sel)
 {
 	if (plMVolType==2)
 	{
@@ -115,7 +116,7 @@ static void MVolDraw(int _ignore)
 		drawpeakpower(plMVolFirstLine, plMVolFirstCol + 8 /* 88 */);
 	} else {
 		int l=(plMVolWidth>=132)?(plMVolWidth/2)-40 :20;
-		displaystr(plMVolFirstLine, plMVolFirstCol /* 0 */, plPause?COLMUTE:COLTEXT, "  peak power level:", l);
+		displaystr(plMVolFirstLine, plMVolFirstCol /* 0 */, plPause?COLMUTE:(sel?COLTITLEH:COLTEXT), "  peak power level:", l);
 		displaystr(plMVolFirstLine, plMVolWidth-l + plMVolFirstCol /* 0 */ , COLTEXT, "", l);
 		if (plMVolHeight==2)
 		{
@@ -169,13 +170,19 @@ static int MVolIProcessKey(unsigned short key)
 {
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp('v', "Enable volume viewer");
+			cpiKeyHelp('V', "Enable volume viewer");
+			return 0;
 		case 'v': case 'V':
+			if (!plMVolType)
+				plMVolType=1;
 			cpiTextSetMode("mvol");
 			break;
 		case 'x': case 'X':
 			plMVolType=plNLChan?2:1;
 			return 0;
-/* TODO-keys*/	case 0x2d00: /*alt-x */
+		case KEY_ALT_X:
 			plMVolType=1;
 			return 0;
 		default:
@@ -188,6 +195,10 @@ static int MVolAProcessKey(unsigned short key)
 {
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp('v', "Change volume viewer mode");
+			cpiKeyHelp('V', "Change volume viewer mode");
+			return 0;
 		case 'v': case 'V':
 			plMVolType=(plMVolType+1)%3;
 			cpiTextRecalc();
@@ -216,4 +227,14 @@ static int MVolEvent(int ev)
 	return 1;
 }
 
-struct cpitextmoderegstruct cpiTModeMVol = {"mvol", MVolGetWin, MVolSetWin, MVolDraw, MVolIProcessKey, MVolAProcessKey, MVolEvent};
+static struct cpitextmoderegstruct cpiTModeMVol = {"mvol", MVolGetWin, MVolSetWin, MVolDraw, MVolIProcessKey, MVolAProcessKey, MVolEvent};
+
+static void __attribute__((constructor))init(void)
+{
+	cpiTextRegisterDefMode(&cpiTModeMVol);
+}
+
+static void __attribute__((destructor))done(void)
+{
+	cpiTextUnregisterDefMode(&cpiTModeMVol);
+}
