@@ -60,27 +60,9 @@ static void plPrepareScopes(void)
 		for (i=16; i<256; i++)
 			gupdatepal(i, plOpenCPPal[i*3], plOpenCPPal[i*3+1], plOpenCPPal[i*3+2]);
 		gflushpal();
-	    plSetGraphPage(0);
-	    memcpy((char*)plVidMem+96*640, plOpenCPPict, 4096);
-	    plSetGraphPage(1);
-	    memcpy((char*)plVidMem, plOpenCPPict+4096, 65536);
-	    plSetGraphPage(2);
-	    memcpy((char*)plVidMem, plOpenCPPict+69632, 65536);
-	    plSetGraphPage(3);
-	    memcpy((char*)plVidMem, plOpenCPPict+135168, 65536);
-	    plSetGraphPage(4);
-	    memcpy((char*)plVidMem, plOpenCPPict+200704, 45056);
+		memcpy((char*)plVidMem+96*640, plOpenCPPict, (480-96)*640);
 	} else {
-		plSetGraphPage(0);
-		memset((char*)plVidMem+96*640, 0, 4096);
-		plSetGraphPage(1);
-		memset((char*)plVidMem, 0, 65536);
-		plSetGraphPage(2);
-		memset((char*)plVidMem, 0, 65536);
-		plSetGraphPage(3);
-		memset((char*)plVidMem, 0, 65536);
-		plSetGraphPage(4);
-		memset((char*)plVidMem, 0, 45056);
+		memset((char*)plVidMem+96*640, 0, (480-96)*640);
 	}
 
 	replacebufpos=replacebuf;
@@ -165,6 +147,14 @@ static int plScopesKey(uint16_t key)
 {
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp('b', "Toggle phase viewer types");
+			cpiKeyHelp('B', "Toggle phase viewer types");
+			cpiKeyHelp(KEY_PPAGE, "Increase the frequency space for the phase viewer");
+			cpiKeyHelp(KEY_NPAGE, "Decrease the frequency space for the phase viewer");
+			cpiKeyHelp(KEY_HOME, "Reset the settings for the phase viewer");
+			cpiKeyHelp(KEY_TAB, "Toggle phase viewer channel-mode");
+			break;
 /* TODO-keys	case 0x8400: //ctrl-pgup
 		//    plOszRate=plOszRate*31/32;
 		//    plOszRate=(plOszRate>=512000)?256000:(plOszRate<2048)?2048:plOszRate;
@@ -206,7 +196,7 @@ static int plScopesKey(uint16_t key)
 			plScopesRatio=256;
 			plOszRate=44100;
 			break;
-		case 9: /* tab */
+		case KEY_TAB: /* tab */
 /* TODO -keys	case 0x0F00: // shift-tab
 		case 0xA500:
 		case 0x1800: // alt-o*/
@@ -316,7 +306,6 @@ static void drawframe(void)
 {
 	int n;
 
-	int pg;
 	uint32_t *bp;
 	uint32_t *b2;
 
@@ -335,13 +324,9 @@ static void drawframe(void)
 	radix(sorttemp, replacebuf, n, 2);
 	radix(replacebuf, sorttemp, n, 1);
 #endif
-	pg=-1;
 	for (b2 = replacebuf; b2<replacebufpos; b2++)
 	{
-		uint8_t cache = ((*b2)>>16)&0xff;
-		if (pg!=cache)
-			plSetGraphPage(pg=cache);
-		*(unsigned char*)(plVidMem+((*b2)&0xffff))=(*b2)>>24;
+		*(unsigned char*)(plVidMem+((*b2)&0xffffff))=(*b2)>>24;
 	}
 
 	memcpy(replacebuf,dotbuf,(dotbufpos-dotbuf)*4);
@@ -415,6 +400,10 @@ static int scoIProcessKey(uint16_t key)
 {
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp('b', "Enable phase mode");
+			cpiKeyHelp('B', "Enable phase mode");
+			return 0;
 		case 'b': case 'B':
 			cpiSetMode("phase");
 			break;
@@ -436,4 +425,14 @@ static int scoEvent(int ev)
 	return 1;
 }
 
-struct cpimoderegstruct cpiModePhase = {"phase", scoSetMode, scoDraw, scoIProcessKey, plScopesKey, scoEvent};
+static struct cpimoderegstruct cpiModePhase = {"phase", scoSetMode, scoDraw, scoIProcessKey, plScopesKey, scoEvent};
+
+static void __attribute__((constructor))init(void)
+{
+	cpiRegisterDefMode(&cpiModePhase);
+}
+
+static void __attribute__((destructor))done(void)
+{
+	cpiUnregisterDefMode(&cpiModePhase);
+}
