@@ -34,4 +34,4 @@ static int cpiReadInfo(struct moduleinfostruct *m, FILE *file, const char *c, si
 	return 0;
 }
 
-struct mdbreadnforegstruct cpiReadInfoReg = {cpiReadMemInfo, cpiReadInfo};
+struct mdbreadinforegstruct cpiReadInfoReg = {cpiReadMemInfo, cpiReadInfo};
