@@ -93,27 +93,9 @@ static void plPrepareScopes(void)
 		for (i=16; i<256; i++)
 			gupdatepal(i, plOpenCPPal[i*3], plOpenCPPal[i*3+1], plOpenCPPal[i*3+2]);
 		gflushpal();
-		plSetGraphPage(0);
-		memcpy((char*)plVidMem+96*640, plOpenCPPict, 4096);
-		plSetGraphPage(1);
-		memcpy((char*)plVidMem, plOpenCPPict+4096, 65536);
-		plSetGraphPage(2);
-		memcpy((char*)plVidMem, plOpenCPPict+69632, 65536);
-		plSetGraphPage(3);
-		memcpy((char*)plVidMem, plOpenCPPict+135168, 65536);
-		plSetGraphPage(4);
-		memcpy((char*)plVidMem, plOpenCPPict+200704, 45056);
+		memcpy((char*)plVidMem+96*640, plOpenCPPict, (480-96)*640);
 	} else {
-		plSetGraphPage(0);
-		memset((char*)plVidMem+96*640, 0, 4096);
-		plSetGraphPage(1);
-		memset((char*)plVidMem, 0, 65536);
-		plSetGraphPage(2);
-		memset((char*)plVidMem, 0, 65536);
-		plSetGraphPage(3);
-		memset((char*)plVidMem, 0, 65536);
-		plSetGraphPage(4);
-		memset((char*)plVidMem, 0, 45056);
+		memset((char*)plVidMem+96*640, 0, (480-96)*640);
 	}
 
 	memset(scopes, 0, MAXDOTS*2);
@@ -203,24 +185,12 @@ static void plPrepareScopeScr(void)
 
 static void plotbuf(uint32_t *buf, int len)
 {
-	uint8_t j;
 	int i;
 	uint8_t *b=(uint8_t*)buf;
-	uint8_t used[5];
 	uint32_t *buf2;
 
-	used[0]=used[1]=used[2]=used[3]=used[4]=0;
 	for (i=0, buf2=buf; i<len; i++, b+=4)
-		used[(buf[i]&0x00ff0000)>>16]=1;
-	for (j=0; j<5; j++)
-	{
-		if (!used[j])
-			continue;
-		plSetGraphPage(j);
-		for (i=0, buf2=buf; i<len; i++, b+=4)
-			if (((buf[i]&0x00ff0000)>>16)==j)
-				*(uint8_t*)(plVidMem+(buf[i]&0xffff))=(buf[i])>>24;
-	}
+		*(uint8_t*)(plVidMem+(buf[i]&0x00ffffff))=(buf[i])>>24;
 }
 
 static void drawscope(int x, int y, const int16_t *in, int16_t *out, int num, uint8_t col, int step)
@@ -280,6 +250,14 @@ static int plScopesKey(uint16_t key)
 {
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp('o', "Toggle scope viewer types");
+			cpiKeyHelp('O', "Toggle scope viewer types");
+			cpiKeyHelp(KEY_PPAGE, "Increase the scope viewer frequency range");
+			cpiKeyHelp(KEY_NPAGE, "Decrease the scope viewer frequency range");
+			cpiKeyHelp(KEY_HOME, "Reset the scope viewer settings");
+			cpiKeyHelp(KEY_TAB, "Toggle scope viewer channel");
+			return 0;
 		/*case 0x4900: //pgup*/
 		case KEY_PPAGE:
 			plOszRate=plOszRate*31/32;
@@ -316,7 +294,7 @@ static int plScopesKey(uint16_t key)
 			plScopesAmp2=640;
 			plOszRate=44100;
 			break;
-		case 9: /* tab */
+		case KEY_TAB: /* tab */
 /* TODO-keys	case 0x0F00: // shift-tab
 		case 0xA500:
 		case 0x1800: // alt-o*/
@@ -505,6 +483,10 @@ static int scoIProcessKey(uint16_t key)
 {
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp('o', "Enable scope mode");
+			cpiKeyHelp('O', "Enable scope");
+			return 0;
 		case 'o': case 'O':
 			cpiSetMode("scope");
 			break;
@@ -526,4 +508,14 @@ static int scoEvent(int ev)
 	return 1;
 }
 
-struct cpimoderegstruct cpiModeScope = {"scope", scoSetMode, scoDraw, scoIProcessKey, plScopesKey, scoEvent};
+static struct cpimoderegstruct cpiModeScope = {"scope", scoSetMode, scoDraw, scoIProcessKey, plScopesKey, scoEvent};
+
+static void __attribute__((constructor))init(void)
+{
+	cpiRegisterDefMode(&cpiModeScope);
+}
+
+static void __attribute__((destructor))done(void)
+{
+	cpiUnregisterDefMode(&cpiModeScope);
+}
