@@ -16,15 +16,14 @@
 #include <string.h>
 #include "types.h"
 #include "stuff/poutput.h"
-#include "boot/pmain.h"
 #include "filesel/pfilesel.h"
 #include "cpiface.h"
 #include "boot/psetting.h"
 #include "boot/plinkman.h"
 
 static struct cpitextmoderegstruct *cpiTextActModes;
-static struct cpitextmoderegstruct *cpiTextModes;
-static struct cpitextmoderegstruct *cpiTextDefModes;
+static struct cpitextmoderegstruct *cpiTextModes = 0;
+static struct cpitextmoderegstruct *cpiTextDefModes = 0;
 static struct cpitextmoderegstruct *cpiFocus;
 static char cpiFocusHandle[9];
 static int modeactive;
@@ -39,14 +38,78 @@ void cpiTextRegisterMode(struct cpitextmoderegstruct *mode)
 	cpiTextModes=mode;
 }
 
-static void cpiTextRegisterDefMode(struct cpitextmoderegstruct *mode)
+void cpiTextUnregisterMode(struct cpitextmoderegstruct *m)
 {
-	if (mode->Event&&!mode->Event(cpievInitAll))
+	if (cpiTextModes==m)
+	{
+		cpiTextModes=m->next;
 		return;
+	} else {
+		struct cpitextmoderegstruct *p = cpiTextModes;
+		while (p)
+		{
+			if (p->next==m)
+			{
+				p->next=m->next;
+				return;
+			}
+			p=p->next;
+		}
+	}
+}
+
+void cpiTextRegisterDefMode(struct cpitextmoderegstruct *mode)
+{
 	mode->nextdef=cpiTextDefModes;
 	cpiTextDefModes=mode;
 }
 
+static void cpiTextVerifyDefModes(void)
+{
+	struct cpitextmoderegstruct *p;
+
+	while (cpiTextDefModes)
+	{
+
+		if (cpiTextDefModes->Event&&!cpiTextDefModes->Event(cpievInitAll))
+			cpiTextDefModes=cpiTextDefModes->nextdef;
+		else
+			break;
+	}
+	p = cpiTextDefModes;
+	while (p)
+	{
+		if (p->nextdef)
+		{
+			if (p->nextdef->Event&&!p->nextdef->Event(cpievInitAll))
+				p->nextdef=p->nextdef->nextdef;
+			else
+				p=p->nextdef;
+		} else
+			break;
+	}
+}
+
+void cpiTextUnregisterDefMode(struct cpitextmoderegstruct *m)
+{
+	if (cpiTextDefModes==m)
+	{
+		cpiTextDefModes=m->next;
+		return;
+	} else {
+		struct cpitextmoderegstruct *p = cpiTextDefModes;
+		while (p)
+		{
+			if (p->nextdef==m)
+			{
+				p->nextdef=m->nextdef;
+				return;
+			}
+			p=p->nextdef;
+		}
+	}
+}
+
 static void cpiSetFocus(const char *name)
 {
 	struct cpitextmoderegstruct *mode;
@@ -66,7 +129,9 @@ static void cpiSetFocus(const char *name)
 	if (!mode||(mode->Event&&!mode->Event(cpievGetFocus)))
 		return;
 	cpiFocus=mode;
+	mode->active=1;
 	strcpy(cpiFocusHandle, cpiFocus->handle);
+	cpiTextRecalc();	
 }
 
 void cpiTextSetMode(const char *name)
@@ -342,9 +407,25 @@ static void txtDraw(void)
 static int txtIProcessKey(uint16_t key)
 {
 	struct cpitextmoderegstruct *mode;
+#ifdef KEYBOARDTEXT_DEBUG
+	fprintf(stderr, "txtIProcessKey:START\n");
+#endif
 	for (mode=cpiTextModes; mode; mode=mode->next)
+	{
+#ifdef KEYBOARDTEXT_DEBUG
+		fprintf(stderr, "Checking mode %s\n", mode->handle);
+#endif
 		if (mode->IProcessKey(key))
+		{
+#ifdef KEYBOARDTEXT_DEBUG
+			fprintf(stderr, "Mode swallowed event\ntxtIProcessKey:STOP\n");
+#endif
 			return 1;
+		}
+	}
+#ifdef KEYBOARDTEXT_DEBUG
+	fprintf(stderr, "txtIProcessKey:STOP\n");
+#endif
 	switch (key)
 	{
 		case 'x': case 'X':
@@ -366,15 +447,32 @@ static int txtIProcessKey(uint16_t key)
 
 static int txtAProcessKey(uint16_t key)
 {
-	struct cpitextmoderegstruct *mode;
-
+#ifdef KEYBOARDTEXT_DEBUG
+	fprintf(stderr, "txtAProcessKey:START\ncpiFocus is %s\n", cpiFocus?"set":"unset");
+#endif
 	if (cpiFocus)
-		cpiFocus->AProcessKey(key);
-	for (mode=cpiTextModes; mode; mode=mode->next)
-		if (mode->IProcessKey(key))
-			 return 1;
+		if (cpiFocus->active)
+			if (cpiFocus->AProcessKey(key))
+			{
+#ifdef KEYBOARDTEXT_DEBUG
+				fprintf(stderr, "cpiFocus %s swallowed event\ntxtAProcessKey:STOP\n", cpiFocus->handle);
+#endif
+				return 1;
+			}
+#ifdef KEYBOARDTEXT_DEBUG
+	fprintf(stderr, "nobody swallowed the event\ntxtAProcessKey:STOP\n");
+#endif
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp('x', "Set screen text mode (set mode 7)");
+			cpiKeyHelp('X', "Set screen text mode (set mode 7)");
+			cpiKeyHelp('z', "Set screen text mode (toggle bit 1)");
+			cpiKeyHelp('Z', "Set screen text mode (toggle bit 1)");
+			cpiKeyHelp(KEY_ALT_X, "Set screen text screen mode (set mode 0)");
+			cpiKeyHelp(KEY_ALT_Z, "Set screen text screen mode (toggle bit 2)");
+			cpiKeyHelp(KEY_CTRL_Z, "Set screen text screen mode (toggle bit 1)");
+			return 0;
 		case 'x': case 'X':
 			fsScrType=7;
 			cpiResetScreen();
@@ -421,21 +519,7 @@ static void txtClose(void)
 
 static int txtInitAll(void)
 {
-	char regname[50];
-	const char *regs;
-
-	cpiTextModes=0;
-	cpiTextDefModes=0;
-
-	regs=_lnkReadInfoReg("deftmodes");
-	/*cfGetProfileString2(cfScreenSec, "screen", "deftmodes", ""); */
-	while (cfGetSpaceListEntry(regname, &regs, 49))
-	{
-		void *reg=_lnkGetSymbol(regname);
-		if (reg)
-			cpiTextRegisterDefMode((struct cpitextmoderegstruct*)reg);
-	}
-
+	cpiTextVerifyDefModes();
 	return 1;
 }
 
