@@ -592,6 +592,14 @@ static int gmdTrkProcessKey(uint16_t key)
 {
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp(' ', "Release the track viewer (enable manual scrolling)");
+			cpiKeyHelp(KEY_TAB, "Rotate track viewer modes");
+			cpiKeyHelp(KEY_SHIFT_TAB, "Rotate track viewer modes (reverse)");
+			cpiKeyHelp(KEY_HOME, "Reset track viewer settings");
+			cpiKeyHelp(KEY_NPAGE, "Zoom track viewer / scroll track viewer");
+			cpiKeyHelp(KEY_PPAGE, "Zoom track viewer / scroll track viewer");
+			return 0;
 		case KEY_PPAGE:
 			if (plPatManualPat==-1)
 			{
@@ -648,7 +656,7 @@ static int gmdTrkProcessKey(uint16_t key)
 			plPatType=(plNLChan<=4)?13:(plNLChan<=8)?11:(plNLChan<=16)?9:(plNLChan<=24)?7:(plNLChan<=32)?5:(plNLChan<=48)?3:1;
 /* TODO   winrecalc(); */
 			break;
-		case 9: /* tab */
+		case KEY_TAB: /* tab */
 			if (plPatManualPat==-1)
 			{
 				plPatType^=1;
@@ -661,8 +669,9 @@ static int gmdTrkProcessKey(uint16_t key)
 				}
 			}
 			break;
-/* TODO-keys	case 0x0F00: // shift-tab
-		case 0xA500:
+		case KEY_SHIFT_TAB:
+/* TODO-keys	
+		case 0xA500:*/
 			if (plPatManualPat==-1)
 			{
 				plPatType^=1;
@@ -674,7 +683,7 @@ static int gmdTrkProcessKey(uint16_t key)
 					plPrepdPat=-1;
 				}
 			}
-			break;*/
+			break;
 		case ' ':
 			if (plPatManualPat==-1)
 			{
@@ -721,15 +730,20 @@ static int TrakIProcessKey(uint16_t key)
 {
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp('t', "Enable track viewer");
+			cpiKeyHelp('T', "Eanble track viewer");
+			return 0;
 		case 't': case 'T':
+			plTrackActive=1;
 			cpiTextSetMode("trak");
 			break;
 		case 'x': case 'X':
 			plTrackActive=1;
 			return 0;
-/* TODO-keys	case 0x2d00: //alt-x
+		case KEY_ALT_X:
 			plTrackActive=0;
-			return 0;*/
+			return 0;
 		default:
 			return 0;
 	}
@@ -769,7 +783,7 @@ static int trkEvent(int ev)
 	return 1;
 }
 
-struct cpitextmoderegstruct cpiTModeTrack = {"trak", TrakGetWin, TrakSetWin, TrakDraw, TrakIProcessKey, TrakAProcessKey, trkEvent};
+static struct cpitextmoderegstruct cpiTModeTrack = {"trak", TrakGetWin, TrakSetWin, TrakDraw, TrakIProcessKey, TrakAProcessKey, trkEvent};
 
 void cpiTrkSetup(const struct cpitrakdisplaystruct *c, int npat)
 {
