@@ -119,8 +119,9 @@ static int32_t cossintab86[SAMPLES2][2]=
 };
 static uint16_t permtab[SAMPLES];
 
-static int inited=0;
-static /*inline*/ void fftInit(void)
+static void
+__attribute__((constructor))
+fftInit(void)
 {
 	int i,j,k;
 	j=0;
@@ -144,8 +145,6 @@ static /*inline*/ void fftInit(void)
 		cossintab86[i][0]=-cossintab86[SAMPLES2-i][0];
 		cossintab86[i][1]=cossintab86[SAMPLES2-i][1];
 	}
-
-	inited=1;
 }
 
 #ifdef I386_ASM
@@ -271,9 +270,6 @@ void fftanalyseall(uint16_t *ana, const int16_t *samp, const int inc, const int
 	int i;
 	int32_t xr[2];
 
-	if (!inited)
-		fftInit();
-
 	for (i=0; i<full; ++i)
 	{
 		x86[i][0]=*samp<<12;
