@@ -220,9 +220,9 @@ static uint16_t prefix[MAX_CODES + 1];           /* Prefix linked list */
 
 static int decoder(int linewidth)
 {
-	register unsigned char *sp, *bufptr;
+	unsigned char *sp, *bufptr;
 	unsigned char *buf;
-	register short code, fc, oc, bufcnt;
+	uint16_t code, fc, oc, bufcnt;
 	int c, size, ret;
 
 	/* Initialize for decoding a new image...
