@@ -18,6 +18,7 @@
 #include "boot/psetting.h"
 #include "stuff/poutput.h"
 #include "stuff/sets.h"
+#include "cpiface.h"
 
 #include <curses.h>
 
@@ -134,6 +135,27 @@ int mcpSetProcessKey(uint16_t key)
 {
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp('-', "Decrease volume");
+			cpiKeyHelp('+', "Increase volume");
+			cpiKeyHelp('/', "Fade balance left");
+			cpiKeyHelp('*', "Fade balance right");
+			cpiKeyHelp(',', "Fade panning against normal");
+			cpiKeyHelp('.', "Fade panning against reverse");
+			cpiKeyHelp(KEY_F2, "Decrease volume (faster)");
+			cpiKeyHelp(KEY_F3, "Increase volume (faster)");
+			cpiKeyHelp(KEY_F4, "Toggle surround on/off");
+			cpiKeyHelp(KEY_F5, "Fade balance left (faster)");
+			cpiKeyHelp(KEY_F6, "Fade balance right (faster)");
+			cpiKeyHelp(KEY_F7, "Fade panning against normal (faster)");
+			cpiKeyHelp(KEY_F8, "Fade panning against reverse (faster)");
+			cpiKeyHelp(KEY_F9, "Decrease speed (fine)");
+			cpiKeyHelp(KEY_F10, "Increase speed (fine)");
+			cpiKeyHelp(KEY_F11, "Decrease pitch (fine)");
+			cpiKeyHelp(KEY_F12, "Increase pitch (fine)");
+			cpiKeyHelp('\\', "Toggle lock between pitch/speed");
+			cpiKeyHelp(KEY_BS, "Cycle mixer-filters");
+			return 0;
 		case '-':
 			if (vol>=2)
 				vol-=2;
