@@ -16,7 +16,6 @@
 #include <string.h>
 #include <stdio.h>
 #include "types.h"
-#include "boot/pmain.h"
 #include "filesel/dirdb.h"
 #include "filesel/pfilesel.h"
 #include "filesel/mdb.h"
@@ -36,6 +35,8 @@ int plrBufSize;
 static struct devinfonode *curplaydev;
 static struct devinfonode *defplaydev;
 
+static struct mdbreaddirregstruct plrReadDirReg;
+
 static struct devinfonode *getdevstr(struct devinfonode *n, const char *hnd)
 {
 	while (n)
@@ -135,6 +136,9 @@ static int playdevinit(void)
 	fprintf(stderr, "playdevinit... trying to init all sound devices [sound]->playerdevices\n");
 #endif
 
+	mdbRegisterReadDir(&plrReadDirReg);
+
+
 	dmSETUP=RegisterDrive("setup:");
 
 	if (!strlen(cfGetProfileString2(cfSoundSec, "sound", "playerdevices", "")))
@@ -168,6 +172,9 @@ static void playdevclose(void)
 #ifdef INITCLOSE_DEBUG
 	fprintf(stderr, "playdevclose...\n");
 #endif
+
+	mdbUnregisterReadDir(&plrReadDirReg);
+
 	setdevice(&curplaydev, 0);
 	while (plPlayerDevices)
 	{
@@ -262,9 +269,8 @@ static void plrPrep(const char *path, struct moduleinfostruct *m, FILE **fp)
 }
 
 struct interfacestruct plrIntr = {plrSet, 0, 0};
-struct mdbreaddirregstruct plrReadDirReg = {plrReadDir};
+static struct mdbreaddirregstruct plrReadDirReg = {plrReadDir};
 
-struct initcloseregstruct plrDevReg={playdevinit, playdevclose};
 struct preprocregstruct plrPreprocess = {plrPrep};
-char *dllinfo = "initclose plrDevReg; interface plrIntr; preprocess plrPreprocess; readdirs plrReadDirReg; interface plrIntr";
-struct linkinfostruct dllextinfo = {"plrbase", "OpenCP Player Devices System (c) 1994-04 Niklas Beisert, Tammo Hinrichs", DLLVERSION, 0};
+char *dllinfo = "preprocess plrPreprocess";
+struct linkinfostruct dllextinfo = {"plrbase", "OpenCP Player Devices System (c) 1994-04 Niklas Beisert, Tammo Hinrichs", DLLVERSION, 0, Init: playdevinit, Close: playdevclose};
