@@ -24,7 +24,6 @@
 #include "boot/psetting.h"
 #include "boot/plinkman.h"
 #include "stuff/err.h"
-#include "boot/pmain.h"
 #include "devigen.h"
 #include "mcp.h"
 #include "stuff/compat.h"
@@ -34,6 +33,7 @@ int (*mcpProcessKey)(unsigned short);
 struct devinfonode *plWaveTableDevices;
 static struct devinfonode *curwavedev;
 static struct devinfonode *defwavedev;
+static struct mdbreaddirregstruct mcpReadDirReg;
 
 static struct devinfonode *getdevstr(struct devinfonode *n, const char *hnd)
 {
@@ -140,6 +140,8 @@ static int wavedevinit(void)
 	fprintf(stderr, "wavedevinit... trying to find all wavetables    [sound]->wavetabledevices\n");
 #endif
 
+	mdbRegisterReadDir(&mcpReadDirReg);
+
 	dmSETUP=RegisterDrive("setup:");
 
 	if (!strlen(cfGetProfileString2(cfSoundSec, "sound", "wavetabledevices", "")))
@@ -192,6 +194,8 @@ static void wavedevclose(void)
 	fprintf(stderr, "wavedevclose....\n");
 #endif
 
+	mdbUnregisterReadDir(&mcpReadDirReg);
+
 	setdevice(&curwavedev, 0);
 	while (plWaveTableDevices)
 	{
@@ -286,11 +290,10 @@ static void mcpPrep(const char *path, struct moduleinfostruct *info, FILE **bp)
 }
 
 
-struct mdbreaddirregstruct mcpReadDirReg = {mcpReadDir};
+static struct mdbreaddirregstruct mcpReadDirReg = {mcpReadDir};
 
 struct interfacestruct mcpIntr = {mcpSetDev, 0, 0};
 
-struct initcloseregstruct mcpDevReg={wavedevinit, wavedevclose};
 struct preprocregstruct mcpPreprocess = {mcpPrep};
-char *dllinfo = "initclose mcpDevReg; preprocess mcpPreprocess; readdirs mcpReadDirReg; interface mcpIntr";
-struct linkinfostruct dllextinfo = {"mcpbase", "OpenCP Wavetable Devices System (c) 1994-04 Niklas Beisert, Tammo Hinrichs", DLLVERSION, 0};
+char *dllinfo = "preprocess mcpPreprocess";
+struct linkinfostruct dllextinfo = {"mcpbase", "OpenCP Wavetable Devices System (c) 1994-04 Niklas Beisert, Tammo Hinrichs", DLLVERSION, 0, Init: wavedevinit, Close: wavedevclose};
