@@ -11,6 +11,8 @@
 
 struct sounddevice;
 
+#define DEVICE_NAME_MAX 63
+
 struct deviceinfo
 {
 	struct sounddevice *dev;
@@ -24,8 +26,8 @@ struct deviceinfo
 	int8_t subtype;
 	uint8_t chan;
 	uint32_t mem;
-	char path[128]; /* can be like 127.0.0.1:32000, or stuff like /tmp/.esd .... or whatever you prefer or just empty for no force*/
-	char mixer[128];
+	char path[DEVICE_NAME_MAX+1]; /* can be like 127.0.0.1:32000, or stuff like /tmp/.esd .... or whatever you prefer or just empty for no force*/
+	char mixer[DEVICE_NAME_MAX+1];
 };
 
 struct sounddevice
