@@ -7,8 +7,8 @@
 
 int retval=0;
 
-char *OK10="[1m[32mok                [0m[37m";
-char *FAILED10="[1m[31mfailed            [0m[37m";
+char *OK10="\x1b[1m\x1b[32mok                \x1b[0m\x1b[37m";
+char *FAILED10="\x1b[1m\x1b[31mfailed            \x1b[0m\x1b[37m";
 
 void test1(void)
 {
