@@ -111,9 +111,9 @@ void mixClipAlt(uint16_t *dst, const uint16_t *src, uint32_t len, const uint16_t
 		"  movb 1+\\from(%%esi), %%dl\n"
 		"  movl (%%ebx,%%edx,4), %%ebp\n"
 		"  movl 1024(%%ebx,%%edx,2), %%eax\n"
-		"  movb \\from(%%esi), %%dl\n"
+		".byte 0x8a\n.byte 0x56\n.byte \\from\n"  /* since some gcc/binutils patct-sets optimze away 0 offset, we do this  "movb \\from(%%esi), %%dl\n" */
 		"  addl (%%ebp,%%edx,2), %%eax\n"
-		"  movw %%ax, \\from(%%edi)\n"
+		".byte 0x66\n.byte 0x89\n.byte 0x47\n.byte \\from\n" /* since some gcc/binutils patct-sets optimze away 0 offset, we do this "movw %%ax, \\from(%%edi)\n" */
 		".if \\to-\\from\n"
 		" dummy \"(\\from+2)\",\\to\n"
 		".endif\n"
@@ -185,12 +185,12 @@ void mixClipAlt2(uint16_t *dst, const uint16_t *src, uint32_t len, const uint16_
 /*		"  nop\n"
 		"  nop\n" */
 		".macro dummy2 from=0, to=60\n"
-		".byte 0x8A\n.byte 0x56\n.byte 1+\\from\n" /* since some gcc/binutils patct-sets optimze away 0 offset, we do this "  movb 1+\\from(%%esi), %%dl\n"*/
+		"  movb 1+\\from(%%esi), %%dl\n"
 		"  movl (%%ebx,%%edx,4), %%ebp\n"
 		"  movl 1024(%%ebx,%%edx,2), %%eax\n"
-		"  movb \\from(%%esi), %%dl\n"
+		".byte 0x8A\n.byte 0x56\n.byte \\from\n" /* since some gcc/binutils patct-sets optimze away 0 offset, we do this "  movb \\from(%%esi), %%dl\n"*/
 		"  addl (%%ebp,%%edx,2), %%eax\n"
-		"  movw %%ax, \\from(%%edi)\n"
+		".byte 0x66\n.byte 0x89\n.byte 0x47\n.byte \\from\n" /* since some gcc/binutils patct-sets optimze away 0 offset, we do this "movw %%ax, \\from(%%edi)\n" */
 		".if \\to-\\from\n"
 		" dummy2 \"(\\from+4)\",\\to\n"
 		".endif\n"
