@@ -20,7 +20,7 @@ extern void (*plrSetOptions)(uint32_t rate, int opt);
 extern int (*plrGetBufPos)(void);
 extern int (*plrGetPlayPos)(void);
 extern void (*plrAdvanceTo)(int pos);
-extern long (*plrGetTimer)(void);
+extern uint32_t (*plrGetTimer)(void);
 extern void (*plrIdle)(void);
 #ifdef PLR_DEBUG
 extern char *(*plrDebug)(void);
