@@ -9,6 +9,7 @@
 #include "config.h"
 #define ALSA_PCM_NEW_HW_PARAMS_API
 #define ALSA_PCM_NEW_SW_PARAMS_API
+#include <curses.h>
 #include <alsa/asoundlib.h>
 #include <alsa/mixer.h>
 #include <alsa/pcm.h>
@@ -16,6 +17,7 @@
 #include <string.h>
 #include "types.h"
 #include "boot/plinkman.h"
+#include "boot/psetting.h"
 #include "cpiface/vol.h"
 #include "dev/imsdev.h"
 #include "dev/player.h"
@@ -23,10 +25,9 @@
 #include "filesel/mdb.h"
 #include "filesel/modlist.h"
 #include "filesel/pfilesel.h"
-#ifdef PLR_DEBUG
-#include "stuff/poutput.h"
-#endif
+#include "stuff/framelock.h"
 #include "stuff/imsrtns.h"
+#include "stuff/poutput.h"
 
 static snd_pcm_t *alsa_pcm = NULL;
 static snd_mixer_t *mixer = NULL;
@@ -36,7 +37,8 @@ struct sounddevice plrAlsa;
 static struct mdbreaddirregstruct readdirAlsa;
 static void alsaOpenDevice(void);
 
-static int defaultcard, defaultdevice;
+static char alsaCardName[DEVICE_NAME_MAX+1];
+static char alsaMixerName[DEVICE_NAME_MAX+1];
 
 static struct dmDrive *dmSETUP;
 
@@ -56,12 +58,39 @@ static int alsa_mixers_n=0;
  *  on getplaypos we use last known kernpos if locked, else update kernpos
  */
 
-volatile static long playpos; /* how many samples have we done totally */
+volatile static uint32_t playpos; /* how many samples have we done totally */
 static int stereo;
 static int bit16;
 
 volatile static int busy=0;
+uint32_t customfileref=0xffffffff;
+uint32_t custommixerref=0xffffffff;
 
+static int mlDrawBox(void)
+{
+	int mlTop=plScrHeight/2-2;
+	int i;
+
+	displayvoid(mlTop+1, 5, plScrWidth-10);
+	displayvoid(mlTop+2, 5, plScrWidth-10);
+	displayvoid(mlTop+3, 5, plScrWidth-10);
+	displaystr(mlTop, 4, 0x04, "\xda", 1);
+	for (i=5;i<(plScrWidth-5);i++)
+		displaystr(mlTop, i, 0x04, "\xc4", 1);
+	displaystr(mlTop, plScrWidth-5, 0x04, "\xbf", 1);
+	displaystr(mlTop+1, 4, 0x04, "\xb3", 1);
+	displaystr(mlTop+2, 4, 0x04, "\xb3", 1);
+	displaystr(mlTop+3, 4, 0x04, "\xb3", 1);
+	displaystr(mlTop+1, plScrWidth-5, 0x04, "\xb3", 1);
+	displaystr(mlTop+2, plScrWidth-5, 0x04, "\xb3", 1);
+	displaystr(mlTop+3, plScrWidth-5, 0x04, "\xb3", 1);
+	displaystr(mlTop+4, 4, 0x04, "\xc0", 1);
+	for (i=5;i<(plScrWidth-5);i++)
+		displaystr(mlTop+4, i, 0x04, "\xc4", 1);
+	displaystr(mlTop+4, plScrWidth-5, 0x04, "\xd9", 1);
+
+	return mlTop;
+}
 /* stolen from devposs */
 static int getbufpos(void)
 {
@@ -252,7 +281,7 @@ static void advance(int pos)
 	busy--;
 }
 /* stolen from devposs */
-static long gettimer(void)
+static uint32_t gettimer(void)
 {
 	long tmp=playpos;
 	int odelay;
@@ -303,22 +332,263 @@ static long gettimer(void)
 	return imuldiv(tmp, 65536>>(stereo+bit16), plrRate);
 }
 
+static FILE *alsaSelectMixer(struct modlistentry *entry)
+{
+	char *t;
+	int card;
+	if (!strcmp(entry->name, "none.dev"))
+	{
+		strcpy(alsaMixerName, "");
+	} else if (!strcmp(entry->name, "custom.dev"))
+	{
+		int mlTop=mlDrawBox();
+		char str[DEVICE_NAME_MAX+1];
+		int curpos;
+		int cmdlen;
+		int insmode=1;
+		int scrolled=0;
+
+		strcpy(str, alsaMixerName);
+
+		displaystr(mlTop+1, 5, 0x0b, "Give me something to crunch!!", 29);
+		displaystr(mlTop+3, 5, 0x0b, "-- Finish with enter, abort with escape --", 32);
+
+		curpos=strlen(str);
+		cmdlen=strlen(str);
+		setcurshape(1);
+
+		while (1)
+		{
+			uint16_t key;
+			displaystr(mlTop+2, 5, 0x8f, str+scrolled, plScrWidth-10);
+			setcur(mlTop+2, 5+curpos-scrolled);
+
+			while (!ekbhit())
+				framelock();
+			key=egetch();
+
+			if ((key>=0x20)&&(key<=0x7f))
+			{
+				if (insmode)
+				{
+					if ((cmdlen+1)<sizeof(str))
+					{
+						memmove(str+curpos+1, str+curpos, cmdlen-curpos+1);
+						str[curpos++]=key;
+						cmdlen++;
+					}
+				} else if (curpos==cmdlen)
+				{
+					if ((cmdlen+1)<(sizeof(str)))
+					{
+						str[curpos++]=key;
+						str[curpos]=0;
+						cmdlen++;
+					}
+				} else
+					str[curpos++]=key;
+			} else switch (key)
+			{
+			case KEY_ESC:
+				setcurshape(0);
+				return NULL;
+			case KEY_LEFT:
+				if (curpos)
+					curpos--;
+				break;
+			case KEY_RIGHT:
+				if (curpos<cmdlen)
+					curpos++;
+				break;
+			case KEY_HOME:
+				curpos=0;
+				break;
+			case KEY_END:
+				curpos=cmdlen;
+				break;
+			case KEY_INSERT:
+				{
+					insmode=!insmode;
+					setcurshape(insmode?1:2);
+				}
+				break;
+			case KEY_DELETE:
+				if (curpos!=cmdlen)
+				{
+					memmove(str+curpos, str+curpos+1, cmdlen-curpos);
+					cmdlen--;
+				}
+				break;
+			case KEY_BACKSPACE:
+				if (curpos)
+				{
+					memmove(str+curpos-1, str+curpos, cmdlen-curpos+1);
+					curpos--;
+					cmdlen--;
+				}
+				break;
+			case _KEY_ENTER:
+				strcpy(alsaMixerName, str);
+				setcurshape(0);	
+				goto out;
+			}
+			while ((curpos-scrolled)>=(plScrWidth-10))
+				scrolled+=8;
+			while ((curpos-scrolled)<0)
+				scrolled-=8;
+		}
+	} else {
+		if (!(t=strchr(entry->name, ':')))
+			return NULL;
+		card=atoi(t+1);
+		snprintf(alsaMixerName, sizeof(alsaMixerName), "hw:%d", card);
+	}
+out:
+/* #ifdef ALSA_DEBUG */
+	fprintf(stderr, "ALSA: Selected mixer %s\n", alsaMixerName);
+/* #endif */
+	{
+		if (custommixerref!=0xffffffff)
+		{
+			struct moduleinfostruct mi;
+			mdbGetModuleInfo(&mi, custommixerref);
+			snprintf(mi.modname, sizeof(mi.modname), "%s", alsaMixerName);
+			mdbWriteModuleInfo(custommixerref, &mi);
+		}
+
+	}
+	return NULL;
+}
+
 static FILE *alsaSelectPcmOut(struct modlistentry *entry)
 {
 	char *t;
 	int card, device;
-	if (!(t=strchr(entry->name, ':')))
-		return NULL;
-	card=atoi(t+1);
-	if (!(t=strchr(entry->name, ',')))
-		return NULL;
-	device=atoi(t+1);
+	if (!strcmp(entry->name, "default.dev"))
+	{
+		strcpy(alsaCardName, "default");
+	} else if (!strcmp(entry->name, "custom.dev"))
+	{
+		int mlTop=mlDrawBox();
+		char str[DEVICE_NAME_MAX+1];
+		int curpos;
+		int cmdlen;
+		int insmode=1;
+		int scrolled=0;
+
+		strcpy(str, alsaCardName);
+
+		displaystr(mlTop+1, 5, 0x0b, "Give me something to crunch!!", 29);
+		displaystr(mlTop+3, 5, 0x0b, "-- Finish with enter, abort with escape --", 32);
+
+		curpos=strlen(str);
+		cmdlen=strlen(str);
+		setcurshape(1);
+
+		while (1)
+		{
+			uint16_t key;
+			displaystr(mlTop+2, 5, 0x8f, str+scrolled, plScrWidth-10);
+			setcur(mlTop+2, 5+curpos-scrolled);
+
+			while (!ekbhit())
+				framelock();
+			key=egetch();
+
+			if ((key>=0x20)&&(key<=0x7f))
+			{
+				if (insmode)
+				{
+					if ((cmdlen+1)<sizeof(str))
+					{
+						memmove(str+curpos+1, str+curpos, cmdlen-curpos+1);
+						str[curpos++]=key;
+						cmdlen++;
+					}
+				} else if (curpos==cmdlen)
+				{
+					if ((cmdlen+1)<(sizeof(str)))
+					{
+						str[curpos++]=key;
+						str[curpos]=0;
+						cmdlen++;
+					}
+				} else
+					str[curpos++]=key;
+			} else switch (key)
+			{
+			case KEY_ESC:
+				setcurshape(0);
+				return NULL;
+			case KEY_LEFT:
+				if (curpos)
+					curpos--;
+				break;
+			case KEY_RIGHT:
+				if (curpos<cmdlen)
+					curpos++;
+				break;
+			case KEY_HOME:
+				curpos=0;
+				break;
+			case KEY_END:
+				curpos=cmdlen;
+				break;
+			case KEY_INSERT:
+				{
+					insmode=!insmode;
+					setcurshape(insmode?1:2);
+				}
+				break;
+			case KEY_DELETE:
+				if (curpos!=cmdlen)
+				{
+					memmove(str+curpos, str+curpos+1, cmdlen-curpos);
+					cmdlen--;
+				}
+				break;
+			case KEY_BACKSPACE:
+				if (curpos)
+				{
+					memmove(str+curpos-1, str+curpos, cmdlen-curpos+1);
+					curpos--;
+					cmdlen--;
+				}
+				break;
+			case _KEY_ENTER:
+				strcpy(alsaCardName, str);
+				setcurshape(0);	
+				goto out;
+			}
+			while ((curpos-scrolled)>=(plScrWidth-10))
+				scrolled+=8;
+			while ((curpos-scrolled)<0)
+				scrolled-=8;
+		}
+	} else {
+		if (!(t=strchr(entry->name, ':')))
+			return NULL;
+		card=atoi(t+1);
+		if (!(t=strchr(entry->name, ',')))
+			return NULL;
+		device=atoi(t+1);
+		snprintf(alsaCardName, sizeof(alsaCardName), "plughw:%d,%d", card, device);
+		snprintf(alsaMixerName, sizeof(alsaMixerName), "hw:%d", card);
+	}
+out:
 /* #ifdef ALSA_DEBUG */
-	fprintf(stderr, "ALSA: Selected card hw:%d,%d\n", card, device);
+	fprintf(stderr, "ALSA: Selected card %s\n", alsaCardName);
 /* #endif */
-	defaultcard=card;
-	defaultdevice=device;
-	alsaOpenDevice();
+	{
+		if (customfileref!=0xffffffff)
+		{
+			struct moduleinfostruct mi;
+			mdbGetModuleInfo(&mi, customfileref);
+			snprintf(mi.modname, sizeof(mi.modname), "%s", alsaCardName);
+			mdbWriteModuleInfo(customfileref, &mi);
+		}
+
+	}
 	return NULL;
 }
 
@@ -328,6 +598,7 @@ static int list_devices_for_card(int card, struct modlist *ml, const struct dmDr
 	char *card_name;
 	int err;
 	int pcm_device=-1;
+	int cards=0;
 	snd_ctl_t *ctl;
 	snd_pcm_info_t *pcm_info;
 	
@@ -340,7 +611,7 @@ static int list_devices_for_card(int card, struct modlist *ml, const struct dmDr
 #ifdef ALSA_DEBUG
 		fprintf(stderr, "failed: %s\n", snd_strerror(-err));
 #endif
-		return -1;
+		return cards;
 	}
 #ifdef ALSA_DEBUG
 	fprintf(stderr, "ok\n");
@@ -406,8 +677,6 @@ static int list_devices_for_card(int card, struct modlist *ml, const struct dmDr
 			continue;
 		}
 
-		if ((defaultcard==card)&&(defaultdevice<0))
-			defaultdevice=pcm_device;
 #ifdef ALSA_DEBUG	
 		fprintf(stderr, "ALSA: hw:%d,%d: name %s\n", card, pcm_device, snd_pcm_info_get_name(pcm_info));
 #endif
@@ -428,7 +697,7 @@ static int list_devices_for_card(int card, struct modlist *ml, const struct dmDr
 				mdbGetModuleInfo(&mi, entry.fileref);
 				mi.flags1&=~MDB_VIRTUAL;
 				mi.channels=2;
-				snprintf(mi.modname, sizeof(mi.modname), snd_pcm_info_get_name(pcm_info));
+				snprintf(mi.modname, sizeof(mi.modname), "%s", snd_pcm_info_get_name(pcm_info));
 				mi.modtype=mtUnRead;
 				mdbWriteModuleInfo(entry.fileref, &mi);
 			}
@@ -437,18 +706,96 @@ static int list_devices_for_card(int card, struct modlist *ml, const struct dmDr
 			ml->append(ml, &entry);
 			dirdbUnref(entry.dirdbfullpath);
 		}
+		cards++;
 	}
 #ifdef ALSA_DEBUG
 	fprintf(stderr, "ALSA snd_ctl_close(ctl)\n");
 #endif
 	snd_ctl_close(ctl);
-	return 0;
+	return cards;
 }
 
-static int list_cards(struct modlist *ml, const struct dmDrive *drive, uint32_t parent, const char *mask,  unsigned long opt)
+static int list_cards(struct modlist *ml, const struct dmDrive *drive, uint32_t parent, const char *mask,  unsigned long opt, int mixercaponly)
 {
 	int card=-1;
 	int result;
+	int cards=0;
+
+	if (ml)
+	{
+		struct modlistentry entry;
+		memset(&entry, 0, sizeof(entry));
+
+		if (!mixercaponly)
+		{
+			snprintf(entry.shortname, sizeof(entry.shortname), "default.dev");
+			strcpy(entry.name, entry.shortname);
+			entry.drive=drive;
+			entry.dirdbfullpath=dirdbFindAndRef(parent, entry.name);
+			entry.flags=MODLIST_FLAG_FILE|MODLIST_FLAG_VIRTUAL;
+			entry.fileref=mdbGetModuleReference(entry.name, 0);
+			if (entry.fileref!=0xffffffff)
+			{
+				struct moduleinfostruct mi;
+				mdbGetModuleInfo(&mi, entry.fileref);
+				mi.flags1&=~MDB_VIRTUAL;
+				mi.channels=2;
+				snprintf(mi.modname, sizeof(mi.modname), "default output");
+				mi.modtype=mtUnRead;
+				mdbWriteModuleInfo(entry.fileref, &mi);
+			}
+			entry.adb_ref=0xffffffff;
+			entry.Read=0; entry.ReadHeader=0; entry.ReadHandle=alsaSelectPcmOut;
+			ml->append(ml, &entry);
+			dirdbUnref(entry.dirdbfullpath);
+		} else {
+			snprintf(entry.shortname, sizeof(entry.shortname), "none.dev");
+			strcpy(entry.name, entry.shortname);
+			entry.drive=drive;
+			entry.dirdbfullpath=dirdbFindAndRef(parent, entry.name);
+			entry.flags=MODLIST_FLAG_FILE|MODLIST_FLAG_VIRTUAL;
+			entry.fileref=mdbGetModuleReference(entry.name, 0);
+			if (entry.fileref!=0xffffffff)
+			{
+				struct moduleinfostruct mi;
+				mdbGetModuleInfo(&mi, entry.fileref);
+				mi.flags1&=~MDB_VIRTUAL;
+				mi.channels=2;
+				mi.modname[0]=0;
+				mi.modtype=mtUnRead;
+				mdbWriteModuleInfo(entry.fileref, &mi);
+			}
+			entry.adb_ref=0xffffffff;
+			entry.Read=0; entry.ReadHeader=0; entry.ReadHandle=alsaSelectMixer;
+			ml->append(ml, &entry);
+			dirdbUnref(entry.dirdbfullpath);
+
+		}
+		snprintf(entry.shortname, sizeof(entry.shortname), "custom.dev");
+		strcpy(entry.name, entry.shortname);
+		entry.drive=drive;
+		entry.dirdbfullpath=dirdbFindAndRef(parent, entry.name);
+		entry.flags=MODLIST_FLAG_FILE|MODLIST_FLAG_VIRTUAL;
+		if (mixercaponly)
+			custommixerref=entry.fileref=mdbGetModuleReference(entry.name, 0);
+		else
+			customfileref=entry.fileref=mdbGetModuleReference(entry.name, 0);
+		if (entry.fileref!=0xffffffff)
+		{
+			struct moduleinfostruct mi;
+			mdbGetModuleInfo(&mi, entry.fileref);
+			mi.flags1&=~MDB_VIRTUAL;
+			mi.channels=2;
+			snprintf(mi.modname, sizeof(mi.modname), "%s", mixercaponly?alsaMixerName:alsaCardName);
+			mi.modtype=mtUnRead;
+			mdbWriteModuleInfo(entry.fileref, &mi);
+		}
+		entry.adb_ref=0xffffffff;
+		entry.Read=0; entry.ReadHeader=0; entry.ReadHandle=mixercaponly?alsaSelectMixer:alsaSelectPcmOut;
+		ml->append(ml, &entry);
+		dirdbUnref(entry.dirdbfullpath);
+
+	}
 
 #ifdef ALSA_DEBUG
 	fprintf(stderr, "ALSA snd_card_next(&card (%i)) = ", card);
@@ -458,31 +805,69 @@ static int list_cards(struct modlist *ml, const struct dmDrive *drive, uint32_t
 #ifdef ALSA_DEBUG
                 fprintf(stderr, "failed: %s\n", snd_strerror(-result));
 #endif
-                return -1;
+                return cards;
         }
 #ifdef ALSA_DEBUG
 	fprintf(stderr, "ok\n");
 #endif
-	defaultcard=card;
-	defaultdevice=-1;
         while (card>-1)
         {
-                list_devices_for_card(card, ml, drive, parent, mask, opt);
+
+		if (mixercaponly)
+		{
+			if (ml)
+			{
+				struct modlistentry entry;
+				memset(&entry, 0, sizeof(entry));
+				char *card_name;
+				int err;
+
+				if ((err=snd_card_get_name(card, &card_name))!=0)
+				{
 #ifdef ALSA_DEBUG
-	fprintf(stderr, "ALSA snd_card_next(&card (%i)) = ", card);
+					fprintf(stderr, "failed: %s\n", snd_strerror(-err));
+#endif
+					card_name="Unknown card";
+				}
+
+				snprintf(entry.shortname, sizeof(entry.shortname), "hw:%d.dev", card);
+				strcpy(entry.name, entry.shortname);
+				entry.drive=drive;
+				entry.dirdbfullpath=dirdbFindAndRef(parent, entry.name);
+				entry.flags=MODLIST_FLAG_FILE|MODLIST_FLAG_VIRTUAL;
+				entry.fileref=mdbGetModuleReference(entry.name, 0);
+				if (entry.fileref!=0xffffffff)
+				{
+					struct moduleinfostruct mi;
+					mdbGetModuleInfo(&mi, entry.fileref);
+					mi.flags1&=~MDB_VIRTUAL;
+					mi.channels=2;
+					snprintf(mi.modname, sizeof(mi.modname), "%s", card_name);
+					mi.modtype=mtUnRead;
+					mdbWriteModuleInfo(entry.fileref, &mi);
+				}
+				entry.adb_ref=0xffffffff;
+				entry.Read=0; entry.ReadHeader=0; entry.ReadHandle=alsaSelectMixer;
+				ml->append(ml, &entry);
+				dirdbUnref(entry.dirdbfullpath);
+			}
+		} else
+			cards+=list_devices_for_card(card, ml, drive, parent, mask, opt);
+#ifdef ALSA_DEBUG
+		fprintf(stderr, "ALSA snd_card_next(&card (%i)) = ", card);
 #endif	
                 if ((result=snd_card_next(&card)))
                 {
 #ifdef ALSA_DEBUG
 	                fprintf(stderr, "failed: %s\n", snd_strerror(-result));
 #endif
-			return -1;
+			return cards;
 		}
 #ifdef ALSA_DEBUG
 		fprintf(stderr, "ok\n");
 #endif
 	}
-	return 0;		
+	return cards;		
 }
 
 /* plr API start */
@@ -766,7 +1151,6 @@ static void alsaStop(void)
 static void alsaOpenDevice(void)
 {
 	int err;
-	char device[64];
 	snd_mixer_elem_t *current;
 
 	alsa_mixers_n=0;
@@ -809,16 +1193,15 @@ static void alsaOpenDevice(void)
 		mixer=NULL;
 	}
 
-	snprintf(device, sizeof(device), "plughw:%d,%d", defaultcard, defaultdevice);
 #ifdef ALSA_DEBUG
-	fprintf(stderr, "ALSA snd_pcm_open(&alsa_pcm, device = \"%s\", SND_PCM_STREAM_PLAYBACK, SND_PCM_NONBLOCK) = ", device);
+	fprintf(stderr, "ALSA snd_pcm_open(&alsa_pcm, device = \"%s\", SND_PCM_STREAM_PLAYBACK, SND_PCM_NONBLOCK) = ", alsaCardName);
 #endif
-	if ((err=snd_pcm_open(&alsa_pcm, device, SND_PCM_STREAM_PLAYBACK, SND_PCM_NONBLOCK))<0)
+	if ((err=snd_pcm_open(&alsa_pcm, alsaCardName, SND_PCM_STREAM_PLAYBACK, SND_PCM_NONBLOCK))<0)
 	{
 #ifdef ALSA_DEBUG
 		fprintf(stderr, "failed: %s\n", snd_strerror(-err));
 #endif
-		fprintf(stderr, "ALSA: failed to open pcm device (%s): %s\n", device, snd_strerror(-err));
+		fprintf(stderr, "ALSA: failed to open pcm device (%s): %s\n", alsaCardName, snd_strerror(-err));
 		alsa_pcm=NULL;
 		return;
 	}
@@ -826,7 +1209,9 @@ static void alsaOpenDevice(void)
 	fprintf(stderr, "ok\n");
 #endif
 
-	snprintf(device, sizeof(device), "hw:%d", defaultcard);
+	if (!strlen(alsaMixerName))
+		return;
+
 #ifdef ALSA_DEBUG
 	fprintf(stderr, "ALSA snd_mixer_open(&mixer, 0) = ");
 #endif
@@ -842,7 +1227,7 @@ static void alsaOpenDevice(void)
 	fprintf(stderr, "ok\n");
 	fprintf(stderr, "ALSA snd_mixer_attach(mixer, device = \"%s\") = ", device);
 #endif
-	if ((err=snd_mixer_attach(mixer, device))<0)
+	if ((err=snd_mixer_attach(mixer, alsaMixerName))<0)
 	{
 #ifdef ALSA_DEBUG
 		fprintf(stderr, "failed: %s\n", snd_strerror(-err));
@@ -991,10 +1376,12 @@ static int alsaInit(const struct deviceinfo *c)
 
 static int alsaDetect(struct deviceinfo *card)
 {
-	list_cards(NULL, NULL, DIRDB_NOPARENT, NULL, 0);
+	int cards = list_cards(NULL, NULL, DIRDB_NOPARENT, NULL, 0, 0);
 	card->dev=&plrAlsa;
-	card->port=defaultcard;
-	card->port2=defaultdevice;
+	snprintf(card->path, sizeof(card->path), "%s", cfGetProfileString("devpALSA", "path", "default"));
+	snprintf(alsaCardName, sizeof(alsaCardName), "%s", card->path);
+	snprintf(card->mixer, sizeof(card->mixer), "%s", cfGetProfileString("devpALSA", "mixer", "hw:0"));
+	snprintf(alsaMixerName, sizeof(alsaMixerName), "%s", card->mixer);
 /*	card->irq=-1;
 	card->irq2=-1;
 	card->dma=-1;
@@ -1003,7 +1390,7 @@ static int alsaDetect(struct deviceinfo *card)
 	card->mem=0;
 	card->chan=2;
 
-	return defaultdevice!=-1;
+	return cards>0;
 }
 
 static void alsaClose(void)
@@ -1017,7 +1404,6 @@ static int alsaReadDir(struct modlist *ml, const struct dmDrive *drive, const ui
 {
 	struct modlistentry entry;
 	uint32_t dmalsa;
-	uint32_t dmpcmout;
 
 	if (drive!=dmSETUP)
 		return 1;
@@ -1038,7 +1424,9 @@ static int alsaReadDir(struct modlist *ml, const struct dmDrive *drive, const ui
 		entry.Read=0; entry.ReadHeader=0; entry.ReadHandle=0;
 		ml->append(ml, &entry);
 	} else {
+		uint32_t dmpcmout,dmmixer;
 		dmpcmout=dirdbFindAndRef(dmalsa, "PCM.OUT");
+		dmmixer=dirdbFindAndRef(dmalsa, "MIXER");
 		if (path==dmalsa)
 		{
 			strcpy(entry.shortname, "PCM.OUT");
@@ -1050,9 +1438,23 @@ static int alsaReadDir(struct modlist *ml, const struct dmDrive *drive, const ui
 			entry.adb_ref=0xffffffff;
 			entry.Read=0; entry.ReadHeader=0; entry.ReadHandle=0;
 			ml->append(ml, &entry);
+
+			strcpy(entry.shortname, "MIXER");
+			strcpy(entry.name, "MIXER");
+			entry.drive=drive;
+			entry.dirdbfullpath=dmmixer;
+			entry.flags=MODLIST_FLAG_DIR;
+			entry.fileref=0xffffffff;
+			entry.adb_ref=0xffffffff;
+			entry.Read=0; entry.ReadHeader=0; entry.ReadHandle=0;
+			ml->append(ml, &entry);
+
 		} else if (path==dmpcmout)
-			list_cards(ml, drive, path, mask, opt);
+			list_cards(ml, drive, path, mask, opt, 0);
+		else if (path==dmmixer)
+			list_cards(ml, drive, path, mask, opt, 1);
 		dirdbUnref(dmpcmout);
+		dirdbUnref(dmmixer);
 	}
 	dirdbUnref(dmalsa);
 	return 1;
