@@ -31,7 +31,7 @@
 
 extern struct sounddevice plrDiskWriter;
 
-static long filepos;
+static uint32_t filepos;
 static unsigned long buflen;
 static char *playbuf;
 static unsigned long bufpos;
@@ -108,7 +108,7 @@ static void advance(int pos)
 	busy=0;
 }
 
-static long gettimer(void)
+static uint32_t gettimer(void)
 {
 	return imuldiv((filepos+cachepos), (65536>>(stereo+bit16)), playrate);
 }
@@ -147,6 +147,8 @@ static int dwPlay(void **buf, int *len)
 	int i;
 	unsigned char hdr[0x2C];
 
+	memset(&hdr, 0, sizeof(hdr));
+
 	if (*len>32704)
 		*len=32704;
 	*buf=playbuf=malloc(*len);
