@@ -21,6 +21,9 @@
 #include "stuff/timer.h"
 #include "stuff/imsrtns.h"
 
+static uint32_t starttime;
+static uint32_t starttime2;
+static uint32_t wrap;
 
 static void short_circuit(void)
 {
@@ -33,16 +36,23 @@ extern struct sounddevice plrNone;
 
 static int getpos(void)
 {
-	return imuldiv(tmGetTimer(), bufrate, 65536)%buflen;
+	/* this makes starttime always be a safe low value */
+	uint32_t now = tmGetTimer();
+
+	if ((now-starttime)>wrap)
+		starttime+=wrap;
+	now-=starttime;
+
+	return imuldiv(now, bufrate, 65536)%buflen;
 }
 
 static void advance(int i)
 {
 }
 
-static long gettimer(void)
+static uint32_t gettimer(void)
 {
-	return tmGetTimer()-imuldiv(buflen, 65536, bufrate);
+	return tmGetTimer()-starttime2;
 }
 
 static void qpSetOptions(uint32_t rate, int opt)
@@ -78,6 +88,10 @@ static int qpPlay(void **buf, int *len)
 	plrAdvanceTo=advance;
 	plrGetTimer=gettimer;
 
+	starttime = starttime2 = tmGetTimer();
+
+	wrap = buflen * bufrate;
+
 	tmInit(short_circuit, plrRate);
 
 	return 1;
