@@ -61,7 +61,7 @@ volatile static int cachelen, kernlen; /* to make life easier */
  *  on getplaypos we use last known kernpos if locked, else update kernpos
  */
 
-volatile static long playpos; /* how many samples have we done totally */
+volatile static uint32_t playpos; /* how many samples have we done totally */
 static int stereo;
 static int bit16;
 
@@ -320,7 +320,7 @@ static void advance(int pos)
 	busy--;
 }
 
-static long gettimer(void)
+static uint32_t gettimer(void)
 {
 	long tmp=playpos;
 	int odelay;
