@@ -79,8 +79,8 @@ static int     channelnum;
 static struct channel *channels;
 static float   fadedown[2];
 
-static int     bufpos;
-static size_t  buflen;
+static int      bufpos;
+static uint32_t buflen;
 
 static void (*playerproc)(void);
 
@@ -322,8 +322,6 @@ static void mixmain(/*int min*/)
 	{
 		int pass2=((bufpos+bufdeltatot)>buflen)?(bufpos+bufdeltatot-buflen):0;
 
-		fprintf(stderr, "(bit16=%d pass2=%d\n", bit16, pass2);
-
 		if (bit16)
 		{
 			memsetw((int16_t *)plrbuf+(bufpos<<stereo), signedout?0:0x8000, (bufdeltatot-pass2)<<stereo);
@@ -1043,7 +1041,6 @@ static int Detect(struct deviceinfo *c)
 #include "dev/devigen.h"
 #include "boot/psetting.h"
 #include "dev/deviplay.h"
-#include "boot/pmain.h"
 #include "boot/plinkman.h"
 
 static struct mixfpostprocaddregstruct *postprocadds;
