@@ -173,7 +173,6 @@ void mixer (void)
 		"  decl %%ecx\n"
 
 	"  mixer_MixNext:\n"
-
 		"    movl voiceflags(,%%ecx,4), %%eax\n"
 		"    testl %0, %%eax\n"
 		"    jz mixer_SkipVoice\n"
@@ -387,20 +386,32 @@ static __attribute__ ((used)) void dummy(void)
 	 */
 		"movl nsamples, %%ecx\n"
 		"shrl $2, %%ebp\n"
+#if 1
+		"pushl %%ebp\n"
+#else
 		"movl %%ebp, 2+mix_0_SM1\n" /* nasty self-modifying code. Kids, don't do this at home */
+#endif
 		"movl %%eax, %%ebp\n"
 		"shrl $2, %%ebp\n"
 	"mix_0_next:\n"
 		"  addl %%esi, %%edx\n"
 		"  adcl %%ebx, %%ebp\n"
+	"mix_0_looped:\n"
+#if 1
+		"  cmpl (%%esp), %%ebp\n"
+#else
 	"mix_0_SM1:\n"
 		"  cmpl $12345678, %%ebp\n"
-		"  jge mix_0_LoopHandler\n"
+#endif
+		"  jae mix_0_LoopHandler\n"
 		"  decl %%ecx\n"
 		"jnz mix_0_next\n"
 	"mix_0_ende:\n"
 		"shll $2, %%ebp\n"
 		"movl %%ebp, %%eax\n"
+#if 1
+		"popl %%ecx\n" /* just a garbage register */
+#endif
 		"ret\n"
 	"mix_0_LoopHandler:\n"
 		"movl looptype, %%eax\n"
@@ -412,9 +423,7 @@ static __attribute__ ((used)) void dummy(void)
 		"jmp mix_0_ende\n"
 	"mix_0_loopme:\n"
 		"subl mixlooplen, %%ebp\n"
-		"decl %%ecx\n"
-		"jz mix_0_ende\n"
-		"jmp mix_0_next\n"
+		"jmp mix_0_looped\n"
 		:
 		: "n"(MIXF_LOOPED),
 		  "n"(FLAG_DISABLED)
@@ -428,7 +437,11 @@ static __attribute__ ((used)) void dummy(void)
 		"movl nsamples, %%ecx\n"
 		"flds voll\n"                /* (vl) */
 		"shrl $2, %%ebp\n"
+#if 1
+		"pushl %%ebp\n"
+#else
 		"movl %%ebp, mixm_n_SM1+2\n" /* self modifying code.  set loop end position */
+#endif
 		"movl %%eax, %%ebp\n"
 		"shrl $2, %%ebp\n"
 	/* align dword we don't need.. alignment is 32bit by default on gnu i386*/
@@ -443,9 +456,14 @@ static __attribute__ ((used)) void dummy(void)
 		"  fadds volrl\n"            /* (vl') (left) */
 		"  fxch %%st(1)\n"           /* (left) (vl) */
 		"  fadds -4(%%edi)\n"        /* (lfinal) (vl') */
+	"mixm_n_looped:\n"
+#if 1
+		"  cmpl (%%esp), %%ebp\n"
+#else
 	"mixm_n_SM1:\n"
 		"  cmpl $12345678, %%ebp\n"
-		"  jge mixm_n_LoopHandler\n"
+#endif
+		"  jae mixm_n_LoopHandler\n"
 		"  fstps -4(%%edi)\n"        /* (vl') (-1) */
 		"  decl %%ecx\n"
 		"jnz mixm_n_next\n"
@@ -453,6 +471,9 @@ static __attribute__ ((used)) void dummy(void)
 		"fstps voll\n"               /* - */
 		"shll $2, %%ebp\n"
 		"movl %%ebp, %%eax\n"
+#if 1
+		"popl %%ecx\n" /* just a garbage register */
+#endif
 		"ret\n"
 
 	"mixm_n_LoopHandler:\n"
@@ -485,6 +506,8 @@ static __attribute__ ((used)) void dummy(void)
 
 	"mixm_n_loopme:\n" /* sample loops -> jump to loop start */
 		"subl mixlooplen, %%ebp\n"
+		"  cmpl (%%esp), %%ebp\n"
+		"jae mixm_n_loopme\n"
 		"decl %%ecx\n"
 		"jz mixm_n_ende\n"
 		"jmp mixm_n_next\n"
@@ -502,7 +525,11 @@ static __attribute__ ((used)) void dummy(void)
 		"flds voll\n"                /* (vl) */
 		"flds volr\n"                /* (vr) (vl) */
 		"shrl $2, %%ebp\n"
+#if 1
+		"pushl %%ebp\n"
+#else
 		"movl %%ebp,2+mixs_n_SM1\n"  /* self modifying code. set loop end position */
+#endif
 		"movl %%eax, %%ebp\n"
 		"shrl $2, %%ebp\n"
 	/* align dword.... we are already align 32bit */
@@ -524,9 +551,14 @@ static __attribute__ ((used)) void dummy(void)
 		"  fadds -8(%%edi)\n"        /* (lfinal) (vl') <right> (vr') */
 		"  fxch %%st(2)\n"           /* (right) (vl') (lfinal) (vr') */
 		"  fadds -4(%%edi)\n"        /* (rfinal) (vl') (lfinal) (vr') */
+	"mixs_n_looped:\n"
+#if 1
+		"  cmpl (%%esp), %%ebp\n"
+#else
 	"mixs_n_SM1:\n"
 		"  cmpl $12345678, %%ebp\n"
-		"  jge mixs_n_LoopHandler\n"
+#endif
+		"  jae mixs_n_LoopHandler\n"
 	/* hier 1 cycle frei */
 		"  fstps -4(%%edi)\n"        /* (vl') (lfinal) (vr') */
 		"  fxch %%st(1)\n"           /* (lfinal) (vl) (vr) */
@@ -539,6 +571,9 @@ static __attribute__ ((used)) void dummy(void)
 		"fstps voll\n"               /* - */
 		"shll $2, %%ebp\n"
 		"movl %%ebp, %%eax\n"
+#if 1
+		"popl %%ecx\n" /* just a garbage register */
+#endif
 		"ret\n"
 
 	"mixs_n_LoopHandler:\n"
@@ -595,6 +630,8 @@ static __attribute__ ((used)) void dummy(void)
 	"mixs_n_loopme:\n"
 	/* sample loops -> jump to loop start */
 		"subl mixlooplen, %%ebp\n"
+		"  cmpl (%%esp), %%ebp\n"
+		"jae mixs_n_loopme\n"
 		"decl %%ecx\n"
 		"jz mixs_n_ende\n"
 		"jmp mixs_n_next\n"
@@ -611,7 +648,11 @@ static __attribute__ ((used)) void dummy(void)
 		"flds minuseins\n"           /* (-1) */
 		"flds voll\n"                /* (vl) (-1) */
 		"shrl $2, %%ebp\n"
+#if 1
+		"pushl %%ebp\n"
+#else
 		"movl %%ebp, mixm_i_SM1+2\n" /* self modifying code. set loop end position */
+#endif
 		"movl %%eax, %%ebp\n"
 		"movl %%edx, %%eax\n"
 		"shrl $9, %%eax\n"
@@ -641,10 +682,15 @@ static __attribute__ ((used)) void dummy(void)
 		"  fxch %%st(1)\n"           /* (left) (vl) (-1) */
 		"  fadds -4(%%edi)\n"        /* (lfinal) (vl') (-1) */
 		"  orl $0x3f800000, %%eax\n"
+	"mixm_i_looped:\n"
+#if 1
+		"  cmpl (%%esp), %%ebp\n"
+#else
 	"mixm_i_SM1:\n"
 		"  cmpl $12345678, %%ebp\n"
+#endif
 		"  movl %%eax, magic1\n"
-		"  jge mixm_i_LoopHandler\n"
+		"  jae mixm_i_LoopHandler\n"
 	/* hier 1 cycle frei */
 		"  fstps -4(%%edi)\n"        /* (vl') (-1) */
 		"  decl %%ecx\n"
@@ -654,6 +700,9 @@ static __attribute__ ((used)) void dummy(void)
 		"fstp %%st\n"                /* - */
 		"shll $2, %%ebp\n"
 		"movl %%ebp, %%eax\n"
+#if 1
+		"popl %%ecx\n" /* just a garbage register */
+#endif
 		"ret\n"
 
 	"mixm_i_LoopHandler:\n"
@@ -687,6 +736,8 @@ static __attribute__ ((used)) void dummy(void)
 	"mixm_i_loopme:\n"
 	/* sample loops -> jump to loop start */
 		"subl mixlooplen, %%ebp\n"
+		"  cmpl (%%esp), %%ebp\n"
+		"jae mixm_i_loopme\n"
 		"decl %%ecx\n"
 		"jz mixm_i_ende\n"
 		"jmp mixm_i_next\n"
@@ -704,7 +755,11 @@ static __attribute__ ((used)) void dummy(void)
 		"flds voll\n"                /* (vl) (-1) */
 		"flds volr\n"                /* (vr) (vl) (-1) */
 		"shrl $2, %%ebp\n"
+#if 1
+		"pushl %%ebp\n"
+#else
 		"movl %%ebp, 2+mixs_i_SM1\n" /* self modifying code. set loop end position */
+#endif
 		"movl %%eax, %%ebp\n"
 		"movl %%edx, %%eax\n"
 		"shrl $9, %%eax\n"
@@ -741,10 +796,15 @@ static __attribute__ ((used)) void dummy(void)
 		"  fxch %%st(2)\n"           /* (right) (vl') (lfinal) (vr') (-1) */
 		"  fadds -4(%%edi)\n"        /* (rfinal) (vl') (lfinal) (vr') (-1) */
 		"  orl $0x3f800000, %%eax\n"
+	"mixs_i_looped:\n"
+#if 1
+		"  cmpl (%%esp), %%ebp\n"
+#else
 	"mixs_i_SM1:\n"
 		"  cmpl $12345678, %%ebp\n"
+#endif
 		"  movl %%eax, magic1\n"
-		"  jge mixs_i_LoopHandler\n"
+		"  jae mixs_i_LoopHandler\n"
 	/* hier 1 cycle frei */
 		"  fstps -4(%%edi)\n"        /* (vl') (lfinal) <vr'> (-1) */
 		"  fxch %%st(1)\n"           /* (lfinal) (vl) (vr) (-1) */
@@ -758,6 +818,9 @@ static __attribute__ ((used)) void dummy(void)
 		"fstp %%st\n"
 		"shll $2, %%ebp\n"
 		"movl %%ebp, %%eax\n"
+#if 1
+		"popl %%ecx\n" /* just a garbage register */
+#endif
 		"ret\n"
 
 	"mixs_i_LoopHandler:\n"
@@ -815,6 +878,8 @@ static __attribute__ ((used)) void dummy(void)
 	"mixs_i_loopme:\n"
 	/* sample loops -> jump to loop start */
 		"subl mixlooplen, %%ebp\n"
+		"  cmpl (%%esp), %%ebp\n"
+		"jae mixs_i_loopme\n"
 		"decl %%ecx\n"
 		"jz mixs_i_ende\n"
 		"jmp mixs_i_next\n"
@@ -830,7 +895,11 @@ static __attribute__ ((used)) void dummy(void)
 		"movl nsamples, %%ecx\n"
 		"flds voll\n"                /* (vl) */
 		"shrl $2, %%ebp\n"
+#if 1
+		"pushl %%ebp\n"
+#else
 		"movl %%ebp, mixm_i2_SM1\n" /* self modifying code. set loop end position */
+#endif
 		"movl %%eax, %%ebp\n"
 		"shrl $2, %%ebp\n"
 		"movl %%edx, %%eax\n"
@@ -860,9 +929,14 @@ static __attribute__ ((used)) void dummy(void)
 		"  fadds volrl\n"            /* (vl') (left) */
 		"  fxch %%st(1)\n"           /* (left) (vl) */
 		"  fadds -4(%%edi)\n"        /* (lfinal) (vl') */
+	"mixm_i2_looped:\n"
+#if 1
+		"  cmpl (%%esp), %%ebp\n"
+#else
 	"mixm_i2_SM1:\n"
 		"  cmpl $12345678, %%ebp\n"
-		"  jge mixm_i2_LoopHandler\n"
+#endif
+		"  jae mixm_i2_LoopHandler\n"
 		"  fstps -4(%%edi)\n"        /* (vl') */
 		"  decl %%ecx\n"
 		"jnz mixm_i2_next\n"
@@ -870,6 +944,9 @@ static __attribute__ ((used)) void dummy(void)
 		"fstps voll\n"               /* - */
 		"shll $2, %%ebp\n"
 		"movl %%ebp, %%eax\n"
+#if 1
+		"popl %%ecx\n" /* just a garbage register */
+#endif
 		"ret\n"
 
 	"mixm_i2_LoopHandler:\n"
@@ -906,10 +983,14 @@ static __attribute__ ((used)) void dummy(void)
 	"mixm_i2_loopme:\n"
 	/* sample loops -> jump to loop start */
 		"popl %%eax\n"
+	"mixm_i2_loopme2:\n"
 		"subl mixlooplen, %%ebp\n"
+		"  cmpl (%%esp), %%ebp\n"
+		"jae mixm_i2_loopme2\n"
 		"decl %%ecx\n"
 		"jz mixm_i2_ende\n"
 		"jmp mixm_i2_next\n"
+
 		:
 		: "n"(MIXF_LOOPED),
 		  "n"(FLAG_DISABLED)
@@ -923,7 +1004,11 @@ static __attribute__ ((used)) void dummy(void)
 		"flds voll\n"                /* (vl) */
 		"flds volr\n"                /* (vr) (vl) */
 		"shrl $2, %%ebp\n"
+#if 1
+		"pushl %%ebp\n"
+#else
 		"movl %%ebp, mixs_i2_SM1+2\n"/* self modifying code. set loop end position */
+#endif
 		"movl %%eax, %%ebp\n"
 		"shrl $2, %%ebp\n"
 		"movl %%edx, %%eax\n"
@@ -960,9 +1045,14 @@ static __attribute__ ((used)) void dummy(void)
 		"  fadds -8(%%edi)\n"        /* (lfinal) (vl') <right> (vr') */
 		"  fxch %%st(2)\n"           /* (right) (vl') (lfinal) (vr') */
 		"  fadds -4(%%edi)\n"        /* (rfinal) (vl') (lfinal) (vr') */
+	"mixs_i2_looped:\n"
+#if 1
+		"  cmpl (%%esp), %%ebp\n"
+#else
 	"mixs_i2_SM1:\n"
 		"  cmpl $12345678, %%ebp\n"
-		"  jge mixs_i2_LoopHandler\n"
+#endif
+		"  jae mixs_i2_LoopHandler\n"
 	/* hier 1 cycle frei */
 		"  fstps -4(%%edi)\n"        /* (vl') (lfinal) (vr') */
 		"  fxch %%st(1)\n"           /* (lfinal) (vl) (vr)  */
@@ -975,6 +1065,9 @@ static __attribute__ ((used)) void dummy(void)
 		"fstps voll\n"               /* - */
 		"shll $2, %%ebp\n"
 		"movl %%ebp, %%eax\n"
+#if 1
+		"popl %%ecx\n" /* just a garbage register */
+#endif
 		"ret\n"
 
 	"mixs_i2_LoopHandler:\n"
@@ -1034,7 +1127,10 @@ static __attribute__ ((used)) void dummy(void)
 	"mixs_i2_loopme:\n"
 	/* sample loops -> jump to loop start */
 		"popl %%eax\n"
+	"mixs_i2_loopme2:\n"
 		"subl mixlooplen, %%ebp\n"
+		"  cmpl (%%esp), %%ebp\n"
+		"jae mixs_i2_loopme2\n"
 		"decl %%ecx\n"
 		"jz mixs_i2_ende\n"
 		"jmp mixs_i2_next\n"
@@ -1050,7 +1146,11 @@ static __attribute__ ((used)) void dummy(void)
 		"movl nsamples, %%ecx\n"
 		"flds voll\n"                /* (vl) */
 		"shrl $2, %%ebp\n"
+#if 1
+		"pushl %%ebp\n"
+#else
 		"movl %%ebp, mixm_nf_SM1+2\n" /* self modifying code. set loop end position */
+#endif
 		"movl %%eax, %%ebp\n"
 		"shrl $2, %%ebp\n"
 		/* align dword sucks */
@@ -1080,9 +1180,14 @@ static __attribute__ ((used)) void dummy(void)
 		"  fadds volrl\n"            /* (vl') (left) */
 		"  fxch %%st(1)\n"           /* (left) (vl) */
 		"  fadds -4(%%edi)\n"        /* (lfinal) (vl') */
+	"mixm_nf_looped:\n"
+#if 1
+		"  cmpl (%%esp), %%ebp\n"
+#else
 	"mixm_nf_SM1:\n"
 		"  cmpl $12345678, %%ebp\n"
-		"  jge mixm_nf_LoopHandler\n"
+#endif
+		"  jae mixm_nf_LoopHandler\n"
 		"  fstps -4(%%edi)\n"        /* (vl') */
 		"  decl %%ecx\n"
 		"jnz mixm_nf_next\n"
@@ -1090,6 +1195,9 @@ static __attribute__ ((used)) void dummy(void)
 		"fstps voll\n"               /* - */
 		"shll $2, %%ebp\n"
 		"movl %%ebp, %%eax\n"
+#if 1
+		"popl %%ecx\n" /* just a garbage register */
+#endif
 		"ret\n"
 
 	"mixm_nf_LoopHandler:\n"
@@ -1124,6 +1232,8 @@ static __attribute__ ((used)) void dummy(void)
 	"mixm_nf_loopme:\n"
 	/* sample loops -> jump to loop start */
 		"subl mixlooplen, %%ebp\n"
+		"  cmpl (%%esp), %%ebp\n"
+		"jae mixm_nf_loopme\n"
 		"decl %%ecx\n"
 		"jz mixm_nf_ende\n"
 		"jmp mixm_nf_next\n"
@@ -1140,7 +1250,11 @@ static __attribute__ ((used)) void dummy(void)
 		"flds voll\n"                /* (vl) */
 		"flds volr\n"                /* (vr) (vl) */
 		"shrl $2, %%ebp\n"
+#if 1
+		"pushl %%ebp\n"
+#else
 		"movl %%ebp, mixs_nf_SM1+2\n" /* self modifying code. set loop end position */
+#endif
 		"movl %%eax, %%ebp\n"
 		"shrl $2, %%ebp\n"
 	/* align dword is for clows */
@@ -1177,9 +1291,14 @@ static __attribute__ ((used)) void dummy(void)
 		"  fadds -8(%%edi)\n"        /* (lfinal) (vl') <right> (vr') */
 		"  fxch %%st(2)\n"           /* (right) (vl') (lfinal) (vr') */
 		"  fadds -4(%%edi)\n"        /* (rfinal) (vl') (lfinal) (vr') */
+	"mixs_nf_looped:\n"
+#if 1
+		"  cmpl (%%esp), %%ebp\n"
+#else
 	"mixs_nf_SM1:\n"
 		"  cmpl $12345678, %%ebp\n"
-		"  jge mixs_nf_LoopHandler\n"
+#endif
+		"  jae mixs_nf_LoopHandler\n"
        /* hier 1 cycle frei */
 		"  fstps -4(%%edi)\n"        /* (vl') (lfinal) (vr') */
 		"  fxch %%st(1)\n"           /* (lfinal) (vl) (vr) */
@@ -1192,6 +1311,9 @@ static __attribute__ ((used)) void dummy(void)
 		"fstps voll\n"               /* - */
 		"shll $2, %%ebp\n"
 		"movl %%ebp, %%eax\n"
+#if 1
+		"popl %%ecx\n" /* just a garbage register */
+#endif
 		"ret\n"
 
 	"mixs_nf_LoopHandler:\n"
@@ -1249,6 +1371,8 @@ static __attribute__ ((used)) void dummy(void)
 	"mixs_nf_loopme:\n"
 	/* sample loops -> jump to loop start */
 		"subl mixlooplen, %%ebp\n"
+		"  cmpl (%%esp), %%ebp\n"
+		"jae mixs_nf_loopme\n"
 		"decl %%ecx\n"
 		"jz mixs_nf_ende\n"
 		"jmp mixs_nf_next\n"
@@ -1265,7 +1389,11 @@ static __attribute__ ((used)) void dummy(void)
 		"flds minuseins\n"           /* (-1) */
 		"flds voll\n"                /* (vl) (-1) */
 		"shrl $2, %%ebp\n"
+#if 1
+		"pushl %%ebp\n"
+#else
 		"movl %%ebp, mixm_if_SM1+2\n" /* self modifying code. set loop end position */
+#endif
 		"movl %%eax, %%ebp\n"
 		"movl %%edx, %%eax\n"
 		"shrl $9, %%eax\n"
@@ -1310,10 +1438,15 @@ static __attribute__ ((used)) void dummy(void)
 		"  fxch %%st(1)\n"           /* (left) (vl) (-1) */
 		"  fadds -4(%%edi)\n"        /* (lfinal) (vl') (-1) */
 		"  orl $0x3f800000, %%eax\n"
+	"mixm_if_looped:\n"
+#if 1
+		"  cmpl (%%esp), %%ebp\n"
+#else
 	"mixm_if_SM1:\n"
 		"  cmpl $12345678, %%ebp\n"
+#endif
 		"  movl %%eax, magic1\n"
-		"  jge mixm_if_LoopHandler\n"
+		"  jae mixm_if_LoopHandler\n"
 	/* hier 1 cycle frei */
 		"  fstps -4(%%edi)\n"        /* (vl') (-1) */
 		"  decl %%ecx\n"
@@ -1323,6 +1456,9 @@ static __attribute__ ((used)) void dummy(void)
 		"fstp %%st\n"                /* - */
 		"shll $2, %%ebp\n"
 		"movl %%ebp, %%eax\n"
+#if 1
+		"popl %%ecx\n" /* just a garbage register */
+#endif
 		"ret\n"
 
 	"mixm_if_LoopHandler:\n"
@@ -1357,6 +1493,8 @@ static __attribute__ ((used)) void dummy(void)
 	"mixm_if_loopme:\n"
 	/* sample loops -> jump to loop start */
 		"subl mixlooplen, %%ebp\n"
+		"  cmpl (%%esp), %%ebp\n"
+		"jae mixm_if_loopme\n"
 		"decl %%ecx\n"
 		"jz mixm_if_ende\n"
 		"jmp mixm_if_next\n"
@@ -1374,7 +1512,11 @@ static __attribute__ ((used)) void dummy(void)
 		"flds voll\n"                /* (vl) (-1) */
 		"flds volr\n"                /* (vr) (vl) (-1) */
 		"shrl $2, %%ebp\n"
+#if 1
+		"pushl %%ebp\n"
+#else
 		"movl %%ebp, mixs_if_SM1+2\n" /* self modifying code. set loop end position */
+#endif
 		"movl %%eax, %%ebp\n"
 		"movl %%edx, %%eax\n"
 		"shrl $9, %%eax\n"
@@ -1426,10 +1568,15 @@ static __attribute__ ((used)) void dummy(void)
 		"  fxch %%st(2)\n"           /* (right) (vl') (lfinal) (vr') (-1) */
 		"  fadds -4(%%edi)\n"        /* (rfinal) (vl') (lfinal) (vr') (-1) */
 		"  orl $0x3f800000, %%eax\n"
+	"mixs_if_looped:\n"
+#if 1
+		"  cmpl (%%esp), %%ebp\n"
+#else
 	"mixs_if_SM1:\n"
 		"  cmpl $12345678, %%ebp\n"
+#endif
 		"  movl %%eax, magic1\n"
-		"  jge mixs_if_LoopHandler;\n"
+		"  jae mixs_if_LoopHandler;\n"
 	/* hier 1 cycle frei */
 		"  fstps -4(%%edi)\n"        /* (vl') (lfinal) <vr'> (-1) */
 		"  fxch %%st(1)\n"           /* (lfinal) (vl) (vr) (-1) */
@@ -1443,6 +1590,9 @@ static __attribute__ ((used)) void dummy(void)
 		"fstp %%st\n"
 		"shll $2, %%ebp\n"
 		"movl %%ebp, %%eax\n"
+#if 1
+		"popl %%ecx\n" /* just a garbage register */
+#endif
 		"ret\n"
 
 	"mixs_if_LoopHandler:\n"
@@ -1500,6 +1650,8 @@ static __attribute__ ((used)) void dummy(void)
 	"mixs_if_loopme:\n"
 	/* sample loops -> jump to loop start */
 		"subl mixlooplen, %%ebp\n"
+		"  cmpl (%%esp), %%ebp\n"
+		"jae mixs_if_loopme\n"
 		"decl %%ecx\n"
 		"jz mixs_if_ende\n"
 		"jmp mixs_if_next\n"
@@ -1515,7 +1667,11 @@ static __attribute__ ((used)) void dummy(void)
 		"movl nsamples, %%ecx\n"
 		"flds voll\n"                /* (vl) */
 		"shrl $2, %%ebp\n"
+#if 1
+		"pushl %%ebp\n"
+#else
 		"movl %%ebp, mixm_i2f_SM1+2\n" /* self modifying code. set loop end position */
+#endif
 		"movl %%eax, %%ebp\n"
 		"shrl $2, %%ebp\n"
 		"movl %%edx, %%eax\n"
@@ -1560,9 +1716,14 @@ static __attribute__ ((used)) void dummy(void)
 		"  fadds volrl\n"            /* (vl') (left) */
 		"  fxch %%st(1)\n"           /* (left) (vl) */
 		"  fadds -4(%%edi)\n"        /* (lfinal) (vl') */
+	"mixm_i2f_looped:\n"
+#if 1
+		"  cmpl (%%esp), %%ebp\n"
+#else
 	"mixm_i2f_SM1:\n"
 		"  cmpl $12345678, %%ebp\n"
-		"  jge mixm_i2f_LoopHandler\n"
+#endif
+		"  jae mixm_i2f_LoopHandler\n"
 		"  fstps -4(%%edi)\n"        /* (vl') */
 		"  decl %%ecx\n"
 		"jnz mixm_i2f_next\n"
@@ -1570,6 +1731,9 @@ static __attribute__ ((used)) void dummy(void)
 		"fstps voll\n"               /* - */
 		"shll $2, %%ebp\n"
 		"movl %%ebp, %%eax\n"
+#if 1
+		"popl %%ecx\n" /* just a garbage register */
+#endif
 		"ret\n"
 
 	"mixm_i2f_LoopHandler:\n"
@@ -1606,7 +1770,10 @@ static __attribute__ ((used)) void dummy(void)
 	"mixm_i2f_loopme:\n"
 	/* sample loops -> jump to loop start */
 		"popl %%eax\n"
+	"mixm_i2f_loopme2:\n"
 		"subl mixlooplen, %%ebp\n"
+		"  cmpl (%%esp), %%ebp\n"
+		"jae mixm_i2f_loopme2\n"
 		"decl %%ecx\n"
 		"jz mixm_i2f_ende\n"
 		"jmp mixm_i2f_next\n"
@@ -1623,7 +1790,11 @@ static __attribute__ ((used)) void dummy(void)
 		"flds voll\n"                /* (vl) */
 		"flds volr\n"                /* (vr) (vl) */
 		"shrl $2, %%ebp\n"
+#if 1
+		"pushl %%ebp\n"
+#else
 		"movl %%ebp, mixs_i2f_SM1+2\n" /* self modifying code.  set loop end position */
+#endif
 		"movl %%eax, %%ebp\n"
 		"shrl $2, %%ebp\n"
 		"movl %%edx, %%eax\n"
@@ -1675,9 +1846,14 @@ static __attribute__ ((used)) void dummy(void)
 		"  fadds -8(%%edi)\n"        /* (lfinal) (vl') <right> (vr') */
 		"  fxch %%st(2)\n"           /* (right) (vl') (lfinal) (vr') */
 		"  fadds -4(%%edi)\n"        /* (rfinal) (vl') (lfinal) (vr') */
+	"mixs_i2f_looped:\n"
+#if 1
+		"  cmpl (%%esp), %%ebp\n"
+#else
 	"mixs_i2f_SM1:\n"
 		"  cmpl $12345678, %%ebp\n"
-		"  jge mixs_i2f_LoopHandler\n"
+#endif
+		"  jae mixs_i2f_LoopHandler\n"
 	/* hier 1 cycle frei */
 		"  fstps -4(%%edi)\n"        /* (vl') (lfinal) (vr') */
 		"  fxch %%st(1)\n"           /* (lfinal) (vl) (vr) */
@@ -1690,6 +1866,9 @@ static __attribute__ ((used)) void dummy(void)
 		"fstps voll\n"               /* - */
 		"shll $2, %%ebp\n"
 		"movl %%ebp, %%eax\n"
+#if 1
+		"popl %%ecx\n" /* just a garbage register */
+#endif
 		"ret\n"
 
 	"mixs_i2f_LoopHandler:\n"
@@ -1749,7 +1928,10 @@ static __attribute__ ((used)) void dummy(void)
 	"mixs_i2f_loopme:\n"
 	/* sample loops -> jump to loop start */
 		"popl %%eax\n"
+	"mixs_i2f_loopme2:\n"
 		"subl mixlooplen, %%ebp\n"
+		"  cmpl (%%esp), %%ebp\n"
+		"jae mixs_i2f_loopme2\n"
 		"decl %%ecx\n"
 		"jz mixs_i2f_ende\n"
 		"jmp mixs_i2f_next\n"
@@ -1997,8 +2179,9 @@ void getchanvol (int n, int len)
 	"getchanvol_goon:\n"
 		"  addl %%esi, %%edx\n"
 		"  adcl %%ebx, %%ebp\n"
+	"getchanvol_looped:\n"
 		"  cmpl %%edi, %%ebp\n"
-		"  jge getchanvol_LoopHandler\n"
+		"  jae getchanvol_LoopHandler\n"
 		"  decl %%ecx\n"
 		"jnz getchanvol_next\n"
 		"jmp getchanvol_SkipVoice\n"
@@ -2006,9 +2189,7 @@ void getchanvol (int n, int len)
 		"testl %2, voiceflags(,%%eax,4)\n"
 		"jz getchanvol_SkipVoice\n"
 		"subl looplen(,%%eax,4), %%ebp\n"
-		"decl %%ecx\n"
-		"jz getchanvol_SkipVoice\n"
-		"jmp getchanvol_next\n"
+		"jmp getchanvol_looped\n"
 	"getchanvol_SkipVoice:\n"
 		"fidivl nsamples\n"          /* (sum'') */
 		"fld %%st(0)\n"              /* (s) (s) */
