@@ -14,6 +14,7 @@
  */
 
 #include "config.h"
+#include <assert.h>
 #include <stdio.h>
 #include "types.h"
 #include "dwmix.h"
@@ -537,7 +538,7 @@ void mixqPlayChannel(int16_t *buf, uint32_t len, struct channel *ch, int quiet)
 	);
 }
 
-void mixqAmplifyChannel(int32_t *buf, int16_t *src, uint32_t len, uint32_t vol, uint32_t step)
+void mixqAmplifyChannel(int32_t *buf, int16_t *src, uint32_t len, int32_t vol, uint32_t step)
 {
 	int d0, d1, d2, d3;
 	__asm__ __volatile__
@@ -595,7 +596,7 @@ void mixqAmplifyChannel(int32_t *buf, int16_t *src, uint32_t len, uint32_t vol,
 	);
 }
 
-void mixqAmplifyChannelUp(int32_t *buf, int16_t *src, uint32_t len, uint32_t vol, uint32_t step)
+void mixqAmplifyChannelUp(int32_t *buf, int16_t *src, uint32_t len, int32_t vol, uint32_t step)
 {
 	int d0, d1, d2, d3;
 	__asm__ __volatile__
@@ -654,7 +655,7 @@ void mixqAmplifyChannelUp(int32_t *buf, int16_t *src, uint32_t len, uint32_t vol
 	);
 }
 
-void mixqAmplifyChannelDown(int32_t *buf, int16_t *src, uint32_t len, uint32_t vol, uint32_t step)
+void mixqAmplifyChannelDown(int32_t *buf, int16_t *src, uint32_t len, int32_t vol, uint32_t step)
 {
 	int d0, d1, d2, d3;
 	__asm__ __volatile__
@@ -1018,7 +1019,7 @@ mixqPlayChannel_bigloop:
 	mixqPlayChannel_maxplaylen:
 		{
 			uint64_t tmppos;/* signed to avoid some warnings */
-			tmppos=(((uint64_t)(mypos<<16))|myfpos)+((uint64_t)mystep)-1;
+			tmppos=(((uint64_t)(mypos<<16))|myfpos)/*+((uint64_t)mystep)-1*/;
 			if ((tmppos>>32)<mystep)
 			{
 				uint32_t tmplen;
@@ -1047,6 +1048,7 @@ mixqPlayChannel_playecx:
 		tmpf=(tmp&0xffff)+chan->fpos;
 		chan->fpos=tmpf&0xffff;
 		chan->pos+=(tmp>>16)+(tmpf>0xffff);
+		assert(chan->pos<chan->length);
 	}
 
 	if (inloop)
@@ -1471,7 +1473,7 @@ mixqPlayChannel_fill:
 	#endif
 }
 
-void mixqAmplifyChannel(int32_t *buf, int16_t *src, uint32_t len, uint32_t vol, uint32_t step)
+void mixqAmplifyChannel(int32_t *buf, int16_t *src, uint32_t len, int32_t vol, uint32_t step)
 {
 	while (len)
 	{
@@ -1482,7 +1484,7 @@ void mixqAmplifyChannel(int32_t *buf, int16_t *src, uint32_t len, uint32_t vol,
 	}
 }
 
-void mixqAmplifyChannelUp(int32_t *buf, int16_t *src, uint32_t len, uint32_t vol, uint32_t step)
+void mixqAmplifyChannelUp(int32_t *buf, int16_t *src, uint32_t len, int32_t vol, uint32_t step)
 {
 	while (len)
 	{
@@ -1494,7 +1496,7 @@ void mixqAmplifyChannelUp(int32_t *buf, int16_t *src, uint32_t len, uint32_t vol
 	}
 }
 
-void mixqAmplifyChannelDown(int32_t *buf, int16_t *src, uint32_t len, uint32_t vol, uint32_t step)
+void mixqAmplifyChannelDown(int32_t *buf, int16_t *src, uint32_t len, int32_t vol, uint32_t step)
 {
 	while (len)
 	{
