@@ -51,31 +51,42 @@ struct __attribute__((packed)) adbheader
 	uint32_t entries;
 };
 
-static void adbRegister(struct adbregstruct *r)
+void adbRegister(struct adbregstruct *r)
 {
 	r->next=adbPackers;
 	adbPackers=r;
 }
 
+void adbUnregister(struct adbregstruct *r)
+{
+	struct adbregstruct *root=adbPackers;
+	if (root==r)
+	{
+		adbPackers=r->next;
+		return;
+	}
+	while (root)
+	{
+		if (root->next==r)
+		{
+			root->next=root->next->next;
+			return;
+		}
+		if (!root->next)
+			return;
+		root=root->next;
+	}
+}
+
 char adbInit(void)
 {
 	char path[PATH_MAX+1];
 	int f;
 	struct adbheader header;
 
-	const char *regs;
-	char regname[50];
 	int old=0;
 	int i;
 
-	regs=_lnkReadInfoReg("arcs");
-	while (cfGetSpaceListEntry(regname, &regs, 49))
-	{
-		void *reg=_lnkGetSymbol(regname);
-		if (reg)
-			adbRegister((struct adbregstruct *)reg);
-	}
-
       	adbDirty=0;
 	adbData=0;
 	adbNum=0;
@@ -557,7 +568,8 @@ static FILE *adb_ReadHandle(struct modlistentry *entry)
 	struct arcentry *this/*, *parent*/;
 	this=&adbData[entry->adb_ref];
 
-	dirdbGetFullName(entry->dirdbfullpath, npath, 0);
+	dirdbGetFullName(entry->dirdbfullpath, npath, DIRDB_FULLNAME_NOBASE);
+
 	_splitpath(npath, NULL, dir, NULL, NULL);
 
 	/* TODO, logic here should work / for / and stat for dir/file */
@@ -648,8 +660,7 @@ static int arcReadDir(struct modlist *ml, const struct dmDrive *drive, const uin
 	if (drive!=dmFILE)
 		return 1;
 
-	dirdbGetFullName(path, _path, DIRDB_FULLNAME_NOBASE|DIRDB_FULLNAME_ENDSLASH);
-/*	fprintf(stderr, "arcReadDir drive=%s path=%s mask=%s opt=%ld\n", drive, path, mask, opt);*/
+	dirdbGetFullName(path, _path, DIRDB_FULLNAME_NOBASE);
 /*	dmGetPath(path, dirref);*/
       	if (isarchivepath(_path))
       	{
@@ -689,7 +700,7 @@ static int arcReadDir(struct modlist *ml, const struct dmDrive *drive, const uin
 
 			m.drive=drive;
 			_makepath(npath, 0, _path, name, ext);
-			m.dirdbfullpath=dirdbResolvePathAndRef(npath);
+			m.dirdbfullpath=dirdbResolvePathWithBaseAndRef(drive->basepath, npath);
 			if ((strlen(name)+strlen(ext))<NAME_MAX)
 				strcat(name, ext);
 			m.flags=MODLIST_FLAG_FILE|MODLIST_FLAG_VIRTUAL;
