@@ -38,4 +38,7 @@ extern int isarchivepath(const char *p);
 extern const char adbsigv1[16];
 extern const char adbsigv2[16];
 
+extern void adbRegister(struct adbregstruct *r);
+extern void adbUnregister(struct adbregstruct *r);
+
 #endif
