@@ -430,15 +430,36 @@ static int adbTARCall(const int act, const char *apath, const char *fullname, co
 }
 
 
-struct adbregstruct adbTARReg1 = {".TGZ", adbTARScan, adbTARCall};
-struct adbregstruct adbTARReg2 = {".TBZ", adbTARScan, adbTARCall};
-struct adbregstruct adbTARReg3 = {".TAR", adbTARScan, adbTARCall};
-struct adbregstruct adbTARReg4 = {".TZ", adbTARScan, adbTARCall};
-struct adbregstruct adbTARReg5 = {".TAR.GZ", adbTARScan, adbTARCall};
-struct adbregstruct adbTARReg6 = {".TAR.BZ2", adbTARScan, adbTARCall};
-struct adbregstruct adbTARReg7 = {".TAR.Z", adbTARScan, adbTARCall};
+static struct adbregstruct adbTARReg1 = {".TGZ", adbTARScan, adbTARCall};
+static struct adbregstruct adbTARReg2 = {".TBZ", adbTARScan, adbTARCall};
+static struct adbregstruct adbTARReg3 = {".TAR", adbTARScan, adbTARCall};
+static struct adbregstruct adbTARReg4 = {".TZ", adbTARScan, adbTARCall};
+static struct adbregstruct adbTARReg5 = {".TAR.GZ", adbTARScan, adbTARCall};
+static struct adbregstruct adbTARReg6 = {".TAR.BZ2", adbTARScan, adbTARCall};
+static struct adbregstruct adbTARReg7 = {".TAR.Z", adbTARScan, adbTARCall};
 
+static void __attribute__((constructor))init(void)
+{
+	adbRegister(&adbTARReg1);
+	adbRegister(&adbTARReg2);
+	adbRegister(&adbTARReg3);
+	adbRegister(&adbTARReg4);
+	adbRegister(&adbTARReg5);
+	adbRegister(&adbTARReg6);
+	adbRegister(&adbTARReg7);
+}
 
-char *dllinfo = "arcs adbTARReg1 adbTARReg2 adbTARReg3 adbTARReg4 adbTARReg5 adbTARReg6 adbTARReg7";
+static void __attribute__((destructor))done(void)
+{
+	adbUnregister(&adbTARReg1);
+	adbUnregister(&adbTARReg2);
+	adbUnregister(&adbTARReg3);
+	adbUnregister(&adbTARReg4);
+	adbUnregister(&adbTARReg5);
+	adbUnregister(&adbTARReg6);
+	adbUnregister(&adbTARReg7);
+}
+
+char *dllinfo = "";
 
 struct linkinfostruct dllextinfo = {"arctar", "OpenCP Archive Reader: .TAR (c) '04-'05 Stian Skjelstad", DLLVERSION, 0};
