@@ -25,7 +25,6 @@
 #include "types.h"
 #include "dirdb.h"
 #include "boot/plinkman.h"
-#include "boot/pmain.h"
 #include "modlist.h"
 #include "mdb.h"
 #include "pfilesel.h"
@@ -43,6 +42,7 @@ static struct cdrom_t
 } *root;
 
 static struct dmDrive *dmCDROM=0;
+static struct mdbreaddirregstruct cdReadDirReg;
 
 static void try(const char *dev, const char *vdev)
 {
@@ -165,12 +165,14 @@ static void try(const char *dev, const char *vdev)
 	}
 }
 
-
 static int cdint(void)
 {
 	char dev[32], vdev[12];
 	char a;
 	root=0;
+	
+	mdbRegisterReadDir(&cdReadDirReg);
+
 	dmCDROM=RegisterDrive("cdrom:");
 	fprintf(stderr, "Locating cdroms [  ]\010\010\010");
 	for (a=0;a<=32;a++)
@@ -208,6 +210,7 @@ static void cdclose(void)
 		free(current);
 		current=temp;
 	}
+	mdbUnregisterReadDir(&cdReadDirReg);
 }
 
 static FILE *cdrom_ReadHandle(struct modlistentry *entry)
@@ -354,8 +357,6 @@ static int cdReadDir(struct modlist *ml, const struct dmDrive *drive, const uint
 	return 1;
 }
 
-struct initcloseregstruct cdReg={cdint, cdclose};
-struct mdbreaddirregstruct cdReadDirReg = {cdReadDir};
-
-char *dllinfo = "initcloseafter cdReg; readdirs cdReadDirReg;";
-struct linkinfostruct dllextinfo = {"cdrom", "OpenCP UNIX audio-cdrom filebrowser (c) '04-'05 Stian Skjelstad", DLLVERSION, 0};
+static struct mdbreaddirregstruct cdReadDirReg = {cdReadDir};
+char *dllinfo = "";
+struct linkinfostruct dllextinfo = {"cdrom", "OpenCP UNIX audio-cdrom filebrowser (c) '04-'05 Stian Skjelstad", DLLVERSION, 0, Init: cdint, Close: cdclose};
