@@ -13,9 +13,13 @@
 struct dirdbEntry
 {
 	uint32_t parent;
+	uint32_t mdbref;
 	char *name; /* we pollute malloc a lot with this */
 	int refcount;
+
+	uint32_t newmdbref;
 };
+static uint32_t tagparentnode = DIRDB_NOPARENT;
 
 struct __attribute__((packed)) dirdbheader
 {
@@ -29,12 +33,36 @@ static struct dirdbEntry *dirdbData=0;
 static uint32_t dirdbNum=0;
 static int dirdbDirty=0;
 
+#ifdef DIRDB_DEBUG
+static void dumpdb_parent(uint32_t parent, int ident)
+{
+	uint32_t i;
+	for (i=0;i<dirdbNum;i++)
+	{
+		if ((dirdbData[i].parent==parent)&&(dirdbData[i].name))
+		{
+			int j;
+			fprintf(stderr, "0x%08x ", i);
+			for (j=0;j<ident;j++)
+				fprintf(stderr, " ");
+			fprintf(stderr, "%s (mdb 0x%08x)\n", dirdbData[i].name, dirdbData[i].mdbref);
+			dumpdb_parent(i, ident+1);
+		}
+	}
+}
+
+static void dumpdirdb(void)
+{
+	dumpdb_parent(DIRDB_NOPARENT, 0);
+}
+#endif
+
 int dirdbInit(void)
 {
 	char path[PATH_MAX+1];
 	struct dirdbheader header;
 	int f;
-	int i;
+	uint32_t i;
 	int retval;
 
 	if ((strlen(cfConfigDir)+11)>PATH_MAX)
@@ -92,6 +120,10 @@ int dirdbInit(void)
 				goto endoffile;
 			dirdbData[i].parent = uint32_little(dirdbData[i].parent);
 
+			if (read(f, &dirdbData[i].mdbref, sizeof(uint32_t))!=sizeof(uint32_t))
+				goto endoffile;
+			dirdbData[i].mdbref = uint32_little(dirdbData[i].mdbref);
+
 			dirdbData[i].name=malloc(len+1);
 			if (!dirdbData[i].name)
 				goto outofmemory;
@@ -101,6 +133,8 @@ int dirdbInit(void)
 				goto endoffile;
 			}
 			dirdbData[i].name[len]=0; /* terminate the string */
+			if (dirdbData[i].mdbref!=DIRDB_NO_MDBREF)
+				dirdbData[i].refcount++;
 		}
 	}
 	close(f);
@@ -142,7 +176,7 @@ unload:
 
 void dirdbClose(void)
 {
-	int i;
+	uint32_t i;
 	if (!dirdbNum)
 		return;
 	for (i=0; i<dirdbNum; i++)
@@ -159,6 +193,10 @@ uint32_t dirdbFindAndRef(uint32_t parent, char const *name /* NAME_MAX + 1 */)
 	uint32_t i;
 	struct dirdbEntry *new;
 
+#ifdef DIRDB_DEBUG
+	fprintf(stderr, "dirdbFindAndRef(0x%08x, \"%s\")\n", parent, name);
+#endif
+
 	if (strlen(name)>NAME_MAX)
 	{
 		fprintf(stderr, "dirdbFindAndRef: name too long\n");
@@ -186,11 +224,15 @@ reentry:
 			dirdbData[i].name=strdup(name);
 			dirdbData[i].parent=parent;
 			dirdbData[i].refcount++;
+			dirdbData[i].mdbref=DIRDB_NO_MDBREF;
 			if (parent!=DIRDB_NOPARENT)
 			{
 				/*fprintf(stderr, "  + %s (%d p=%d)\n", dirdbData[i].name, i, dirdbData[i].parent);*/
 				dirdbData[parent].refcount++;
 			}
+#ifdef DIRDB_DEBUG
+			dumpdirdb();
+#endif
 			return i;
 		}
 	
@@ -204,6 +246,14 @@ reentry:
 	memset(dirdbData+dirdbNum, 0, 16*sizeof(struct dirdbEntry));
 	i=dirdbNum;
 	dirdbNum+=16;
+	{
+		uint32_t j;
+		for (j=i;j<dirdbNum;j++)
+		{
+			dirdbData[j].mdbref=DIRDB_NO_MDBREF;
+			dirdbData[j].newmdbref=DIRDB_NO_MDBREF;
+		}
+	}
 	goto reentry;
 }
 
@@ -224,7 +274,9 @@ uint32_t dirdbResolvePathWithBaseAndRef(uint32_t base, char *name /* PATH_MAX +
 	char *next, *split;
 	uint32_t retval=base, newretval;
 
-/*	fprintf(stderr, "dirdbResolvePathWithBaseAndRef %d %s\n", base, name);*/
+#ifdef DIRDB_DEBUG
+	fprintf(stderr, "dirdbResolvePathWithBaseAndRef(0x%08x, \"%s\")\n", base, name);
+#endif
 
 	if (strlen(name)>PATH_MAX)
 	{
@@ -255,6 +307,9 @@ uint32_t dirdbResolvePathWithBaseAndRef(uint32_t base, char *name /* PATH_MAX +
 		dirdbUnref(retval);
 		retval=newretval;
 	}
+#ifdef DIRDB_DEBUG
+	dumpdirdb();
+#endif
 	return retval;
 }
 
@@ -264,8 +319,9 @@ extern uint32_t dirdbResolvePathAndRef(char *name /*PATH_MAX + 1 */)
 	char *next, *split;
 	uint32_t retval=DIRDB_NOPARENT, newretval;
 
-/*	fprintf(stderr, "dirdbResolvePathAndRef %s\n", name);*/
-
+#ifdef DIRDB_DEBUG
+	fprintf(stderr, "dirdbResolvePathAndRef(\"%s\")\n", name);
+#endif
 	if (strlen(name)>PATH_MAX)
 	{
 		fprintf(stderr, "dirdbResolvPathWithBase: name too long\n");
@@ -294,12 +350,18 @@ extern uint32_t dirdbResolvePathAndRef(char *name /*PATH_MAX + 1 */)
 			dirdbUnref(retval);
 		retval=newretval;
 	}
+#ifdef DIRDB_DEBUG
+	dumpdirdb();
+#endif
 	return retval;
 }
 
 void dirdbUnref(uint32_t node)
 {
 	uint32_t parent;
+#ifdef DIRDB_DEBUG
+	fprintf(stderr, "dirdbUnref(0x%08x)\n", node);
+#endif
 	if (node>=dirdbNum)
 	{
 err:
@@ -319,6 +381,12 @@ err:
 	dirdbData[node].parent=0;
 	free(dirdbData[node].name);
 	dirdbData[node].name=0;
+
+	dirdbData[node].mdbref=0xffffffff; /* this should not be needed */
+	dirdbData[node].newmdbref=0xffffffff; /* this should not be needed */
+#ifdef DIRDB_DEBUG
+	dumpdirdb();
+#endif
 	if (parent!=DIRDB_NOPARENT)
 		dirdbUnref(parent);
 }
@@ -328,7 +396,7 @@ void dirdbGetname(uint32_t node, char *name /*NAME_MAX+1*/)
 	name[0]=0;
 	if (node>=dirdbNum)
 	{
-		fprintf(stderr, "dirdbGetname: invalid node\n");
+		fprintf(stderr, "dirdbGetname: invalid node #1\n");
 		return;
 	}
 	if (!dirdbData[node].name)
@@ -337,7 +405,6 @@ void dirdbGetname(uint32_t node, char *name /*NAME_MAX+1*/)
 		return;
 	}
 	strcpy(name, dirdbData[node].name);
-
 }
 
 static void dirdbGetFullnameR(uint32_t node, char *name, int *left, int nobase)
@@ -428,17 +495,23 @@ void dirdbFlush(void)
 
 	for (i=0;i<max;i++)
 	{
-		if (dirdbData[i].name)
+		int len=(dirdbData[i].name?strlen(dirdbData[i].name):0);
+		buf16=uint16_little(len);
+		if (write(f, &buf16, sizeof(uint16_t))!=sizeof(uint16_t))
+			goto writeerror;
+		if (len)
 		{
-			int len = strlen(dirdbData[i].name);
-			buf16=uint16_little(len);
-			if (write(f, &buf16, sizeof(uint16_t))!=sizeof(uint16_t))
-				goto writeerror;
 			buf32=uint32_little(dirdbData[i].parent);
 			if (write(f, &buf32, sizeof(uint32_t))!=sizeof(uint32_t))
 				goto writeerror;
-			if (write(f, dirdbData[i].name, len)!=len)
+			buf32=uint32_little(dirdbData[i].mdbref);
+			if (write(f, &buf32, sizeof(uint32_t))!=sizeof(uint32_t))
 				goto writeerror;
+			if (dirdbData[i].name)
+			{
+				if (write(f, dirdbData[i].name, len)!=len)
+					goto writeerror;
+			}
 		}
 	}
 	close(f);
@@ -458,3 +531,180 @@ uint32_t dirdbGetParentAndRef (uint32_t node)
 		dirdbData[dirdbData[node].parent].refcount++;
 	return retval;
 }
+
+#if 0
+void dirdbMakeMdbRef(uint32_t node, uint32_t mdbref)
+{
+#ifdef DIRDB_DEBUG
+	fprintf(stderr, "dirdbMakeMdbRef(node 0x%08x, mdbref 0x%08x)\n", node, mdbref);
+#endif
+	if (node>=dirdbNum)
+	{
+		fprintf(stderr, "dirdbMakeMdbRef: invalid node\n");
+		return;
+	}
+	if (mdbref==DIRDB_NO_MDBREF)
+	{
+		if (dirdbData[node].mdbref!=DIRDB_NO_MDBREF)
+		{
+			dirdbData[node].mdbref=DIRDB_NO_MDBREF;
+			dirdbDirty=1;
+			dirdbUnref(node);
+		}
+	} else {
+		int doref = (dirdbData[node].mdbref==DIRDB_NO_MDBREF);
+		dirdbData[node].mdbref=mdbref;
+		dirdbDirty=1;
+		if (doref)
+			dirdbRef(node);
+	}
+#ifdef DIRDB_DEBUG
+	dumpdirdb();
+#endif
+}
+#endif
+
+void dirdbTagSetParent(uint32_t node)
+{
+	uint32_t i;
+	if (tagparentnode!=DIRDB_NOPARENT)
+	{
+		fprintf(stderr, "dirdbTagSetParent: warning, a node was already set as parent\n");
+		dirdbUnref(tagparentnode);
+		tagparentnode=DIRDB_NOPARENT;
+	}
+
+	for (i=0;i<dirdbNum;i++)
+		dirdbData[i].newmdbref=DIRDB_NO_MDBREF;
+
+	if (node>=dirdbNum)
+	{
+		fprintf(stderr, "dirdbTagSetParent: invalid node\n");
+		return;
+	}
+	tagparentnode = node;
+	dirdbRef(node);
+}
+
+void dirdbMakeMdbRef(uint32_t node, uint32_t mdbref)
+{
+	if (node>=dirdbNum)
+	{
+		fprintf(stderr, "dirdbMakeMdbRef: invalid node\n");
+		return;
+	}
+	if (mdbref==DIRDB_NO_MDBREF)
+	{
+		if (dirdbData[node].newmdbref!=DIRDB_NO_MDBREF)
+		{
+			dirdbData[node].newmdbref=DIRDB_NO_MDBREF;
+			dirdbUnref(node);
+		} /* else, no change */
+	} else {
+		if (dirdbData[node].mdbref==DIRDB_NO_MDBREF)
+		{
+			dirdbData[node].newmdbref=mdbref;
+			dirdbRef(node);
+		} else {
+			dirdbData[node].newmdbref=mdbref;
+		}
+	}
+}
+
+void dirdbTagCancel(void)
+{
+	uint32_t i;
+	for (i=0;i<dirdbNum;i++)
+	{
+		if (dirdbData[i].newmdbref!=DIRDB_NO_MDBREF)
+		{
+			dirdbData[i].newmdbref=DIRDB_NO_MDBREF;
+			dirdbUnref(i);
+		}
+	}
+	if (tagparentnode==DIRDB_NOPARENT)
+	{
+		fprintf(stderr, "dirdbTagCancel: parent is not set\n");
+		return;
+	}
+	dirdbUnref(tagparentnode);
+	tagparentnode=DIRDB_NOPARENT;
+}
+
+void _dirdbTagRemoveUntaggedAndSubmit(uint32_t node)
+{
+	uint32_t i;
+	for (i=0;i<dirdbNum;i++)
+	{
+		if (dirdbData[i].parent==node)
+		{
+			if (dirdbData[i].newmdbref==dirdbData[i].mdbref)
+			{
+				if (dirdbData[i].mdbref==DIRDB_NO_MDBREF)
+				{
+					/* probably a dir */
+					_dirdbTagRemoveUntaggedAndSubmit(i);
+				} else {
+					/* mdbref changed */
+					dirdbData[i].mdbref=dirdbData[i].newmdbref;
+					dirdbData[i].newmdbref=DIRDB_NO_MDBREF;
+					dirdbUnref(i);
+				}
+			} else {
+				if (dirdbData[i].mdbref==DIRDB_NO_MDBREF)
+				{
+					dirdbData[i].mdbref=dirdbData[i].newmdbref;
+					dirdbData[i].newmdbref=DIRDB_NO_MDBREF;
+					/* no need to unref/ref, since we are balanced.
+					 * If somebody has named a file, the same name
+					 * a directory used to have, we will be a
+					 * bit f*cked here, but the cost to scan the
+					 * database here is to expensive by my meenings.
+					 * NB NB NB NB
+					 */
+				} else if (dirdbData[i].newmdbref==DIRDB_NO_MDBREF)
+				{
+					dirdbData[i].mdbref=DIRDB_NO_MDBREF;
+					dirdbUnref(i);
+					/* same as above regarding renaming */
+				} else {
+					dirdbData[i].mdbref=dirdbData[i].newmdbref;
+					dirdbData[i].newmdbref=DIRDB_NO_MDBREF;
+					dirdbUnref(i);
+				}
+			}
+		}
+	}
+}
+
+void dirdbTagRemoveUntaggedAndSubmit(void)
+{
+	if (tagparentnode==DIRDB_NOPARENT)
+	{
+		fprintf(stderr, "dirdbTagRemoveUntaggedAndSubmit: parent is not set\n");
+		return;
+	}
+	/* if parent has changed mdbref, we can't detect this.. NB NB NB */
+	_dirdbTagRemoveUntaggedAndSubmit(tagparentnode);
+	dirdbUnref(tagparentnode);
+	tagparentnode=DIRDB_NOPARENT;
+	dirdbDirty=1;
+}
+
+int dirdbGetMdb(uint32_t *dirdbnode, uint32_t *mdbnode, int *first)
+{
+	if (*first)
+	{
+		*dirdbnode=0;
+		*first=0;
+	} else
+		(*dirdbnode)++;
+	for (;*dirdbnode<dirdbNum;(*dirdbnode)++)
+		if ((dirdbData[*dirdbnode].name)&&(dirdbData[*dirdbnode].mdbref!=DIRDB_NO_MDBREF))
+		{
+			*mdbnode=dirdbData[*dirdbnode].mdbref;
+			return 0;
+		}
+	return -1;
+}
+
