@@ -2,6 +2,7 @@
 #define _DIRDB_H
 
 #define DIRDB_NOPARENT 0xffffffff
+#define DIRDB_NO_MDBREF 0xffffffff
 
 extern const char dirdbsigv1[60];
 
@@ -20,4 +21,11 @@ extern int dirdbInit(void);
 extern void dirdbClose(void);
 extern uint32_t dirdbGetParentAndRef(uint32_t node);
 
+extern void dirdbTagSetParent(uint32_t node);
+extern void dirdbMakeMdbRef(uint32_t node, uint32_t mdbref);
+extern void dirdbTagCancel(void);
+extern void dirdbTagRemoveUntaggedAndSubmit(void);
+
+extern int dirdbGetMdb(uint32_t *dirdbnode, uint32_t *mdbnode, int *first);
+
 #endif
