@@ -120,9 +120,9 @@ int mdbInfoRead(uint32_t fileref)
 
 /* This thing will end up with a register of all valid pre-interprators for modules and friends
  */
-static struct mdbreadnforegstruct *mdbReadInfos=NULL;
+static struct mdbreadinforegstruct *mdbReadInfos=NULL;
 
-static void mdbRegisterReadInfo(struct mdbreadnforegstruct *r)
+void mdbRegisterReadInfo(struct mdbreadinforegstruct *r)
 {
 	r->next=mdbReadInfos;
 	mdbReadInfos=r;
@@ -130,9 +130,30 @@ static void mdbRegisterReadInfo(struct mdbreadnforegstruct *r)
 		r->Event(mdbEvInit);
 }
 
+void mdbUnregisterReadInfo(struct mdbreadinforegstruct *r)
+{
+	struct mdbreadinforegstruct *root=mdbReadInfos;
+	if (root==r)
+	{
+		mdbReadInfos=r->next;
+		return;
+	}
+	while (root)
+	{
+		if (root->next==r)
+		{
+			root->next=root->next->next;
+			return;
+		}
+		if (!root->next)
+			return;
+		root=root->next;
+	}
+}
+
 int mdbReadMemInfo(struct moduleinfostruct *m, const char *buf, int len)
 {
-	struct mdbreadnforegstruct *rinfos;
+	struct mdbreadinforegstruct *rinfos;
 
 	for (rinfos=mdbReadInfos; rinfos; rinfos=rinfos->next)
 	if (rinfos->ReadMemInfo)
@@ -145,7 +166,7 @@ int mdbReadMemInfo(struct moduleinfostruct *m, const char *buf, int len)
 int mdbReadInfo(struct moduleinfostruct *m, FILE *f)
 {
 	char mdbScanBuf[1084];
-	struct mdbreadnforegstruct *rinfos;
+	struct mdbreadinforegstruct *rinfos;
 	int maxl;
 
 	memset(mdbScanBuf, 0, 1084);
@@ -187,9 +208,15 @@ static uint32_t mdbGetNew(void)
 int mdbWriteModuleInfo(uint32_t fileref, struct moduleinfostruct *m)
 {
 	if (fileref>=mdbNum)
+	{
+		fprintf(stderr, "mdbWriteModuleInfo, fileref(%d)<mdbNum(%d)\n", fileref, mdbNum);
 		return 0;
+	}
 	if ((mdbData[fileref].flags&(MDB_USED|MDB_BLOCKTYPE))!=(MDB_USED|MDB_GENERAL))
+	{
+		 fprintf(stderr, "mdbWriteModuleInfo (mdbData[fileref].flags&(MDB_USED|MDB_BLOCKTYPE))!=(MDB_USED|MDB_GENERAL) Failed\n");
 		return 0;
+	}
 
 	m->flags1=MDB_USED|MDB_DIRTY|MDB_GENERAL|(m->flags1&(MDB_VIRTUAL|MDB_BIGMODULE|MDB_PLAYLIST));
 	m->flags2=MDB_DIRTY|MDB_COMPOSER;
@@ -268,7 +295,7 @@ void mdbUnregisterReadDir(struct mdbreaddirregstruct *r)
 		mdbReadDirs=r->next;
 		return;
 	}
-	while (1)
+	while (root)
 	{
 		if (root->next==r)
 		{
@@ -295,48 +322,11 @@ static int miecmp(const void *a, const void *b)
 
 int mdbInit(void)
 {
-	char regname[50];
-	const char *regs;
 	char path[PATH_MAX+1];
 	int f;
 	struct mdbheader header;
 	uint32_t i;
 
-	regs=_lnkReadInfoReg("readdirs");
-	while (cfGetSpaceListEntry(regname, &regs, 49))
-	{
-		void *reg=_lnkGetSymbol(regname);
-		if (reg)
-		{
-#ifdef LD_DEBUG
-			fprintf(stderr, "mdb: Registering %s\n", regname);
-#endif
-			mdbRegisterReadDir((struct mdbreaddirregstruct *)reg);
-#ifdef LD_DEBUG
-		} else {
-			fprintf(stderr, "mdb: UNABLE TO LOCATE %s\n", regname);
-#endif
-		}
-	
-	}
-
-	regs=_lnkReadInfoReg("readinfos");
-	while (cfGetSpaceListEntry(regname, &regs, 49))
-	{
-		void *reg=_lnkGetSymbol(regname);
-		if (reg)
-		{
-#ifdef LD_DEBUG
-			fprintf(stderr, "mdb: Registering: %s\n", regname);
-#endif
-			mdbRegisterReadInfo((struct mdbreadnforegstruct*)reg);
-		}
-#ifdef LD_DEBUG
-		else
-			fprintf(stderr, "mdb: (warning) Unable to find symbol: %s\n", regname);
-#endif
-	}
-
 	mdbDirty=0;
 	mdbData=0;
 	mdbNum=0;
