@@ -47,7 +47,7 @@ enum
 	mtMID=16, mtCDA=17, mtMIDd=18, mtPTM=19, mtMED=20, mtMDL=21, mtAMS=22,
 	mtINP=23, mtDEVp=24, mtDEVs=25, mtDEVw=26, mtIT=27, mtWAV=28, mtVOC=29,
 	mtMPx=30, mtSID=31, mtMXM=32, mtMODf=33, mtWMA=34, mtOGG=35, mtOPL=36,
-	mtAY=37,
+	mtAY=37, mtFLAC=38,
 	mtPLS=128, mtM3U=129, mtANI=130,
 	mtUnRead=0xFF
 };
@@ -57,12 +57,12 @@ enum
   mdbEvInit, mdbEvDone
 };
 
-struct mdbreadnforegstruct /* this is to test a file, and give it a tag..*/
+struct mdbreadinforegstruct /* this is to test a file, and give it a tag..*/
 {
 	int (*ReadMemInfo)(struct moduleinfostruct *m, const char *buf, size_t len);
 	int (*ReadInfo)(struct moduleinfostruct *m, FILE *f, const char *buf, size_t len);
 	void (*Event)(int mdbEv);
-	struct mdbreadnforegstruct *next;
+	struct mdbreadinforegstruct *next;
 };
 
 struct modlist;
@@ -92,6 +92,8 @@ extern int mdbGetModuleInfo(struct moduleinfostruct *m, uint32_t fileref);
 
 extern void mdbRegisterReadDir(struct mdbreaddirregstruct *r);
 extern void mdbUnregisterReadDir(struct mdbreaddirregstruct *r);
+extern void mdbRegisterReadInfo(struct mdbreadinforegstruct *r);
+extern void mdbUnregisterReadInfo(struct mdbreadinforegstruct *r);
 
 #if 0
 /* these two are super-set by modlist itself */
