@@ -8,11 +8,13 @@
 #endif
 #include <stdio.h> /* size_t */
 
+struct dmDrive;
 struct modlistentry
 {
 	char shortname[12]; /* the name that we present in the filelists.. 8:3 format looks so nice... yuck... but i works*/
-	const char *drive;
-	char fullname[PATH_MAX+1]; /* the very full path to this object */
+	const struct dmDrive *drive;
+//	char fullname[PATH_MAX+1]; /* the very full path to this object */
+	uint32_t dirdbfullpath; /* full path */
 	char name[NAME_MAX+1]; /* the very lonely filename */
 	
 #define MODLIST_FLAG_DIR      1
@@ -42,11 +44,11 @@ struct modlist
 	int num; /* entries used */
 
 	void (*_free)(struct modlist *);
-	struct modlistentry *(*getcur)(struct modlist *modlist); /* does not Ref() */
-	struct modlistentry *(*get)(struct modlist *modlist, int index);
+	struct modlistentry *(*getcur)(const struct modlist *modlist); /* does not Ref() */
+	struct modlistentry *(*get)(const struct modlist *modlist, int index);
 	void (*append)(struct modlist *modlist, struct modlistentry *entry);
 	void (*remove)(struct modlist *modlist, int index, int count);
-	int (*find)(struct modlist *modlist, const char *drive, const char *fullname);
+	int (*find)(struct modlist *modlist, const uint32_t path);
 	void (*sort)(struct modlist *modlist);
 	int (*fuzzyfind)(struct modlist *modlist, const char *filename);
 };
