@@ -11,6 +11,8 @@ extern signed int fsFileSelect(void);
 extern char fsInit(void);
 extern void fsClose(void);
 
+extern int fsFPS; /* see stuff/framelock.c */
+extern int fsFPSCurrent; /* see stuff/framelock.c */
 extern int fsListScramble;
 extern int fsListRemove;
 extern int fsLoopMods;
@@ -40,16 +42,25 @@ struct filehandlerstruct
 	int (*Process)(const char *path, struct moduleinfostruct *m, FILE **f);
 };
 
+typedef enum {
+	interfaceReturnContinue=0,
+	interfaceReturnNextAuto=1,
+	interfaceReturnQuit=2,
+	interfaceReturnNextManuel=3,
+	interfaceReturnCallFs=4,
+	interfaceReturnDosShell=5
+} interfaceReturnEnum;
+
 struct interfacestruct
 {
 	int (*Init)(const char *path, struct moduleinfostruct *info, FILE **f);
-	int (*Run)(void);
+	interfaceReturnEnum (*Run)(void);
 	void (*Close)(void);
 };
 
 #define RD_PUTSUBS 1
 #define RD_ARCSCAN 2
-#define RD_DIRRECURSE 4
+#define RD_SUBNOSYMLINK 4
 #define RD_PUTRSUBS 16
 
 #if 0
@@ -62,13 +73,6 @@ extern unsigned short dmGetDriveDir(int drv);
 
 #if 0
 extern char mifMemRead(const char *name, unsigned short size, char *ptr);
-
-struct fsgetfileregstruct
-{
-	void (*GetFile)(char *path, FILE **f);
-	struct fsgetfileregstruct *next;
-};
-
 #endif
 struct dmDrive
 {
