@@ -19,6 +19,7 @@
 #include <unistd.h>
 #include "types.h"
 #include "adb.h"
+#include "dirdb.h"
 #include "gendir.h"
 #include "mdb.h"
 #include "modlist.h"
@@ -26,7 +27,7 @@
 #include "playlist.h"
 #include "stuff/compat.h"
 
-static int m3uReadDir(struct modlist *ml, const char *drive, const char *path, const char *mask, unsigned long opt)
+static int m3uReadDir(struct modlist *ml, const struct dmDrive *drive, const uint32_t path, const char *mask, unsigned long opt)
 {
 	char *s1, *s2;
 #if 0
@@ -41,20 +42,11 @@ static int m3uReadDir(struct modlist *ml, const char *drive, const char *path, c
 	
 	int fd;
 	struct stat st;
-	
-	if (strcmp(drive, "file:")) /* we, only support file:// transport for now... TODO */
-		return 1;
-	if (path[0]!='/')
-		return 1;
 
-	/* we need to strip of the last / */
-	strcpy(newpath, path);
-	s1=rindex(newpath, '/');
-	if (!s1)
+	if (drive!=dmFILE)
 		return 1;
-	/* remove trailing / */
-	if (!s1[1])
-		*s1=0;
+	
+	dirdbGetFullName(path, newpath, DIRDB_FULLNAME_NOBASE); /* no file: */
 
 	/* Does the file end in .M3U ? */
 	s1=newpath+strlen(newpath)-4;
@@ -122,7 +114,7 @@ static int m3uReadDir(struct modlist *ml, const char *drive, const char *path, c
 		if (!buftail[0])
 			goto newline;
 #if 1
-		fsAddPlaylist(ml, drive, newpath, mask, opt, buftail);
+		fsAddPlaylist(ml, newpath, mask, opt, buftail);
 #else
 		{
 			const char *dmDrive=NULL;
