@@ -36,6 +36,8 @@
 
 static struct preprocregstruct *plPreprocess = 0;
 
+extern struct mdbreaddirregstruct adbReadDirReg, dosReadDirReg, fsReadDirReg, plsReadDirReg, m3uReadDirReg;
+extern struct mdbreadinforegstruct fsReadInfoReg;
 
 static struct interfacestruct *plintr;
 static struct interfacestruct *nextintr;
@@ -61,13 +63,18 @@ static int  stop;
 
 
 
+/* return values:
+ * 0  - no files available (and user hit esc
+ * 1  - we have a new song availble
+ * -1 - error occured
+ */
 
 int callselector (char *path, struct moduleinfostruct *info, FILE **fi,
                   char callfs, char forcecall, char forcenext,
                   struct interfacestruct **iface)
 {
-	char ret;
-	char result;
+	int ret;
+	int result;
 	char tpath[PATH_MAX+1];
 	struct interfacestruct *intr;
 	struct filehandlerstruct *hdlr;
@@ -146,7 +153,6 @@ int callselector (char *path, struct moduleinfostruct *info, FILE **fi,
 	} while (ret);
 
   return 0;
-
 }
 
 static int _fsMain(int argc, char *argv[])
@@ -268,15 +274,15 @@ static int _fsMain(int argc, char *argv[])
 						break;
 					case 3: /* next playlist file (man) */
 						if (fsFilesLeft())
-							stop=callselector(nextpath,&nextinfo,&nextf,1,0,1,&nextintr);
+							stop=callselector(nextpath,&nextinfo,&nextf,1,0,1,&nextintr)?interfaceReturnNextAuto:interfaceReturnContinue;
 						else
-							stop=callselector(nextpath,&nextinfo,&nextf,1,0,0,&nextintr);
+							stop=callselector(nextpath,&nextinfo,&nextf,1,0,0,&nextintr)?interfaceReturnNextAuto:interfaceReturnContinue;
 						if (stop==-1)
 							callfs=1;
 						break;
 					case 4: /* call fs */
 						callfs=1;
-						stop=callselector(nextpath,&nextinfo,&nextf,1,1,0,&nextintr);
+						stop=callselector(nextpath,&nextinfo,&nextf,1,1,0,&nextintr)?interfaceReturnNextAuto:interfaceReturnContinue;
 						break;
 					case 5: /* dos shell */
 						plSetTextMode(fsScrType);
@@ -318,6 +324,13 @@ static int fsint(void)
 
 	char regname[50];
 	const char *regs=NULL;
+
+	mdbRegisterReadDir(&adbReadDirReg);
+	mdbRegisterReadDir(&dosReadDirReg);
+	mdbRegisterReadDir(&fsReadDirReg);
+	mdbRegisterReadDir(&plsReadDirReg);
+	mdbRegisterReadDir(&m3uReadDirReg);
+	mdbRegisterReadInfo(&fsReadInfoReg);
 	regs=_lnkReadInfoReg("preprocess");
 
 	while (cfGetSpaceListEntry(regname, &regs, 49))
@@ -342,6 +355,13 @@ static int fsint(void)
 
 static void fsclose()
 {
+	mdbUnregisterReadDir(&adbReadDirReg);
+	mdbUnregisterReadDir(&dosReadDirReg);
+	mdbUnregisterReadDir(&fsReadDirReg);
+	mdbUnregisterReadDir(&plsReadDirReg);
+	mdbUnregisterReadDir(&m3uReadDirReg);
+	mdbUnregisterReadInfo(&fsReadInfoReg);
+
 	fsClose();
 }
 
@@ -528,11 +548,25 @@ int addm3u(const char *path, moduleinfostruct &info, binfile *&fil)
 }
 #endif
 
-struct initcloseregstruct fsReg={fsint, fsclose};
 /*
 struct filehandlerstruct fsAddPLS={addpls};
 struct filehandlerstruct fsAddM3U={addm3u};
 */
-struct mainstruct fsMain = { _fsMain };
-char *dllinfo = "initcloseafter fsReg; main fsMain; readdirs adbReadDirReg dosReadDirReg fsReadDirReg plsReadDirReg m3uReadDirReg; getfile adbGetFileReg dosGetFileReg; readinfos fsReadInfoReg";
-struct linkinfostruct dllextinfo = {"pfilesel", "OpenCP Fileselector (c) 1994-04 Niklas Beisert, Tammo Hinrichs", DLLVERSION, 0};
+static struct mainstruct fsmain = { _fsMain };
+
+static void __attribute__((constructor))init(void)
+{
+	if (ocpmain)
+		fprintf(stderr, "pfsmain.c: ocpmain != NULL\n");
+	else
+		ocpmain = &fsmain;
+}
+
+static void __attribute__((destructor))done(void)
+{
+	if (ocpmain!=&fsmain)
+		ocpmain = 0;
+}
+
+char *dllinfo = "";
+struct linkinfostruct dllextinfo = {"pfilesel", "OpenCP Fileselector (c) 1994-04 Niklas Beisert, Tammo Hinrichs", DLLVERSION, 0, PreInit: fsint, LateClose: fsclose};
