@@ -41,9 +41,11 @@
  * ask me why).
  */
 
+#include "config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include "types.h"
 #include "zlib.h"
 
 #pragma pack (1)                       /* this is essential */
@@ -64,9 +66,9 @@ typedef struct sect {
 	char *desc;
 	void *data,
 	     *compdata;
-	int   datasize,
-	      compdatasize;
-	int   textlines;
+	uint32_t   datasize,
+	           compdatasize,
+	           textlines;
 	struct sect *next;
 } section;
 
@@ -80,7 +82,7 @@ section *sections=NULL,
 FILE    *in,
         *out;
 char     file_id[5]="OCPH";
-int      helpver=0x011000;
+uint32_t helpver=0x011000;
 int      verbose=0,
          comment=0;
 
@@ -403,7 +405,7 @@ void compress_sections(void)
 
 void write_section_directory(void)
 {
-	int      numsects;
+	uint32_t numsects;
 	section *s;
 
 	s=sections;
@@ -414,6 +416,7 @@ void write_section_directory(void)
 		numsects++;
 	}
 
+	numsects = uint32_little(numsects);
 	fwrite(&numsects, 1, 4, out);
 
 	s=sections;
@@ -422,10 +425,15 @@ void write_section_directory(void)
 	{
 		putfstr(s->name, out);
 		putfstr(s->desc, out);
+		s->datasize=uint32_little(s->datasize);
+		s->textlines=uint32_little(s->textlines);
+		s->compdatasize=uint32_little(s->compdatasize);
 		fwrite(&s->datasize, 1, 4, out);
 		fwrite(&s->textlines, 1, 4, out);
 		fwrite(&s->compdatasize, 1, 4, out);
-
+		s->datasize=uint32_little(s->datasize);
+		s->textlines=uint32_little(s->textlines);
+		s->compdatasize=uint32_little(s->compdatasize);
 		s=s->next;
 	}
 }
@@ -455,8 +463,9 @@ void write_sections(void)
 
 void write_file_header(void)
 {
+	uint32_t t = uint32_little(helpver);
 	fwrite(file_id, 1, 4, out);
-	fwrite(&helpver, 1, 4, out);
+	fwrite(&t, 1, 4, out);
 }
 
 int main(int argc, char *argv[])
@@ -492,5 +501,15 @@ int main(int argc, char *argv[])
 	fclose(in);
 	fclose(out);
 
+	for(cursect=sections;cursect;cursect=sections)
+	{
+		sections=cursect->next;
+		free(cursect->name);
+		free(cursect->desc);
+		free(cursect->data);
+		free(cursect->compdata);
+		free(cursect);
+	}
+
 	return 0;
 }
