@@ -86,9 +86,9 @@
 #include "stuff/poutput.h"
 #include "boot/plinkman.h"
 #include "stuff/err.h"
-#include "boot/pmain.h"
 #include "help/cphelper.h"
 #include "binfile/binfpak.h"
+#include "cpiface/cpiface.h"
 #include <curses.h>
 
 static int plWinFirstLine, plWinHeight, plHelpHeight, plHelpScroll;
@@ -641,6 +641,19 @@ int brHelpKey(uint16_t key)
 
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp(KEY_UP, "Scroll help page up");
+			cpiKeyHelp(KEY_DOWN, "Scroll help page down");
+			cpiKeyHelp(KEY_PPAGE, "Scroll help page, a page up");
+			cpiKeyHelp(KEY_NPAGE, "Scroll help page, a page down");
+			cpiKeyHelp(KEY_HOME, "Scroll help page, to the start");
+			cpiKeyHelp(KEY_END, "Scroll help page, to the bottom");
+			cpiKeyHelp(KEY_ALT_C, "Goto contents help page");
+			cpiKeyHelp(KEY_ALT_I, "Goto index help page");
+			cpiKeyHelp(KEY_ALT_L, "Goto licence help page");
+			cpiKeyHelp(KEY_TAB, "Goto next link");
+			cpiKeyHelp(KEY_SHIFT_TAB, "Goto previous link");
+			return 0;
 		/*case 0x4800: //up*/
 		case KEY_UP:
 			if (curpage->linkcount)
@@ -767,38 +780,38 @@ int brHelpKey(uint16_t key)
 		case KEY_ALT_L:
 			brSetPage(brDecodeRef("License"));
 			break;
-/*case 0x0009: //tab
-    if (curpage->linkcount)
-    {
-      if (linkOnCurrentPage(curlink))
-      {
-        link_ind=(link_ind+1)%curpage->linkcount;
-        curlink=&curpage->links[link_ind];
-      };
-
-      if (!linkOnCurrentPage(curlink)) plHelpScroll=curlink->posy;
-    };
-
-    break;
-  case 0x0f00: //shift-tab
-    if (curpage->linkcount)
-    {
-      if (linkOnCurrentPage(curlink))
-      {
-        link_ind--; if (link_ind<0) link_ind=curpage->linkcount-1;
-        curlink=&curpage->links[link_ind];
-      };
-
-      if (!linkOnCurrentPage(curlink)) plHelpScroll=curlink->posy;
-    };
-
-    break;*/
+		case KEY_TAB:
+			if (curpage->linkcount)
+			{
+				if (linkOnCurrentPage(curlink))
+				{
+					link_ind=(link_ind+1)%curpage->linkcount;
+					curlink=&curpage->links[link_ind];
+				}
+				if (!linkOnCurrentPage(curlink))
+					plHelpScroll=curlink->posy;
+			}
+ 			break;
+		case KEY_SHIFT_TAB: /* 0x0f00: //shift-tab*/
+			if (curpage->linkcount)
+			{
+				if (linkOnCurrentPage(curlink))
+				{
+					link_ind--;
+					if (link_ind<0)
+						link_ind=curpage->linkcount-1;
+					curlink=&curpage->links[link_ind];
+				}
+				if (!linkOnCurrentPage(curlink))
+					plHelpScroll=curlink->posy;
+			}
+			break;
 /*  case 0x3920: case 0x3900: case 0x0020: case 0x000D: // space/enter*/
-		case 10: case 13: case ' ':
+		case KEY_CTRL_J: case _KEY_ENTER: case ' ':
 			processActiveHyperlink();
 			break;
 		default:
- 			return 0;
+			return 0;
 	}
 	if ((plHelpScroll+plWinHeight)>plHelpHeight)
 		plHelpScroll=plHelpHeight-plWinHeight;
@@ -874,7 +887,5 @@ static void hlpGlobalClose(void)
 	hlpFreePages();
 }
 
-struct initcloseregstruct hlpReg = { hlpGlobalInit, hlpGlobalClose };
-
-char *dllinfo = "initcloseafter hlpReg";
-struct linkinfostruct dllextinfo = {"cphelper", "OpenCP help browser (c) 1998-04 Fabian Giesen", DLLVERSION, 0};
+char *dllinfo = "";
+struct linkinfostruct dllextinfo = {"cphelper", "OpenCP help browser (c) 1998-04 Fabian Giesen", DLLVERSION, 0, Init: hlpGlobalInit, Close: hlpGlobalClose};
