@@ -48,11 +48,11 @@
 #include "z80.h"
 
 /* from main.c */
-struct aydata_tag aydata;
-struct time_tag ay_tunetime;
-int ay_track=0;
-int new_ay_track=0;
-unsigned long ay_tstates,ay_tsmax;
+__attribute__ ((visibility ("internal"))) struct aydata_tag aydata;
+__attribute__ ((visibility ("internal"))) struct time_tag ay_tunetime;
+__attribute__ ((visibility ("internal"))) int ay_track=0;
+static int new_ay_track=0;
+__attribute__ ((visibility ("internal"))) unsigned long ay_tstates,ay_tsmax;
 static int ay_current_reg=0;
 static int done_fade=0;
 static int fadetime=10;	/* fadeout time *after* that in sec, 0=none */
@@ -61,7 +61,7 @@ static int silent_max=4*50;	/* max frames of silence before skipping */
 static int ay_looped;
 
 /* the memory is a flat all-RAM 64k */
-unsigned char ay_mem[64*1024];
+__attribute__ ((visibility ("internal"))) unsigned char ay_mem[64*1024];
 #define AYLET_VER	"0.3"
 #define FRAME_STATES_48		(3500000/50)
 #define FRAME_STATES_128	(3546900/50)
@@ -154,14 +154,14 @@ static void audio_pcm_s16(int16_t *dest, unsigned int nsamples, uint16_t *source
 }
 
 /* from main.c */
-unsigned int ay_in(int h,int l)
+unsigned int __attribute__ ((visibility ("internal"))) ay_in(int h,int l)
 {
 	/* presumably nothing? XXX */
 	return 255;
 }
 
 /* from main.c */
-unsigned int ay_out(int h,int l,int a)
+unsigned int __attribute__ ((visibility ("internal"))) ay_out(int h,int l,int a)
 {
 	static int cpc_f4=0;
 
@@ -313,7 +313,7 @@ static void mem_init(int track)
 }
 
 /* from main.c */
-int read_ay_file(FILE *in)
+static int read_ay_file(FILE *in)
 {
 	unsigned char *data,*buf,*ptr,*ptr2;
 	int data_alloc=16384,buf_alloc=16384,data_ofs=0;
@@ -455,7 +455,7 @@ static void tunetime_reset(void)
 }
 
 /* rets zero if we want to exit the emulation (i.e. exit track) */
-int ay_do_interrupt(void)
+int __attribute__ ((visibility ("internal"))) ay_do_interrupt(void)
 {
 	static int count=0;
 	static int silent_for=0;
@@ -506,7 +506,7 @@ int ay_do_interrupt(void)
 	return 0;
 }
 
-void ay_driver_frame(uint16_t *stereo_samples, size_t bytes)
+void __attribute__ ((visibility ("internal"))) ay_driver_frame(uint16_t *stereo_samples, size_t bytes)
 {
 	_buf8=stereo_samples;
 	_buf8_n=bytes>>1;
@@ -563,7 +563,7 @@ static void ayIdler(void)
 	}
 }
 
-void ayIdle(void)
+void __attribute__ ((visibility ("internal"))) ayIdle(void)
 {
 	uint32_t bufplayed;
 	uint32_t bufdelta;
@@ -975,7 +975,7 @@ void ayIdle(void)
 }
 
 
-int ayOpenPlayer(FILE *file)
+int __attribute__ ((visibility ("internal"))) ayOpenPlayer(FILE *file)
 {
 	aydata.filedata=NULL;
 	aydata.tracks=NULL;
@@ -1083,7 +1083,7 @@ int ayOpenPlayer(FILE *file)
 	return 1;
 }
 
-void ayClosePlayer(void)
+void __attribute__ ((visibility ("internal"))) ayClosePlayer(void)
 {
 	pollClose();
 
@@ -1101,29 +1101,29 @@ void ayClosePlayer(void)
 		free(aydata.filedata);
 }
 
-int ayIsLooped(void)
+int __attribute__ ((visibility ("internal"))) ayIsLooped(void)
 {
 	return ay_looped;
 }
 
-void aySetLoop(unsigned char s)
+void __attribute__ ((visibility ("internal"))) aySetLoop(unsigned char s)
 {
       	donotloop=!s;
 }
 
-void ayPause(unsigned char p)
+void __attribute__ ((visibility ("internal"))) ayPause(unsigned char p)
 {
       	inpause=p;
 }
 
-void aySetSpeed(unsigned short sp)
+void __attribute__ ((visibility ("internal"))) aySetSpeed(unsigned short sp)
 {
       	if (sp<32)
 		sp=32;
 	aybufrate=256*sp;
 }
 
-void aySetVolume(unsigned char vol_, signed char bal_, signed char pan_, unsigned char opt)
+void __attribute__ ((visibility ("internal"))) aySetVolume(unsigned char vol_, signed char bal_, signed char pan_, unsigned char opt)
 {
 	pan=pan_;
 	volr=voll=vol_*4;
@@ -1134,7 +1134,7 @@ void aySetVolume(unsigned char vol_, signed char bal_, signed char pan_, unsigne
 	srnd=opt;
 }
 
-void ayGetInfo(struct ayinfo *info)
+void __attribute__ ((visibility ("internal"))) ayGetInfo(struct ayinfo *info)
 {
 	info->track=ay_track+1;
 	info->numtracks=aydata.num_tracks;
@@ -1144,7 +1144,7 @@ void ayGetInfo(struct ayinfo *info)
 }
 
 
-void ayStartSong(int song)
+void __attribute__ ((visibility ("internal"))) ayStartSong(int song)
 {
 	new_ay_track=song-1;
 }
