@@ -243,6 +243,15 @@ static int ayProcessKey(uint16_t key)
 
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp('p', "Start/stop pause with fade");
+			cpiKeyHelp('P', "Start/stop pause with fade");
+			cpiKeyHelp(KEY_CTRL_P, "Start/stop pause");
+			cpiKeyHelp('<', "Jump to previous track");
+			cpiKeyHelp('>', "Jump to next track");
+			if (plrProcessKey)
+				plrProcessKey(key);
+			return 0;
 		case 'p': case 'P':
 			startpausefade();
 			break;
@@ -274,7 +283,6 @@ static int ayProcessKey(uint16_t key)
 			break;
 
 		default:
-
 			if (plrProcessKey)
 			{
 				int ret=plrProcessKey(key);
