@@ -30,19 +30,19 @@ enum cb_action_tag
 extern int action_callback(enum cb_action_tag action);
 #endif
 
-extern int ay_do_interrupt(void);
-extern unsigned int ay_in(int h,int l);
-extern unsigned int ay_out(int h,int l,int a);
+extern int __attribute__ ((visibility ("internal"))) ay_do_interrupt(void);
+extern unsigned int __attribute__ ((visibility ("internal"))) ay_in(int h,int l);
+extern unsigned int __attribute__ ((visibility ("internal"))) ay_out(int h,int l,int a);
 
-extern unsigned char ay_mem[];
-extern unsigned long ay_tstates,ay_tsmax;
+extern __attribute__ ((visibility ("internal"))) unsigned char ay_mem[];
+extern __attribute__ ((visibility ("internal"))) unsigned long ay_tstates,ay_tsmax;
 #ifdef STIAN
 extern int highspeed,playing,paused,want_quit;
 extern int stopafter,fadetime;
 extern int use_ui,play_to_stdout;
 extern char **ay_filenames;
 extern int ay_file,ay_num_files;
-extern int ay_track;
+extern __attribute__ ((visibility ("internal"))) int ay_track;
 #endif
 
 struct aydata_tag
@@ -67,9 +67,9 @@ struct ay_track_tag
 
 #ifdef STIAN
 
-extern struct aydata_tag aydata;
+extern __attribute__ ((visibility ("internal"))) struct aydata_tag aydata;
 #endif
 
 struct time_tag { int min,sec,subsecframes; };
-extern struct time_tag ay_tunetime;
+extern __attribute__ ((visibility ("internal"))) struct time_tag ay_tunetime;
 
