@@ -45,10 +45,10 @@ int sound_enabled=0;
 int sound_freq=44100;
 int sound_stereo=1;		/* true for stereo *output sample* (only) */
 #endif
-int sound_stereo_beeper=0;	/* beeper pseudo-stereo */
-int sound_stereo_ay=1;		/* AY stereo separation */
-int sound_stereo_ay_abc=0;	/* (AY stereo) true for ABC stereo, else ACB */
-int sound_stereo_ay_narrow=0;	/* (AY stereo) true for narrow AY st. sep. */
+__attribute__ ((visibility ("internal"))) int sound_stereo_beeper=0;	/* beeper pseudo-stereo */
+__attribute__ ((visibility ("internal"))) int sound_stereo_ay=1;		/* AY stereo separation */
+__attribute__ ((visibility ("internal"))) int sound_stereo_ay_abc=0;	/* (AY stereo) true for ABC stereo, else ACB */
+__attribute__ ((visibility ("internal"))) int sound_stereo_ay_narrow=0;	/* (AY stereo) true for narrow AY st. sep. */
 
 #define AY_CLOCK		1773400
 #define AY_CLOCK_CPC		1000000
@@ -103,7 +103,7 @@ static struct ay_change_tag ay_change[AY_CHANGE_MAX];
 static int ay_change_count;
 
 static int fading=0,fadetotal;
-int fadetime;
+static int fadetime;
 
 #define STEREO_BUF_SIZE 1024
 
@@ -115,7 +115,7 @@ static int rstereopos,rchan1pos,rchan2pos,rchan3pos;
 
 
 
-void sound_ay_init(void)
+static void sound_ay_init(void)
 {
 /* AY output doesn't match the claimed levels; these levels are based
  * on the measurements posted to comp.sys.sinclair in Dec 2001 by
@@ -149,7 +149,7 @@ ay_change_count=0;
 }
 
 
-int sound_init(void)
+int __attribute__ ((visibility ("internal"))) sound_init(void)
 {
 int f;
 /*
@@ -206,7 +206,7 @@ return(1);
 }
 
 
-void sound_end(void)
+void __attribute__ ((visibility ("internal"))) sound_end(void)
 {
 /*if(sound_enabled)
   {*/
@@ -219,7 +219,7 @@ void sound_end(void)
 
 
 /* write sample to buffer as pseudo-stereo */
-void sound_write_buf_pstereo(signed short *out,int c)
+static void sound_write_buf_pstereo(signed short *out,int c)
 {
 int bl=(c-pstereobuf[pstereopos])/2;
 int br=(c+pstereobuf[pstereopos])/2;
@@ -538,7 +538,7 @@ for(f=0,ptr=sound_buf;f<sound_framesiz;f++)
 /* don't make the change immediately; record it for later,
  * to be made by sound_frame() (via sound_ay_overlay()).
  */
-void sound_ay_write(int reg,int val,unsigned long tstates)
+void __attribute__ ((visibility ("internal"))) sound_ay_write(int reg,int val,unsigned long tstates)
 {
 /*if(!sound_enabled) return;*/
 
@@ -557,7 +557,7 @@ if(ay_change_count<AY_CHANGE_MAX)
 /* no need to call this initially, but should be called
  * on reset otherwise.
  */
-void sound_ay_reset(void)
+void __attribute__ ((visibility ("internal"))) sound_ay_reset(void)
 {
 int f;
 
@@ -574,7 +574,7 @@ CLOCK_RESET(AY_CLOCK);	/* in case it was CPC before */
 }
 
 
-void sound_ay_reset_cpc(void)
+void __attribute__ ((visibility ("internal"))) sound_ay_reset_cpc(void)
 {
 sound_ay_reset();
 
@@ -602,7 +602,7 @@ CLOCK_RESET(AY_CLOCK_CPC);
 
 
 /* returns zero if this frame was completely silent */
-int sound_frame(int really_play)
+int __attribute__ ((visibility ("internal"))) sound_frame(int really_play)
 {
 static int silent_level=-1;
 signed short *ptr;
@@ -682,7 +682,7 @@ return(!silent);
 
 #if 0
 /* don't do a real frame, just play silence to keep things sane. */
-void sound_frame_blank(void)
+void __attribute__ ((visibility ("internal"))) sound_frame_blank(void)
 {
 static int first=1;
 static signed short buf[2048];		/* should be plenty */
@@ -704,13 +704,13 @@ if(sizeof(buf)<fulllen)
 ay_driver_frame(buf,fulllen);
 }
 #endif
-void sound_start_fade(int fadetime_in_sec)
+void __attribute__ ((visibility ("internal"))) sound_start_fade(int fadetime_in_sec)
 {
 fading=1;
 fadetime=fadetotal=fadetime_in_sec*sound_freq;
 }
 
-void sound_beeper(int on)
+void __attribute__ ((visibility ("internal"))) sound_beeper(int on)
 {
 signed short *ptr;
 int newpos;
