@@ -45,7 +45,7 @@ struct gmdinstrument
 
 struct sampleinfo;
 
-extern void gmdInstSetup(const struct gmdinstrument *ins, int nins, const struct gmdsample *smp, int nsmp, const struct sampleinfo *smpi, int nsmpi, int type, void (*MarkyBoy)(uint8_t *, uint8_t *));
-extern void gmdInstClear(void);
+extern void __attribute__ ((visibility ("internal"))) gmdInstSetup(const struct gmdinstrument *ins, int nins, const struct gmdsample *smp, int nsmp, const struct sampleinfo *smpi, int nsmpi, int type, void (*MarkyBoy)(uint8_t *, uint8_t *));
+extern void __attribute__ ((visibility ("internal"))) gmdInstClear(void);
 
 #endif
