@@ -51,7 +51,7 @@ static const unsigned char envsin[513]=
 };
 
 
-int mpLoadAMS(struct gmdmodule *m, FILE *file)
+static int _mpLoadAMS(struct gmdmodule *m, FILE *file)
 {
 	int retval;
 
@@ -1153,4 +1153,6 @@ safeout:
 	return retval;
 }
 
+struct gmdloadstruct mpLoadAMS = { _mpLoadAMS };
+
 struct linkinfostruct dllextinfo = {"gmdlams", "OpenCP Module Loader: *.669 (c) 1994-04 Niklas Beisert", DLLVERSION, 0};
