@@ -117,7 +117,7 @@ static void calctempo(uint16_t rpm, uint8_t *tempo, uint8_t *bpm)
 	(*bpm)=rpm*(*tempo)/24;
 }
 
-int mpLoadDMF(struct gmdmodule *m, FILE *file)
+static int _mpLoadDMF(struct gmdmodule *m, FILE *file)
 {
 	struct __attribute__((packed)) {
 		uint8_t sig[4];
@@ -737,4 +737,7 @@ int mpLoadDMF(struct gmdmodule *m, FILE *file)
 
 	return errOk;
 }
+
+struct gmdloadstruct mpLoadDMF = { _mpLoadDMF };
+
 struct linkinfostruct dllextinfo = {"gmdldmf", "OpenCP Module Loader: *.DMF (c) 1994-04 Niklas Beisert", DLLVERSION, 0};
