@@ -97,7 +97,7 @@ static inline void putcmd(unsigned char **p, unsigned char c, unsigned char d)
   *(*p)++=d;
 }
 
-int mpLoadMDL(struct gmdmodule *m, FILE *file)
+static int _mpLoadMDL(struct gmdmodule *m, FILE *file)
 {
 	uint32_t waste1;
 	uint16_t waste2;
@@ -1168,4 +1168,7 @@ int mpLoadMDL(struct gmdmodule *m, FILE *file)
 
 	return errOk;
 }
+
+struct gmdloadstruct mpLoadMDL = { _mpLoadMDL };
+
 struct linkinfostruct dllextinfo = {"gmdlmdl", "OpenCP Module Loader: *.MDL (c) 1994-04 Niklas Beisert", DLLVERSION, 0};
