@@ -25,7 +25,7 @@ static inline void putcmd(uint8_t **p, uint8_t c, uint8_t d)
 	*(*p)++=d;
 }
 
-int mpLoadOKT(struct gmdmodule *m, FILE *file)
+static int _mpLoadOKT(struct gmdmodule *m, FILE *file)
 {
 
 	uint8_t sig[8];
@@ -435,4 +435,6 @@ int mpLoadOKT(struct gmdmodule *m, FILE *file)
 	return errOk;
 }
 
+struct gmdloadstruct mpLoadOKT = { _mpLoadOKT };
+
 struct linkinfostruct dllextinfo = {"gmdlokt", "OpenCP Module Loader: *.OKT (c) 1994-04 Niklas Beisert", DLLVERSION, 0};
