@@ -24,7 +24,7 @@ static inline void putcmd(uint8_t **p, uint8_t c, uint8_t d)
 	*(*p)++=d;
 }
 
-int mpLoadPTM(struct gmdmodule *m, FILE *file)
+static int _mpLoadPTM(struct gmdmodule *m, FILE *file)
 {
 
 	int16_t t;
@@ -615,4 +615,6 @@ int mpLoadPTM(struct gmdmodule *m, FILE *file)
 	return errOk;
 }
 
+struct gmdloadstruct mpLoadPTM = { _mpLoadPTM };
+
 struct linkinfostruct dllextinfo = {"gmdlptm", "OpenCP Module Loader: *.PTM (c) 1994-04 Niklas Beisert", DLLVERSION, 0};
