@@ -28,7 +28,7 @@ static inline void putcmd(uint8_t **p, uint8_t c, uint8_t d)
 	*(*p)++=d;
 }
 
-int mpLoadS3M(struct gmdmodule *m, FILE *file)
+static int _mpLoadS3M(struct gmdmodule *m, FILE *file)
 {
 	int t,i;
 	uint8_t orders[256];
@@ -768,4 +768,7 @@ int mpLoadS3M(struct gmdmodule *m, FILE *file)
 
 	return errOk;
 }
+
+struct gmdloadstruct mpLoadS3M = { _mpLoadS3M };
+
 struct linkinfostruct dllextinfo = {"gmdls3m", "OpenCP Module Loader: *.669 (c) 1994-04 Niklas Beisert, Tammo Hinrichs", DLLVERSION, 0};
