@@ -24,7 +24,7 @@ static inline void putcmd(uint8_t **p, uint8_t c, uint8_t d)
 	*(*p)++=d;
 }
 
-int mpLoadULT(struct gmdmodule *m, FILE *file)
+static int _mpLoadULT(struct gmdmodule *m, FILE *file)
 {
 	char id[15];
 	uint8_t ver;
@@ -555,4 +555,7 @@ int mpLoadULT(struct gmdmodule *m, FILE *file)
 
 	return errOk;
 }
+
+struct gmdloadstruct mpLoadULT = { _mpLoadULT };
+
 struct linkinfostruct dllextinfo = {"gmdlult", "OpenCP Module Loader: *.ULT (c) 1994-04 Niklas Beisert", DLLVERSION, 0};
