@@ -11,13 +11,14 @@
 #include "config.h"
 #include <stdio.h> /* FILE is defined here */
 #include "types.h"
+#include "cpiface/cpiface.h"
 #include "dev/mcp.h"
 #include "gmdplay.h"
-#include "cpiface/cpiface.h"
+#include "gmdpdots.h"
 
 /*extern unsigned short plNLChan;*/
 
-int gmdGetDots(struct notedotsdata *d, int max)
+int __attribute__ ((visibility ("internal"))) gmdGetDots(struct notedotsdata *d, int max)
 {
 	int pos=0;
 	int i;
