@@ -225,7 +225,7 @@ static void gmdMark(void)
 	Mark(plInstUsed, plSampUsed);
 }
 
-void gmdInstClear(void)
+void __attribute__ ((visibility ("internal"))) gmdInstClear(void)
 {
 	memset(plInstUsed, 0, instnum);
 	memset(plSampUsed, 0, sampnum);
@@ -239,7 +239,7 @@ static void Done(void)
 	free(plBigSampNum);
 }
 
-void gmdInstSetup(const struct gmdinstrument *ins, int nins, const struct gmdsample *smp, int nsmp, const struct sampleinfo *smpi, int _notused, int type, void (*MarkyBoy)(uint8_t *, uint8_t *))
+void __attribute__ ((visibility ("internal"))) gmdInstSetup(const struct gmdinstrument *ins, int nins, const struct gmdsample *smp, int nsmp, const struct sampleinfo *smpi, int _notused, int type, void (*MarkyBoy)(uint8_t *, uint8_t *))
 {
 	int i,j;
 	int biginstlen;
