@@ -21,7 +21,6 @@
 #include "dev/mcp.h"
 #include "gmdplay.h"
 #include "stuff/imsrtns.h"
-#include "boot/pmain.h"
 
 #define MAXLCHAN MP_MAXCHANNELS
 #define MAXPCHAN 32
@@ -1518,7 +1517,7 @@ static void PlayTick(void)
 	putque(cmdtime, -1, (currentrow<<8)|(currentpattern<<16), 0);
 }
 
-char mpPlayModule(const struct gmdmodule *m)
+char __attribute__ ((visibility ("internal"))) mpPlayModule(const struct gmdmodule *m)
 {
 	int i;
 	for (i=65; i<=128; i++)
@@ -1592,7 +1591,7 @@ char mpPlayModule(const struct gmdmodule *m)
 	return 1;
 }
 
-void mpStopModule(void)
+void __attribute__ ((visibility ("internal"))) mpStopModule(void)
 {
 	int i;
 	for (i=0; i<physchan; i++)
@@ -1601,7 +1600,7 @@ void mpStopModule(void)
 	free(que);
 }
 
-void mpGetChanInfo(uint8_t ch, struct chaninfo *ci)
+void __attribute__ ((visibility ("internal"))) mpGetChanInfo(uint8_t ch, struct chaninfo *ci)
 {
 	const struct trackdata *t=&tdata[ch];
 	ci->ins=0xFF;
@@ -1629,7 +1628,7 @@ void mpGetChanInfo(uint8_t ch, struct chaninfo *ci)
 
 
 
-uint16_t mpGetRealNote(uint8_t ch)
+uint16_t __attribute__ ((visibility ("internal"))) mpGetRealNote(uint8_t ch)
 {
 	struct trackdata *td=&tdata[ch];
 	if (exponential)
@@ -1639,7 +1638,7 @@ uint16_t mpGetRealNote(uint8_t ch)
   /*    return td.nteval<<8; */
 }
 
-void mpGetGlobInfo(struct globinfo *gi)
+void __attribute__ ((visibility ("internal"))) mpGetGlobInfo(struct globinfo *gi)
 {
 	int i;
 
@@ -1657,19 +1656,19 @@ void mpGetGlobInfo(struct globinfo *gi)
 			gi->globvolslide=globalvolslide[i];
 }
 
-void mpGetPosition(uint16_t *pat, uint8_t *row)
+void __attribute__ ((visibility ("internal"))) mpGetPosition(uint16_t *pat, uint8_t *row)
 {
 	*pat=currentpattern;
 	*row=currentrow;
 }
 
-int mpGetRealPos(void)
+int __attribute__ ((visibility ("internal"))) mpGetRealPos(void)
 {
 	readque();
 	return realpos;
 }
 
-void mpSetPosition(int16_t pat, int16_t row)
+void __attribute__ ((visibility ("internal"))) mpSetPosition(int16_t pat, int16_t row)
 {
 	unsigned int i;
 	if (row<0)
@@ -1727,17 +1726,17 @@ void mpSetPosition(int16_t pat, int16_t row)
 	currenttick=tempo;
 }
 
-char mpLooped(void)
+char __attribute__ ((visibility ("internal"))) mpLooped(void)
 {
 	return looped;
 }
 
-void mpSetLoop(uint8_t s)
+void __attribute__ ((visibility ("internal"))) mpSetLoop(uint8_t s)
 {
 	donotloopmodule=!s;
 }
 
-void mpLockPat(int st)
+void __attribute__ ((visibility ("internal"))) mpLockPat(int st)
 {
 	if (st)
 		lockpattern=currentpattern;
@@ -1745,7 +1744,7 @@ void mpLockPat(int st)
 		lockpattern=-1;
 }
 
-int mpGetChanSample(int ch, short *buf, int len, uint32_t rate, int opt)
+int __attribute__ ((visibility ("internal"))) mpGetChanSample(int ch, int16_t *buf, int len, uint32_t rate, int opt)
 {
 	if (tdata[ch].phys==-1)
 	{
@@ -1755,26 +1754,26 @@ int mpGetChanSample(int ch, short *buf, int len, uint32_t rate, int opt)
 	return mcpGetChanSample(tdata[ch].phys, buf, len, rate, opt);
 }
 
-void mpMute(int ch, int mute)
+void __attribute__ ((visibility ("internal"))) mpMute(int ch, int mute)
 {
        	tdata[ch].mute=mute;
 	if (tdata[ch].phys!=-1)
 		mcpSet(tdata[ch].phys, mcpCMute, mute);
 }
 
-int mpGetMute(int ch)
+int __attribute__ ((visibility ("internal"))) mpGetMute(int ch)
 {
 	return tdata[ch].mute;
 }
 
-int mpGetChanStatus(int ch)
+int __attribute__ ((visibility ("internal"))) mpGetChanStatus(int ch)
 {
 	if (tdata[ch].phys==-1)
 		return 0;
 	return mcpGet(tdata[ch].phys, mcpCStatus);
 }
 
-void mpGetRealVolume(int ch, int *l, int *r)
+void __attribute__ ((visibility ("internal"))) mpGetRealVolume(int ch, int *l, int *r)
 {
 	if (tdata[ch].phys==-1)
 	{
@@ -1784,7 +1783,7 @@ void mpGetRealVolume(int ch, int *l, int *r)
 	mcpGetRealVolume(tdata[ch].phys, l, r);
 }
 
-int mpLoadSamples(struct gmdmodule *m)
+int __attribute__ ((visibility ("internal"))) mpLoadSamples(struct gmdmodule *m)
 {
 	return mcpLoadSamples(m->samples, m->sampnum);
 }
