@@ -21,19 +21,22 @@
 #include "dev/mcp.h"
 #include "boot/psetting.h"
 #include "gmdplay.h"
+#include "cpiface/cpiface.h"
+#include "gmdpchan.h"
+#include "gmdpdots.h"
+#include "gmdptrak.h"
 #include "filesel/pfilesel.h"
 #include "stuff/compat.h"
 #include "stuff/poutput.h"
 #include "stuff/err.h"
 #include "boot/plinkman.h"
 #include "dev/deviwave.h"
-#include "cpiface/cpiface.h"
 #include "stuff/compat.h"
 
 #define _MAX_FNAME 8
 #define _MAX_EXT 4
 
-int gmdActive;
+static int gmdActive;
 
 static const char *modname;
 static const char *composer;
@@ -170,13 +173,6 @@ static void dopausefade(void)
 	mcpSetFadePars(i);
 }
 
-
-int gmdTrkProcessKey(uint16_t key);
-void gmdChanSetup(const struct gmdmodule *);
-void gmdTrkSetup(const struct gmdmodule *m);
-int gmdGetDots(struct notedotsdata *, int);
-void gmdDrawPattern(uint8_t sel);
-
 static void gmdDrawGStrings(unsigned short (*buf)[CONSOLE_MAX_X])
 {
 	struct globinfo gi;
@@ -248,10 +244,18 @@ static int gmdProcessKey(unsigned short key)
 {
 	uint16_t pat; 
 	uint8_t row;
-	if (mcpSetProcessKey(key))
-		return 1;
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp('p', "Start/stop pause with fade");
+			cpiKeyHelp('P', "Start/stop pause with fade");
+			cpiKeyHelp(KEY_CTRL_P, "Start/stop pause");
+			cpiKeyHelp('<', "Jump to previous track");
+			cpiKeyHelp('>', "Jump to next track");
+			mcpSetProcessKey(key);
+			if (mcpProcessKey)
+				mcpProcessKey(key);
+			return 0;
 #if 0
 		case 0x1900: /* TODO keys */
 			while (!dkbhit())
@@ -310,6 +314,8 @@ static int gmdProcessKey(unsigned short key)
 			mpLockPat(patlock);
 			break;*/
 		default:
+			if (mcpSetProcessKey(key))
+				return 1;
 			if (mcpProcessKey)
 			{
 				int ret=mcpProcessKey(key);
@@ -460,5 +466,5 @@ static int gmdOpenFile(const char *path, struct moduleinfostruct *info, FILE *fi
 
 struct cpifaceplayerstruct gmdPlayer = {gmdOpenFile, gmdCloseFile};
 
-char *dllinfo = "player gmdPlayer";
+char *dllinfo = "";
 struct linkinfostruct dllextinfo = {"playgmd", "OpenCP General Module Player (c) 1994-04 Niklas Beisert, Tammo Hinrichs", DLLVERSION, 0};
