@@ -15,6 +15,7 @@
 #include "gmdplay.h"
 #include "stuff/poutput.h"
 #include "cpiface/cpiface.h"
+#include "gmdptrak.h"
 
 #define COLPTNOTE 0x0A
 #define COLNOTE 0x0F
@@ -454,7 +455,7 @@ static struct cpitrakdisplaystruct gmdptrkdisplay=
 };
 
 
-void gmdTrkSetup(const struct gmdmodule *mod)
+void __attribute__ ((visibility ("internal"))) gmdTrkSetup(const struct gmdmodule *mod)
 {
 	plPatterns=mod->patterns;
 	plOrders=mod->orders;
