@@ -269,4 +269,4 @@ static int gmdReadInfo(struct moduleinfostruct *m, FILE *fp, const char *buf, si
 	return 0;
 }
 
-struct mdbreadnforegstruct gmdReadInfoReg = {gmdReadMemInfo, gmdReadInfo};
+struct mdbreadinforegstruct gmdReadInfoReg = {gmdReadMemInfo, gmdReadInfo};
