@@ -228,11 +228,11 @@ struct FFF_DATA_LIST
 };
 
 
-struct FFF_ENVP_LIST *envp_list=0;
-struct FFF_PTCH_LIST *ptch_list=0;
-struct FFF_DATA_LIST *data_list=0;
+static struct FFF_ENVP_LIST *envp_list=0;
+static struct FFF_PTCH_LIST *ptch_list=0;
+static struct FFF_DATA_LIST *data_list=0;
 
-void *getENVP(uint32_t id)
+static void *getENVP(uint32_t id)
 {
 	struct FFF_ENVP_LIST *l=envp_list;
 
@@ -246,7 +246,7 @@ void *getENVP(uint32_t id)
 	return 0;
 }
 
-void *getDATA(uint32_t id)
+static void *getDATA(uint32_t id)
 {
 	struct FFF_DATA_LIST *l=data_list;
 
@@ -621,16 +621,17 @@ static void closeFFF(void)
 	}
 }
 
-int addpatchFFF( struct minstrument *ins,
-                 uint8_t             program,
-                 uint8_t             sn,
-                 uint8_t             sampnum,
-                 struct sampleinfo  *sip,
-                 uint16_t           *samplenum)
+/*
+static int addpatchFFF( struct minstrument *ins,
+                        uint8_t             program,
+                        uint8_t             sn,
+                        uint8_t             sampnum,
+                        struct sampleinfo  *sip,
+                        uint16_t           *samplenum)
 {
 	return 0;
 }
-
+*/
 /*
  * instrument name table for .FFF files (melodic bank, after GM standard)
  */
@@ -679,11 +680,11 @@ static char *gmins_melo[]={
 	"Helicopter", "Applause", "Gun Shot"
 };
 
-int loadpatchFFF(struct minstrument *ins,
-                 uint8_t             program,
-                 uint8_t            *sampused,
-                 struct sampleinfo **smps,
-                 uint16_t           *samplenum)
+static int loadpatchFFF(struct minstrument *ins,
+                        uint8_t             program,
+                        uint8_t            *sampused,
+                        struct sampleinfo **smps,
+                        uint16_t           *samplenum)
 {
 	struct FFF_PTCH_LIST *pl=ptch_list;
 	struct FFF_PTCH_CHUNK *patch;
@@ -870,7 +871,7 @@ int loadpatchFFF(struct minstrument *ins,
 	return errOk;
 }
 
-int midInitFFF(void)
+int __attribute__ ((visibility ("internal"))) midInitFFF(void)
 {
 	FILE *fff;
 	const char *fn=cfGetProfileString("midi", "fff", "midi.fff");
