@@ -69,20 +69,22 @@
 #include "stuff/err.h"
 #include "stuff/imsrtns.h"
 
-int (*loadpatch)( struct minstrument *ins,
-                  uint8_t             program,
-                  uint8_t            *sampused,
-                  struct sampleinfo **smps,
-                  uint16_t           *samplenum) = 0;
+int __attribute__ ((visibility ("internal")))
+	(*loadpatch)( struct minstrument *ins,
+	              uint8_t             program,
+	              uint8_t            *sampused,
+	              struct sampleinfo **smps,
+	              uint16_t           *samplenum) = 0;
 
-int (*addpatch)( struct minstrument *ins,
-                 uint8_t             program,
-                 uint8_t             sn,
-                 uint8_t             sampnum,
-                 struct sampleinfo  *sip,
-                 uint16_t           *samplenum) = 0;
+int __attribute__ ((visibility ("internal")))
+	(*addpatch)( struct minstrument *ins,
+	             uint8_t             program,
+	             uint8_t             sn,
+	             uint8_t             sampnum,
+	             struct sampleinfo  *sip,
+	             uint16_t           *samplenum) = 0;
 
-char midInstrumentNames[256][NAME_MAX+1];
+__attribute__ ((visibility ("internal"))) char midInstrumentNames[256][NAME_MAX+1];
 
 static inline unsigned long readvlnum(unsigned char **ptr)
 {
@@ -96,7 +98,7 @@ static inline unsigned long readvlnum(unsigned char **ptr)
 	return num;
 }
 
-char midLoadMidi( struct midifile *m,
+char __attribute__ ((visibility ("internal"))) midLoadMidi( struct midifile *m,
                   FILE            *file,
                   uint32_t         opt)
 {
@@ -386,14 +388,14 @@ char midLoadMidi( struct midifile *m,
 	return errOk;
 }
 
-void mid_reset(struct midifile *mf)
+void __attribute__ ((visibility ("internal"))) mid_reset(struct midifile *mf)
 {
 	mf->tracks=0;
 	mf->instruments=0;
 	mf->samples=0;
 }
 
-void mid_free(struct midifile *mf)
+void __attribute__ ((visibility ("internal"))) mid_free(struct midifile *mf)
 {
 	int i;
 	if (mf->tracks)
