@@ -99,35 +99,26 @@ static inline void PATCHDATA_endian(struct PATCHDATA *a) {
 struct minstrument;
 struct sampleinfo;
 
-extern int loadsamplePAT( int                 file,
-                          struct minstrument *ins,
-                          uint8_t             j,
-                          uint8_t             vox,
-                          int                 setnote, /* local boolean */
-                          uint8_t             sampnum,
-                          uint8_t            *sampused,
-                          struct sampleinfo  *sip,
-                          uint16_t           *samplenum);
+extern int __attribute__ ((visibility ("internal")))
+loadpatchPAT( int file,
+              struct minstrument *ins,
+              uint8_t             program,
+              uint8_t            *sampused,
+              struct sampleinfo **smps,
+              uint16_t           *samplenum);
 
-extern int loadpatchPAT( int file,
-                         struct minstrument *ins,
-                         uint8_t             program,
-                         uint8_t            *sampused,
-                         struct sampleinfo **smps,
-                         uint16_t           *samplenum);
+extern int __attribute__ ((visibility ("internal")))
+addpatchPAT ( int                 file,
+              struct minstrument *ins,
+              uint8_t             program,
+              uint8_t             sn,
+              uint8_t             sampnum,
+              struct sampleinfo  *sip,
+              uint16_t           *samplenum);
 
-
-extern int addpatchPAT ( int                 file,
-                         struct minstrument *ins,
-                         uint8_t             program,
-                         uint8_t             sn,
-                         uint8_t             sampnum,
-                         struct sampleinfo  *sip,
-                         uint16_t           *samplenum);
-
-extern uint32_t pocttab[16];
-extern uint16_t pnotetab[12];
-extern uint16_t pfinetab[16];
-extern uint16_t pxfinetab[16];
+extern __attribute__ ((visibility ("internal"))) uint32_t pocttab[16];
+extern __attribute__ ((visibility ("internal"))) uint16_t pnotetab[12];
+extern __attribute__ ((visibility ("internal"))) uint16_t pfinetab[16];
+extern __attribute__ ((visibility ("internal"))) uint16_t pxfinetab[16];
 
 #endif
