@@ -15,7 +15,7 @@
 #include "gmiplay.h"
 #include "cpiface/cpiface.h"
 
-int gmiGetDots(struct notedotsdata *d, int max)
+int __attribute__ ((visibility ("internal"))) gmiGetDots(struct notedotsdata *d, int max)
 {
 	int i,j;
 	int pos=0;
