@@ -16,9 +16,9 @@
 #include "stuff/poutput.h"
 #include "cpiface/cpiface.h"
 
-uint8_t plInstUsed[256];
-uint8_t plSampUsed[1024];
-uint16_t plInstSampNum[256];
+static uint8_t plInstUsed[256];
+static uint8_t plSampUsed[1024];
+static uint16_t plInstSampNum[256];
 
 static const struct minstrument *plMInstr;
 static const struct sampleinfo *plSamples;
@@ -216,13 +216,13 @@ static void gmiMarkIns(void)
 	}
 }
 
-void gmiClearInst(void)
+void __attribute__ ((visibility ("internal")))gmiClearInst(void)
 {
 	memset(plInstUsed, 0, 256);
 	memset(plSampUsed, 0, 1024);
 }
 
-void gmiInsSetup(const struct midifile *mid)
+void __attribute__ ((visibility ("internal"))) gmiInsSetup(const struct midifile *mid)
 {
 	struct insdisplaystruct plInsDisplay;
 	int i;
