@@ -571,7 +571,7 @@ static void PlayTick(void)
 		}
 }
 
-int midPlayMidi(const struct midifile *m, uint8_t voices)
+int __attribute__ ((visibility ("internal"))) midPlayMidi(const struct midifile *m, uint8_t voices)
 {
 	int i;
 
@@ -624,24 +624,24 @@ int midPlayMidi(const struct midifile *m, uint8_t voices)
 	return 1;
 }
 
-void midStopMidi(void)
+void __attribute__ ((visibility ("internal"))) midStopMidi(void)
 {
 	mcpClosePlayer();
 }
 
-uint32_t midGetPosition(void)
+uint32_t __attribute__ ((visibility ("internal"))) midGetPosition(void)
 {
 	return outtick;
 }
 
-void midSetPosition(int32_t pos)
+void __attribute__ ((visibility ("internal"))) midSetPosition(int32_t pos)
 {
 	if ((pos<0)||(pos>=ticknum))
 		pos=0;
 	outtick=pos;
 }
 
-void midGetChanInfo(uint8_t ch, struct mchaninfo *ci)
+void __attribute__ ((visibility ("internal"))) midGetChanInfo(uint8_t ch, struct mchaninfo *ci)
 {
 	int i,j;
 
@@ -671,7 +671,7 @@ void midGetChanInfo(uint8_t ch, struct mchaninfo *ci)
 			}
 }
 
-void midGetRealNoteVol(uint8_t ch, struct mchaninfo2 *ci)
+void __attribute__ ((visibility ("internal"))) midGetRealNoteVol(uint8_t ch, struct mchaninfo2 *ci)
 {
 	struct mchandata *mc=&mchan[ch];
 	int i;
@@ -692,7 +692,7 @@ void midGetRealNoteVol(uint8_t ch, struct mchaninfo2 *ci)
 		}
 }
 
-void midGetGlobInfo(struct mglobinfo *gi)
+void __attribute__ ((visibility ("internal"))) midGetGlobInfo(struct mglobinfo *gi)
 {
 	gi->curtick=curtick;
 	gi->ticknum=ticknum;
@@ -702,27 +702,27 @@ void midGetGlobInfo(struct mglobinfo *gi)
 		gi->speed=0;
 }
 
-void midSetMute(int ch, int p)
+void __attribute__ ((visibility ("internal"))) midSetMute(int ch, int p)
 {
 	mchan[ch].mute=p;
 }
 
-uint8_t midGetMute(uint8_t ch)
+uint8_t __attribute__ ((visibility ("internal"))) midGetMute(uint8_t ch)
 {
 	return mchan[ch].mute;
 }
 
-int midLooped(void)
+int __attribute__ ((visibility ("internal"))) midLooped(void)
 {
 	return looped;
 }
 
-void midSetLoop(int s)
+void __attribute__ ((visibility ("internal"))) midSetLoop(int s)
 {
 	donotloop=!s;
 }
 
-int midGetChanSample(int ch, int16_t *buf, int len, uint32_t rate, int opt)
+int __attribute__ ((visibility ("internal"))) midGetChanSample(int ch, int16_t *buf, int len, uint32_t rate, int opt)
 {
 	int i,n;
 	int chn[MAXCHAN];
@@ -734,7 +734,7 @@ int midGetChanSample(int ch, int16_t *buf, int len, uint32_t rate, int opt)
 	return 1;
 }
 
-int mid_loadsamples(struct midifile *m)
+int __attribute__ ((visibility ("internal"))) mid_loadsamples(struct midifile *m)
 {
 	return mcpLoadSamples(m->samples, m->sampnum);
 }
