@@ -96,10 +96,18 @@ static void gmiDrawGStrings(uint16_t (*buf)[CONSOLE_MAX_X])
 
 static int gmiProcessKey(unsigned short key)
 {
-	if (mcpSetProcessKey(key))
-		return 1;
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp('p', "Start/stop pause");
+			cpiKeyHelp('P', "Start/stop pause");
+			cpiKeyHelp(KEY_CTRL_P, "Start/stop pause");
+			cpiKeyHelp('<', "Jump to previous track");
+			cpiKeyHelp('>', "Jump to next track");
+			mcpSetProcessKey(key);
+			if (mcpProcessKey)
+				mcpProcessKey(key);
+			return 0;
 		case 'p': case 'P':
 		case KEY_CTRL_P:
 			if (plPause)
@@ -137,6 +145,8 @@ static int gmiProcessKey(unsigned short key)
 			midSetPosition(midGetPosition()+(mid.ticknum>>8));
 			break;*/
 		default:
+			if (mcpSetProcessKey(key))
+				return 1;
 			if (mcpProcessKey)
 			{
 				int ret=mcpProcessKey(key);
