@@ -117,4 +117,4 @@ static int gmiReadInfo(struct moduleinfostruct *m, FILE *fp, const char *mem, si
 	return 0;
 }
 
-struct mdbreadnforegstruct gmiReadInfoReg = {gmiReadMemInfo, gmiReadInfo};
+struct mdbreadinforegstruct gmiReadInfoReg = {gmiReadMemInfo, gmiReadInfo};
