@@ -30,7 +30,7 @@
 #include "dev/mcp.h"
 #include "stuff/err.h"
 
-int it_load(struct it_module *this, FILE *file)
+int __attribute__ ((visibility ("internal"))) it_load(struct it_module *this, FILE *file)
 {
 	int i,j,k,n;
 
@@ -187,7 +187,10 @@ int it_load(struct it_module *this, FILE *file)
 		char cmd[33];
 
 		if (!(this->midicmds=malloc(sizeof(char *)*(9+16+128))))
+		{
+			fprintf(stderr, __FILE__ ": malloc(%d) failed #1\n", sizeof(char *)*(9+16+128));
 			return errAllocMem;
+		}
 
 		memset(cmd,0,sizeof(cmd));
 
@@ -198,7 +201,10 @@ int it_load(struct it_module *this, FILE *file)
 				if (!cmd[n])
 					cmd[n]=32;
 			if (!(this->midicmds[i]=malloc(sizeof(char)*(strlen(cmd)+1))))
+			{
+				fprintf(stderr, __FILE__ ": malloc(%d) failed #2\n", sizeof(char)*(strlen(cmd)+1));
 				return errAllocMem;
+			}
 			strcpy(this->midicmds[i], cmd);
 			strupr(this->midicmds[i]);
 		}
@@ -210,7 +216,10 @@ int it_load(struct it_module *this, FILE *file)
 		char *msg;
 
 		if (!(msg=malloc(sizeof(char)*(hdr.msglen+1))))
+		{
+			fprintf(stderr, __FILE__ ": malloc(%d) failed #3\n", sizeof(char)*(hdr.msglen+1));
 			return errAllocMem;
+		}
 		linect=1;
 		fseek(file, hdr.msgoff, SEEK_SET);
 		fread(msg, hdr.msglen, 1, file);
@@ -223,7 +232,10 @@ int it_load(struct it_module *this, FILE *file)
 				linect++;
 		}
 		if (!(this->message=calloc(sizeof(char *), linect+1)))
+		{
+			fprintf(stderr, __FILE__ ": calloc(%d) failed #4\n", sizeof(char *)*linect+1);
 			return errAllocMem;
+		}
 		*this->message=msg;
 		linect=1;
 		for (i=0; i<hdr.msglen; i++)
@@ -263,21 +275,33 @@ int it_load(struct it_module *this, FILE *file)
 	this->endord=i;
 
 	if (!(this->orders=malloc(sizeof(uint16_t)*this->nord)))
+	{
+		fprintf(stderr, __FILE__ ": malloc(%d) failed #5\n", sizeof(uint16_t)*this->nord);
 		return errAllocMem;
+	}
 
 	for (i=0; i<this->nord; i++)
 		this->orders[i]=(ords[i]==254)?0xFFFF:(ords[i]>=hdr.npats)?hdr.npats:ords[i];
 
 	if (!(this->patlens=malloc(sizeof(uint16_t)*this->npat)))
+	{
+		fprintf(stderr, __FILE__ ": malloc(%d) failed #6\n", sizeof(uint16_t)*this->npat);
 		return errAllocMem;
+	}
 	if (!(this->patterns=malloc(sizeof(uint8_t*)*this->npat)))
+	{
+		fprintf(stderr, __FILE__ ": malloc(%d) failed #7\n", sizeof(uint8_t*)*this->npat);
 		return errAllocMem;
+	}
 			
 	this->patlens[this->npat-1]=64;
 	this->patterns[this->npat-1]=malloc(sizeof(uint8_t)*64);
 
 	if (!this->patterns[this->npat-1])
+	{
+		fprintf(stderr, __FILE__ ": malloc(%d) failed #8\n", sizeof(uint8_t)*64);
 		return errAllocMem;
+	}
 
 	memset(this->patterns[this->npat-1], 0, 64);
 
@@ -300,7 +324,10 @@ int it_load(struct it_module *this, FILE *file)
 		{
 			this->patlens[k]=64;
 			if (!(this->patterns[k]=malloc(sizeof(uint8_t)*this->patlens[k])))
+			{
+				fprintf(stderr, __FILE__ ": malloc(%d) failed #9\n", sizeof(uint8_t)*this->patlens[k]);
 				return errAllocMem;
+			}
 			memset(this->patterns[k], 0, this->patlens[k]);
 			continue;
 		}
@@ -313,7 +340,10 @@ int it_load(struct it_module *this, FILE *file)
 		fseek(file, 4, SEEK_CUR);
 
 		if (!(patbuf=malloc(sizeof(uint8_t)*patlen)))
+		{
+			fprintf(stderr, __FILE__ ": malloc(%d) failed #10\n", sizeof(uint8_t)*patlen);
 			return errAllocMem;
+		}
 
 		fread(patbuf, patlen, 1, file);
 
@@ -321,6 +351,7 @@ int it_load(struct it_module *this, FILE *file)
 		if (!(this->patterns[k]=malloc(sizeof(uint8_t)*((6*64+1)*this->patlens[k]))))
 		{
 			free(patbuf);
+			fprintf(stderr, __FILE__ ": malloc(%d) failed #11\n", sizeof(uint8_t)*((6*64+1)*this->patlens[k]));
 			return errAllocMem;
 		}
 
@@ -373,7 +404,11 @@ int it_load(struct it_module *this, FILE *file)
 		{
 			void *new;
 			if (!(new=realloc(this->patterns[k], wp-this->patterns[k])))
-				return errAllocMem;	
+			{
+				/* we loose the pointer for-ever here */
+				fprintf(stderr, __FILE__ ": realloc(%d) failed #12\n", wp-this->patterns[k]);
+				return errAllocMem;
+			}
 			this->patterns[k]=(uint8_t *)new;
 		}
 	}
@@ -389,9 +424,15 @@ int it_load(struct it_module *this, FILE *file)
 	this->nsamp=hdr.nsmps;
 
 	if (!(this->sampleinfos=malloc(sizeof(struct it_sampleinfo)*this->nsampi)))
+	{
+		fprintf(stderr, __FILE__ ": malloc(%d) failed #13\n", sizeof(struct it_sampleinfo)*this->nsampi);
 		return errAllocMem;
+	}
 	if (!(this->samples=malloc(sizeof(struct it_sample)*this->nsamp)))
+	{
+		fprintf(stderr, __FILE__ ": malloc(%d) failed #14\n", sizeof(struct it_sample)*this->nsamp);
 		return errAllocMem;
+	}
 	memset(this->sampleinfos, 0, this->nsampi*sizeof(struct it_sampleinfo));
 	memset(this->samples, 0, this->nsamp*sizeof(struct it_sample));
 
@@ -474,7 +515,10 @@ int it_load(struct it_module *this, FILE *file)
 		sp->packed=(shdr.flags&8?1:0);
 
 		if (!(sip->ptr=malloc((sip->length+512)<<((sip->type&mcpSamp16Bit)?1:0))))
+		{
+			fprintf(stderr, __FILE__ ": malloc(%d) failed #15\n", (sip->length+512)<<((sip->type&mcpSamp16Bit)?1:0));
 			return errAllocMem;
+		}
 	}
 
 	for (i=0; i<hdr.nsmps; i++)
@@ -497,7 +541,10 @@ int it_load(struct it_module *this, FILE *file)
 
 	this->ninst=(hdr.flags&4)?hdr.nins:hdr.nsmps;
 	if (!(this->instruments=malloc(sizeof(struct it_instrument)*this->ninst)))
+	{
+		fprintf(stderr, __FILE__ ": malloc(%d) failed #16\n", sizeof(struct it_instrument)*this->ninst);
 		return errAllocMem;
+	}
 	memset(this->instruments, 0, this->ninst*sizeof(*this->instruments));
 
 	for (k=0; k<this->ninst; k++)
@@ -628,11 +675,10 @@ int it_load(struct it_module *this, FILE *file)
 			}
 		}
 	}
-
 	return 0;
 }
 
-void it_free(struct it_module *this)
+void __attribute__ ((visibility ("internal"))) it_free(struct it_module *this)
 {
 	int i;
 
