@@ -78,7 +78,7 @@ static int it_random(struct itplayer *this)
 	return (this->randseed>>16)&32767;
 }
 
-struct itplayer *staticthis=NULL;
+static struct itplayer *staticthis=NULL;
 
 static int8_t sintab[256] =
 {
@@ -1349,7 +1349,7 @@ static void putchandata(struct itplayer *this, struct it_physchan *p)
 	mcpSet(p->no, mcpCFilterRez, p->reso);
 }
 
-void mutechan(struct itplayer *this, int c, int m)
+void __attribute__ ((visibility ("internal"))) mutechan(struct itplayer *this, int c, int m)
 {
 	if ((c>=0)||(c<this->nchan))
 		this->channels[c].mute=m;
@@ -1438,6 +1438,11 @@ static void putque(struct itplayer *this, int type, int val1, int val2)
        	this->quewpos=(this->quewpos+1)%this->quelen;
 }
 
+static int gettime(void)
+{
+	return mcpGet(-1, mcpGTimer);
+}
+
 static void readque(struct itplayer *this)
 {
 	int i;
@@ -1668,12 +1673,12 @@ static void playtick(struct itplayer *this)
 	putque(this, quePos, -1, (this->curtick&0xFF)|(this->currow<<8)|(this->curord<<16));
 }
 
-int loadsamples(struct it_module *m)
+int __attribute__ ((visibility ("internal"))) loadsamples(struct it_module *m)
 {
 	return mcpLoadSamples(m->sampleinfos, m->nsampi);
 }
 
-int play(struct itplayer *this, const struct it_module *m, int ch)
+int __attribute__ ((visibility ("internal"))) play(struct itplayer *this, const struct it_module *m, int ch)
 {
 	int i;
 	staticthis=this;
@@ -1768,7 +1773,7 @@ int play(struct itplayer *this, const struct it_module *m, int ch)
       	return 1;
 }
 
-void stop(struct itplayer *this)
+void __attribute__ ((visibility ("internal"))) stop(struct itplayer *this)
 {
 	mcpClosePlayer();
 	if (this->channels)
@@ -1788,20 +1793,20 @@ void stop(struct itplayer *this)
 	}
 }
 
-int getpos(struct itplayer *this)
+int __attribute__ ((visibility ("internal"))) getpos(struct itplayer *this)
 {
 	if (this->manualgoto)
 		return (this->gotorow<<8)|(this->gotoord<<16);
 	return (this->curtick&0xFF)|(this->currow<<8)|(this->curord<<16);
 }
 
-int getrealpos(struct itplayer *this)
+int __attribute__ ((visibility ("internal"))) getrealpos(struct itplayer *this)
 {
 	readque(this);
 	return this->realpos;
 }
 
-int getchansample(struct itplayer *this, int ch, int16_t *buf, int len, uint32_t rate, int opt)
+int __attribute__ ((visibility ("internal"))) getchansample(struct itplayer *this, int ch, int16_t *buf, int len, uint32_t rate, int opt)
 {
 	int i,n;
 	int chn[64];
@@ -1813,7 +1818,7 @@ int getchansample(struct itplayer *this, int ch, int16_t *buf, int len, uint32_t
 	return 1;
 }
 
-void itplayer_getrealvol(struct itplayer *this, int ch, int *l, int *r)
+void __attribute__ ((visibility ("internal"))) itplayer_getrealvol(struct itplayer *this, int ch, int *l, int *r)
 {
 	int i, voll, volr;
 	
@@ -1828,7 +1833,7 @@ void itplayer_getrealvol(struct itplayer *this, int ch, int *l, int *r)
 		}
 }
 
-void setpos(struct itplayer *this, int ord, int row)
+void __attribute__ ((visibility ("internal"))) setpos(struct itplayer *this, int ord, int row)
 {
        	int i;
 	if (this->curord!=ord)
@@ -1849,7 +1854,7 @@ void setpos(struct itplayer *this, int ord, int row)
 	this->realpos=(this->gotorow<<8)|(this->gotoord<<16);
 }
 
-int getdotsdata(struct itplayer *this, int ch, int pch, int *smp, int *note, int *voll, int *volr, int *sus)
+int __attribute__ ((visibility ("internal"))) getdotsdata(struct itplayer *this, int ch, int pch, int *smp, int *note, int *voll, int *volr, int *sus)
 {
 	struct it_physchan *p;
 	for (pch=pch; pch<this->npchan; pch++)
@@ -1873,7 +1878,7 @@ int getdotsdata(struct itplayer *this, int ch, int pch, int *smp, int *note, int
 	return pch+1;
 }
 
-void getglobinfo(struct itplayer *this, int *tmp, int *bp, int *gv, int *gs)
+void __attribute__ ((visibility ("internal"))) getglobinfo(struct itplayer *this, int *tmp, int *bp, int *gv, int *gs)
 {
 	readque(this);
 	*tmp=this->realspeed;
@@ -1882,7 +1887,7 @@ void getglobinfo(struct itplayer *this, int *tmp, int *bp, int *gv, int *gs)
 	*gs=this->gvolslide?(this->gvolslide>0?ifxGVSUp:ifxGVSDown):0;
 }
 
-int getsync(struct itplayer *this, int ch, int *time)
+int __attribute__ ((visibility ("internal"))) getsync(struct itplayer *this, int ch, int *time)
 {
 	readque(this);
 	if ((ch<0)||(ch>=this->nchan))
@@ -1894,25 +1899,20 @@ int getsync(struct itplayer *this, int ch, int *time)
 		return this->channels[ch].realsync;
 	}
 }
-
-int gettime(void) /* should be static on order not to confuse other libs? */
-{
-	return mcpGet(-1, mcpGTimer);
-}
-
-int getticktime(struct itplayer *this)
+/*
+int __attribute__ ((visibility ("internal"))) getticktime(struct itplayer *this)
 {
       	readque(this);
 	return 65536*5/(2*this->realtempo);
 }
 
-int getrowtime(struct itplayer *this)
+int __attribute__ ((visibility ("internal"))) getrowtime(struct itplayer *this)
 {
 	readque(this);
 	return 65536*5*this->realspeed/(2*this->realtempo);
-}
-
-void setevpos(struct itplayer *this, int ch, int pos, int modtype, int mod)
+}*/
+/*
+void __attribute__ ((visibility ("internal"))) setevpos(struct itplayer *this, int ch, int pos, int modtype, int mod)
 {
 	struct it_logchan *c;
 	if ((ch<0)||(ch>=this->nchan))
@@ -1925,8 +1925,9 @@ void setevpos(struct itplayer *this, int ch, int pos, int modtype, int mod)
 	c->evpos=-1;
 	c->evtime=-1;
 }
-
-int getevpos(struct itplayer *this, int ch, int *time)
+*/
+/*
+int __attribute__ ((visibility ("internal"))) getevpos(struct itplayer *this, int ch, int *time)
 {
 	readque(this);
 	if ((ch<0)||(ch>=this->nchan))
@@ -1937,8 +1938,9 @@ int getevpos(struct itplayer *this, int ch, int *time)
 	*time=gettime()-this->channels[ch].evtime;
 	return this->channels[ch].evpos;
 }
-
-extern int findevpos(struct itplayer *this, int pos, int *time)
+*/
+/*
+int __attribute__ ((visibility ("internal"))) findevpos(struct itplayer *this, int pos, int *time)
 {
 	int i;
       	readque(this);
@@ -1948,18 +1950,19 @@ extern int findevpos(struct itplayer *this, int pos, int *time)
 	*time=gettime()-this->channels[i].evtime;
 	return this->channels[i].evpos;
 }
+*/
 
-void setloop(struct itplayer *this, int s)
+void __attribute__ ((visibility ("internal"))) setloop(struct itplayer *this, int s)
 {
       	this->noloop=!s;
 }
 
-int getloop(struct itplayer *this)
+int __attribute__ ((visibility ("internal"))) getloop(struct itplayer *this)
 {
 	return this->looped;
 }
 
-int chanactive(struct itplayer *this, int ch, int *lc)
+int __attribute__ ((visibility ("internal"))) chanactive(struct itplayer *this, int ch, int *lc)
 {
 	struct it_physchan *p=&this->pchannels[ch];
 	*lc=p->lch;
@@ -1968,7 +1971,7 @@ int chanactive(struct itplayer *this, int ch, int *lc)
 	return mcpGet(ch, mcpCStatus);
 }
 
-int lchanactive(struct itplayer *this, int lc)
+int __attribute__ ((visibility ("internal"))) lchanactive(struct itplayer *this, int lc)
 {
 	struct it_physchan *p=this->channels[lc].pch;
 	if (!p)
@@ -1978,13 +1981,13 @@ int lchanactive(struct itplayer *this, int lc)
 	return mcpGet(p->no, mcpCStatus);
 }
 
-int getchanins(struct itplayer *this, int ch)
+int __attribute__ ((visibility ("internal"))) getchanins(struct itplayer *this, int ch)
 {
 	struct it_physchan *p=&this->pchannels[ch];
 	return p->inst->handle+1;
 }
 
-int getchansamp(struct itplayer *this, int ch)
+int __attribute__ ((visibility ("internal"))) getchansamp(struct itplayer *this, int ch)
 {
 	struct it_physchan *p=&this->pchannels[ch];
 	if (!p->smp)
@@ -1993,7 +1996,7 @@ int getchansamp(struct itplayer *this, int ch)
 }
 
 
-void getchaninfo(struct itplayer *this, uint8_t ch, struct it_chaninfo *ci)
+void __attribute__ ((visibility ("internal"))) getchaninfo(struct itplayer *this, uint8_t ch, struct it_chaninfo *ci)
 {
 	const struct it_logchan *t=&this->channels[ch];
 	if (t->pch)
@@ -2017,7 +2020,7 @@ void getchaninfo(struct itplayer *this, uint8_t ch, struct it_chaninfo *ci)
 		memset(ci, 0, sizeof(*ci));
 }
 
-int getchanalloc(struct itplayer *this, uint8_t ch)
+int __attribute__ ((visibility ("internal"))) getchanalloc(struct itplayer *this, uint8_t ch)
 {
 	int num=0;
 	int i;
