@@ -106,13 +106,13 @@ struct it_module
 	int geffect;
 };
 
-extern int it_load(struct it_module *, FILE *); /* done */
-extern void it_free(struct it_module *); /* done */
-extern void it_optimizepatlens(struct it_module *); /* done */
-extern int it_precalctime(struct it_module *, int startpos, int (*calctimer)[2], int calcn, int ite); /* done */
+extern int __attribute__ ((visibility ("internal"))) it_load(struct it_module *, FILE *); /* done */
+extern void __attribute__ ((visibility ("internal"))) it_free(struct it_module *); /* done */
+extern void __attribute__ ((visibility ("internal"))) it_optimizepatlens(struct it_module *); /* done */
+extern int __attribute__ ((visibility ("internal"))) it_precalctime(struct it_module *, int startpos, int (*calctimer)[2], int calcn, int ite); /* done */
 
-extern int decompress8 (FILE *, void *dst, int len, char it215); /* done */
-extern int decompress16(FILE *, void *dst, int len, char it215); /* done */
+extern int __attribute__ ((visibility ("internal"))) decompress8 (FILE *, void *dst, int len, char it215); /* done */
+extern int __attribute__ ((visibility ("internal"))) decompress16(FILE *, void *dst, int len, char it215); /* done */
 
 enum
 {
@@ -356,33 +356,32 @@ struct itplayer
 	} que_types;
 };
 
-extern int loadsamples(struct it_module *m);/* - done */
-extern int play(struct itplayer *this, const struct it_module *m, int ch); /* - done */
-extern void stop(struct itplayer *this); /* - done */
+extern int __attribute__ ((visibility ("internal"))) loadsamples(struct it_module *m);/* - done */
+extern int __attribute__ ((visibility ("internal"))) play(struct itplayer *this, const struct it_module *m, int ch); /* - done */
+extern void __attribute__ ((visibility ("internal"))) stop(struct itplayer *this); /* - done */
 
-extern int getsync(struct itplayer *this, int ch, int *time); /* - done */
-extern int gettime(void); /* - done */
-extern int getpos(struct itplayer *this); /* - done */
-extern int getrealpos(struct itplayer *this); /* - done */
-extern int getticktime(struct itplayer *this); /* - done */
-extern int getrowtime(struct itplayer *this); /* - done */
-extern void setevpos(struct itplayer *this, int ch, int pos, int modtype, int mod); /* - done */
-extern int getevpos(struct itplayer *this, int ch, int *time); /* - done */
-extern int findevpos(struct itplayer *this, int pos, int *time); /* - done */
-extern void setpos(struct itplayer *this, int ord, int row); /* - done */
-extern void mutechan(struct itplayer *this, int c, int m); /* - done */
-extern void getglobinfo(struct itplayer *this, int *speed, int *bpm, int *gvol, int *gs); /* - done */
-extern int getchansample(struct itplayer *this, int ch, int16_t *buf, int len, uint32_t rate, int opt); /* - done */
-extern int getdotsdata(struct itplayer *this, int ch, int pch, int *smp, int *note, int *voll, int *volr, int *sus); /* - done */
-extern void itplayer_getrealvol(struct itplayer *this, int ch, int *l, int *r); /* - done */
-extern void setloop(struct itplayer *this, int s); /* - done */
-extern int getloop(struct itplayer *this); /* - done */
-extern int chanactive(struct itplayer *this, int ch, int *lc); /* - done */
-extern int getchanins(struct itplayer *this, int ch); /* - done */
-extern int getchansamp(struct itplayer *this, int ch); /* - done */
-extern int lchanactive(struct itplayer *, int lc); /* - done */
-extern void getchaninfo(struct itplayer *this, uint8_t ch, struct it_chaninfo *ci); /* - done */
-extern int getchanalloc(struct itplayer *this, uint8_t ch); /* - done */
+extern int __attribute__ ((visibility ("internal"))) getsync(struct itplayer *this, int ch, int *time); /* - done */
+extern int __attribute__ ((visibility ("internal"))) getpos(struct itplayer *this); /* - done */
+extern int __attribute__ ((visibility ("internal"))) getrealpos(struct itplayer *this); /* - done */
+/* extern int __attribute__ ((visibility ("internal"))) getticktime(struct itplayer *this); */ /* - done */
+/* extern int __attribute__ ((visibility ("internal"))) getrowtime(struct itplayer *this); */ /* - done */
+/* extern void __attribute__ ((visibility ("internal"))) setevpos(struct itplayer *this, int ch, int pos, int modtype, int mod); */ /* - done */
+/* extern int __attribute__ ((visibility ("internal"))) getevpos(struct itplayer *this, int ch, int *time); */ /* - done */
+/* extern int __attribute__ ((visibility ("internal"))) findevpos(struct itplayer *this, int pos, int *time); */ /* - done */
+extern void __attribute__ ((visibility ("internal"))) setpos(struct itplayer *this, int ord, int row); /* - done */
+extern void __attribute__ ((visibility ("internal"))) mutechan(struct itplayer *this, int c, int m); /* - done */
+extern void __attribute__ ((visibility ("internal"))) getglobinfo(struct itplayer *this, int *speed, int *bpm, int *gvol, int *gs); /* - done */
+extern int __attribute__ ((visibility ("internal"))) getchansample(struct itplayer *this, int ch, int16_t *buf, int len, uint32_t rate, int opt); /* - done */
+extern int __attribute__ ((visibility ("internal"))) getdotsdata(struct itplayer *this, int ch, int pch, int *smp, int *note, int *voll, int *volr, int *sus); /* - done */
+extern void __attribute__ ((visibility ("internal"))) itplayer_getrealvol(struct itplayer *this, int ch, int *l, int *r); /* - done */
+extern void __attribute__ ((visibility ("internal"))) setloop(struct itplayer *this, int s); /* - done */
+extern int __attribute__ ((visibility ("internal"))) getloop(struct itplayer *this); /* - done */
+extern int __attribute__ ((visibility ("internal"))) chanactive(struct itplayer *this, int ch, int *lc); /* - done */
+extern int __attribute__ ((visibility ("internal"))) getchanins(struct itplayer *this, int ch); /* - done */
+extern int __attribute__ ((visibility ("internal"))) getchansamp(struct itplayer *this, int ch); /* - done */
+extern int __attribute__ ((visibility ("internal"))) lchanactive(struct itplayer *, int lc); /* - done */
+extern void __attribute__ ((visibility ("internal"))) getchaninfo(struct itplayer *this, uint8_t ch, struct it_chaninfo *ci); /* - done */
+extern int __attribute__ ((visibility ("internal"))) getchanalloc(struct itplayer *this, uint8_t ch); /* - done */
 
 /*
 #####static void playtickstatic(struct itplayer *); - done
@@ -426,8 +425,9 @@ static int random(struct itplayer *this); - done
 static int processenvelope(const struct it_envelope *env, int *pos, int noteoff, int active); - done
 */
 
-extern void itpInstSetup(const struct it_instrument *ins, int nins, const struct it_sample *smp, int nsmp, const struct it_sampleinfo *smpi,/* int unused,*/ int type, void (*MarkyBoy)(uint8_t *, uint8_t *)); /* private, done */
+extern void __attribute__ ((visibility ("internal"))) itpInstSetup(const struct it_instrument *ins, int nins, const struct it_sample *smp, int nsmp, const struct it_sampleinfo *smpi,/* int unused,*/ int type, void (*MarkyBoy)(uint8_t *, uint8_t *)); /* private, done */
 
-extern void itTrkSetup(const struct it_module *mod); /* private, done */
+extern void __attribute__ ((visibility ("internal"))) itTrkSetup(const struct it_module *mod); /* private, done */
 
+extern __attribute__ ((visibility ("internal"))) struct itplayer itplayer;
 #endif
