@@ -35,7 +35,7 @@
 #define _MAX_FNAME 8
 #define _MAX_EXT 4
 
-/*static*/ struct itplayer itplayer = {0}; /* dirty export - stian */
+__attribute__ ((visibility ("internal"))) struct itplayer itplayer = {0}; /* dirty export - stian */
 static struct it_module mod = {{0}};
 
 static struct it_instrument *insts;
@@ -58,18 +58,18 @@ static int itpProcessKey(uint16_t key)
 /*	int row;*/
 	int pat, p;
 
-	if (mcpSetProcessKey(key))
-		return 1;
-	if (mcpProcessKey)
-	{
-		int ret=mcpProcessKey(key);
-		if (ret==2)
-			cpiResetScreen();
-		if (ret)
-			return 1;
-	}
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp('p', "Start/stop pause with fade");
+			cpiKeyHelp('P', "Start/stop pause with fade");
+			cpiKeyHelp(KEY_CTRL_P, "Start/stop pause");
+			cpiKeyHelp('<', "Jump to previous track");
+			cpiKeyHelp('>', "Jump to next track");
+			mcpSetProcessKey(key);
+			if (mcpProcessKey)
+				mcpProcessKey(key);
+			return 0;
 		case 'p': case 'P': case KEY_CTRL_P:
 			if (plPause)
 				starttime=starttime+dos_clock()-pausetime;
@@ -112,6 +112,17 @@ static int itpProcessKey(uint16_t key)
 			itplayer.setpos(pat, row+8);
 			break;
 			*/
+		default:
+			if (mcpSetProcessKey(key))
+				return 1;
+			if (mcpProcessKey)
+			{
+				int ret=mcpProcessKey(key);
+				if (ret==2)
+					cpiResetScreen();
+				if (ret)
+					return 1;
+			}
 	}
 	return 1;
 }
@@ -487,7 +498,7 @@ static void drawchannel(uint16_t *buf, int len, int i)
 
 /************************************************************************/
 
-int itpGetDots(struct notedotsdata *d, int max)
+static int itpGetDots(struct notedotsdata *d, int max)
 {
 	int i,j;
 	int pos=0;
@@ -513,7 +524,7 @@ int itpGetDots(struct notedotsdata *d, int max)
   return pos;
 }
 
-void itpMute(int i, int m)
+static void itpMute(int i, int m)
 {
 	mutechan(&itplayer, i, m);
 }
