@@ -26,8 +26,6 @@
 #define COLACT 0x04
 #define COLINS 0x07
 
-extern struct itplayer itplayer; /* dirty import - stian */
-
 static uint16_t *plPatLens;
 static uint8_t **plPatterns;
 static const uint16_t *plOrders;
@@ -519,7 +517,7 @@ static struct cpitrakdisplaystruct xmtrakdisplay=
 	xmgetins, xmgetvol, xmgetpan, xmgetfx, xmgetgcmd
 };
 
-void itTrkSetup(const struct it_module *mod)
+void __attribute__ ((visibility ("internal"))) itTrkSetup(const struct it_module *mod)
 {
 	plPatterns=mod->patterns;
 	plOrders=mod->orders;
