@@ -235,7 +235,7 @@ static int freeblock(void)          /* frees that block again */
  *                            returns: status                     )
  */
 
-int decompress8 (FILE *module, void *dst, int len, char it215)
+int __attribute__ ((visibility ("internal"))) decompress8 (FILE *module, void *dst, int len, char it215)
 {
 	sbyte *destbuf;   /* the destination buffer which will be returned */
 
@@ -339,7 +339,7 @@ int decompress8 (FILE *module, void *dst, int len, char it215)
  *                                      compression flag
  *                             returns: status                     )
  */
-int decompress16(FILE *module, void *dst, int len, char it215)
+int __attribute__ ((visibility ("internal"))) decompress16(FILE *module, void *dst, int len, char it215)
 {
 	sword *destbuf;   /* the destination buffer which will be returned */
 
