@@ -44,18 +44,18 @@ static struct mad_stream stream;
 static struct mad_frame frame;
 static struct mad_synth synth;
 static int data_in_synth;
-int mpeg_Bitrate; /* bitrate of the last decoded frame */
+int __attribute__ ((visibility ("internal"))) mpeg_Bitrate; /* bitrate of the last decoded frame */
 static int mpegrate; /* samp-rate in the mpeg */
 static int mpegstereo;
-unsigned char *GuardPtr;
+static unsigned char *GuardPtr;
 /* Are resourses in-use (needs to be freed at Close) ?*/
-int active=0;
+static int active=0;
 
 /* file-buffer */
 #define MPEG_BUFSZ    40000   /* 2.5 s at 128 kbps; 1 s at 320 kbps */
-unsigned char data[MPEG_BUFSZ];
-int data_length;
-int eof;
+static unsigned char data[MPEG_BUFSZ];
+static int data_length;
+static int eof;
 
 /* stats about the file-buffer */
 static FILE *file;
@@ -160,7 +160,7 @@ static void audio_pcm_s16(unsigned char *_data, unsigned int nsamples, mad_fixed
 			ls = audio_linear_round(16, *right++);
 			PANPROC;
 			data[0] = rs;
-			data[1] = (signed short)ls^xormask;
+			data[1] = (int16_t)ls^xormask;
 			data += 2;
 		}
 	else /* mono */
@@ -326,7 +326,7 @@ static void mpegIdler(void)
 	}
 }
 
-void mpegIdle(void)
+void __attribute__ ((visibility ("internal"))) mpegIdle(void)
 {
 	uint32_t bufplayed;
 	uint32_t bufdelta;
@@ -394,7 +394,6 @@ void mpegIdle(void)
 			}
 		} else { /* re-sample intil we don't have more target-buffer or source-buffer */
 			int32_t c0, c1, c2, c3, ls, rs, vm1,v1,v2, wp1, wp2, wpm1;
-/*			if ((bufdelta-=2)<0) bufdelta=0;  by my meening, this should be in place   TODO stian */
 			for (i=0; i<bufdelta; i++)
 			{
 				wpm1=mpegbufpos-4; if (wpm1<0) wpm1+=mpegbuflen;
@@ -717,7 +716,7 @@ void mpegIdle(void)
 	clipbusy--;
 }
 
-unsigned char mpegOpenPlayer(FILE *mpeg, size_t offset, size_t fsize)
+unsigned char __attribute__ ((visibility ("internal"))) mpegOpenPlayer(FILE *mpeg, size_t offset, size_t fsize)
 {
 #define _MPEG_BUFSZ    256000   /* 2.5 s at 128 kbps; 1 s at 320 kbps */
 #if 0
@@ -882,7 +881,7 @@ error_out:
 	return 0;
 }
 
-void mpegClosePlayer(void)
+void __attribute__ ((visibility ("internal"))) mpegClosePlayer(void)
 {
 	if (active)
 	{
@@ -907,29 +906,29 @@ void mpegClosePlayer(void)
 	}
 }
 
-void mpegSetLoop(uint8_t s)
+void __attribute__ ((visibility ("internal"))) mpegSetLoop(uint8_t s)
 {
       	donotloop=!s;
 }
-char mpegIsLooped(void)
+char __attribute__ ((visibility ("internal"))) mpegIsLooped(void)
 {
 	return looped;
 }
-void mpegPause(uint8_t p)
+void __attribute__ ((visibility ("internal"))) mpegPause(uint8_t p)
 {
 	inpause=p;
 }
-void mpegSetAmplify(uint32_t amp)
+void __attribute__ ((visibility ("internal"))) mpegSetAmplify(uint32_t amp)
 {
 	amplify=amp;
 }
-void mpegSetSpeed(uint16_t sp)
+void __attribute__ ((visibility ("internal"))) mpegSetSpeed(uint16_t sp)
 {
       	if (sp<32)
 		sp=32;
 	mpegbufrate=imuldiv(256*sp, mpegrate, plrRate);
 }
-void mpegSetVolume(uint8_t vol_, int8_t bal_, int8_t pan_, uint8_t opt)
+void __attribute__ ((visibility ("internal"))) mpegSetVolume(uint8_t vol_, int8_t bal_, int8_t pan_, uint8_t opt)
 {
 	pan=pan_;
 	volr=voll=vol_*4;
@@ -939,7 +938,7 @@ void mpegSetVolume(uint8_t vol_, int8_t bal_, int8_t pan_, uint8_t opt)
 		voll=(voll*(64-bal_))>>6;
 	srnd=opt;
 }
-void mpegGetInfo(struct mpeginfo *info)
+void __attribute__ ((visibility ("internal"))) mpegGetInfo(struct mpeginfo *info)
 {
 	info->pos=datapos;
 	info->len=fl;
@@ -948,11 +947,11 @@ void mpegGetInfo(struct mpeginfo *info)
 	info->stereo=mpegstereo;
 	info->bit16=1;
 }
-int32_t mpegGetPos(void)
+int32_t __attribute__ ((visibility ("internal"))) mpegGetPos(void)
 {
 	return datapos;
 }
-void mpegSetPos(int32_t pos)
+void __attribute__ ((visibility ("internal"))) mpegSetPos(int32_t pos)
 {
 	if (pos<0)
 		pos=0;
