@@ -16,7 +16,6 @@
 #include <string.h>
 #include <time.h>
 #include "types.h"
-#include "boot/pmain.h"
 #include "filesel/pfilesel.h"
 #include "filesel/mdb.h"
 #include "stuff/poutput.h"
@@ -255,6 +254,32 @@ static int mpegProcessKey(uint16_t key)
 {
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp('p', "Start/stop pause with fade");
+			cpiKeyHelp('P', "Start/stop pause with fade");
+			cpiKeyHelp(KEY_CTRL_P, "Start/stop pause");
+			cpiKeyHelp('<', "Jump back");
+			cpiKeyHelp('>', "Jump forward");
+			cpiKeyHelp('-', "Decrease volume (small)");
+			cpiKeyHelp('+', "Increase volume (small)");
+			cpiKeyHelp('/', "Move balance left (small)");
+			cpiKeyHelp('*', "Move balance right (small)");
+			cpiKeyHelp(',', "Move panning against normal (small)");
+			cpiKeyHelp('.', "Move panning against reverse (small)");
+			cpiKeyHelp(KEY_F2, "Decrease volume");
+			cpiKeyHelp(KEY_F3, "Increase volume");
+			cpiKeyHelp(KEY_F4, "Toggle surround on/off");
+			cpiKeyHelp(KEY_F5, "Move panning against normal");
+			cpiKeyHelp(KEY_F6, "Move panning against reverse");
+			cpiKeyHelp(KEY_F7, "Move balance left");
+			cpiKeyHelp(KEY_F8, "Move balance right");
+			cpiKeyHelp(KEY_F9, "Decrease pitch speed");
+			cpiKeyHelp(KEY_F11, "Decrease pitch speed");
+			cpiKeyHelp(KEY_F10, "Increase pitch speed");
+			cpiKeyHelp(KEY_F12, "Increase pitch speed");
+			if (plrProcessKey)
+				plrProcessKey(key);
+			return 0;
 		case 'p': case 'P':
 			startpausefade();
 			break;
