@@ -115,4 +115,4 @@ static int oggReadInfo(struct moduleinfostruct *m, FILE *f, const char *buf, siz
 	return oggReadMemInfo(m, buf, len);
 }
 
-struct mdbreadnforegstruct oggReadInfoReg = {oggReadMemInfo, oggReadInfo};
+struct mdbreadinforegstruct oggReadInfoReg = {oggReadMemInfo, oggReadInfo};
