@@ -144,7 +144,7 @@ static int GET(int ch, int opt)
 	return 0;
 }
 
-int oplOpenPlayer(const char *filename)
+int __attribute__ ((visibility ("internal"))) oplOpenPlayer(const char *filename)
 {
 	plrSetOptions(44100, (PLR_SIGNEDOUT|PLR_16BIT)|PLR_STEREO);
 
