@@ -61,9 +61,19 @@ static void oplEvent(int event)
 	}
 }
 
-extern "C" {
+static struct mdbreadinforegstruct oplReadInfoReg = {oplReadMemInfo, oplReadInfo, oplEvent};
 
-	struct mdbreadnforegstruct oplReadInfoReg = {oplReadMemInfo, oplReadInfo, oplEvent};
-	char *dllinfo = "readinfos oplReadInfoReg";
+static void __attribute__((constructor))init(void)
+{
+	mdbRegisterReadInfo(&oplReadInfoReg);
+}
+
+static void __attribute__((destructor))done(void)
+{
+	mdbUnregisterReadInfo(&oplReadInfoReg);
+}
+
+extern "C" {
+	char *dllinfo = "";
 	struct linkinfostruct dllextinfo = {"opltype", "OpenCP OPL Detection (c) 2005 Stian Skjelstad", DLLVERSION, 0};
 }
