@@ -24,7 +24,6 @@ extern "C"
 #include "dev/plrasm.h"
 #include "dev/deviplay.h"
 #include "dev/mixclip.h"
-#include "boot/pmain.h"
 #include "cpiface/cpiface.h"
 #include "boot/psetting.h"
 }
@@ -34,11 +33,11 @@ extern "C"
 #include <sidplay/sidtune.h>
 #include "opstruct.h"
 
-emuEngine *myEmuEngine;
-emuConfig *myEmuConfig;
+static emuEngine *myEmuEngine;
+static emuConfig *myEmuConfig;
 
-sidTune *mySidTune;
-sidTuneInfo *mySidTuneInfo;
+static sidTune *mySidTune;
+static sidTuneInfo *mySidTuneInfo;
 
 extern bool sidEmuFastForwardReplay(int percent);
 
@@ -65,8 +64,8 @@ static uint32_t voll,volr;
 static char active;
 static char inpause;
 
-char sidpmute[4];
-int16_t v4outl, v4outr;
+static char sidpmute[4];
+static int16_t v4outl, v4outr;
 
 static volatile int clipbusy=0;
 
@@ -211,12 +210,12 @@ static void updateconf()
 }
 
 
-void sidpIdle()
+void __attribute__ ((visibility ("internal"))) sidpIdle(void)
 {
       	timerproc();
 }
 
-unsigned char sidpOpenPlayer(FILE *f)
+unsigned char __attribute__ ((visibility ("internal"))) sidpOpenPlayer(FILE *f)
 {
       	if (!plrPlay)
 		return 0;
@@ -355,8 +354,7 @@ unsigned char sidpOpenPlayer(FILE *f)
 	return 1;
 }
 
-
-void sidpClosePlayer(void)
+void __attribute__ ((visibility ("internal"))) sidpClosePlayer(void)
 {
       	active=0;
 	
@@ -375,18 +373,18 @@ void sidpClosePlayer(void)
 }
 
 
-void sidpPause(unsigned char p)
+void __attribute__ ((visibility ("internal"))) sidpPause(unsigned char p)
 {
       	inpause=p;
 }
 
-void sidpSetAmplify(unsigned long amp)
+void __attribute__ ((visibility ("internal"))) sidpSetAmplify(unsigned long amp)
 {
       	amplify=amp;
 	calccliptab((amplify*voll)>>8, (amplify*volr)>>8);
 }
 
-void sidpSetVolume(unsigned char vol, signed char bal, signed char pan, unsigned char opt)
+void __attribute__ ((visibility ("internal"))) sidpSetVolume(unsigned char vol, signed char bal, signed char pan, unsigned char opt)
 {
       	pan=pan;
 	voll=vol*4;
@@ -399,12 +397,12 @@ void sidpSetVolume(unsigned char vol, signed char bal, signed char pan, unsigned
 	srnd=opt;
 }
 
-void sidpGetGlobInfo(sidTuneInfo &si)
+void __attribute__ ((visibility ("internal"))) sidpGetGlobInfo(sidTuneInfo &si)
 {
       	mySidTune->getInfo(si);
 }
 
-void sidpStartSong(char sng)
+void __attribute__ ((visibility ("internal"))) sidpStartSong(char sng)
 {
       	if (sng<1)
 		sng=1;
@@ -417,45 +415,45 @@ void sidpStartSong(char sng)
 	clipbusy--;
 }
 
-void sidpToggleVideo()
+void __attribute__ ((visibility ("internal"))) sidpToggleVideo(void)
 {
       	int &cs=myEmuConfig->clockSpeed;
 	cs=(cs==SIDTUNE_CLOCK_PAL)?SIDTUNE_CLOCK_NTSC:SIDTUNE_CLOCK_PAL;
 	updateconf();
 }
 
-char sidpGetVideo()
+char __attribute__ ((visibility ("internal"))) sidpGetVideo(void)
 {
       	int &cs=myEmuConfig->clockSpeed;
 	return (cs==SIDTUNE_CLOCK_PAL);
 }
 
-char sidpGetFilter()
+char __attribute__ ((visibility ("internal"))) sidpGetFilter(void)
 {
       	return myEmuConfig->emulateFilter;
 }
 
 
-void sidpToggleFilter()
+void __attribute__ ((visibility ("internal"))) sidpToggleFilter(void)
 {
       	myEmuConfig->emulateFilter^=1;
 	updateconf();
 }
 
 
-char sidpGetSIDVersion()
+char __attribute__ ((visibility ("internal"))) sidpGetSIDVersion(void)
 {
       	return myEmuConfig->mos8580;
 }
 
 
-void sidpToggleSIDVersion()
+void __attribute__ ((visibility ("internal"))) sidpToggleSIDVersion(void)
 {
       	myEmuConfig->mos8580^=1;
 	updateconf();
 }
 
-void sidpMute(int i, int m)
+void __attribute__ ((visibility ("internal"))) sidpMute(int i, int m)
 {
       	sidpmute[i]=m;
 }
@@ -463,7 +461,7 @@ void sidpMute(int i, int m)
 
 /*extern ubyte filterType;*/
 
-void sidpGetChanInfo(int i, sidChanInfo &ci)
+void __attribute__ ((visibility ("internal"))) sidpGetChanInfo(int i, sidChanInfo &ci)
 {
       	sidOperator ch;
 	switch (i)
@@ -530,7 +528,7 @@ void sidpGetChanInfo(int i, sidChanInfo &ci)
 }
 
 
-void sidpGetDigiInfo(sidDigiInfo &di)
+void __attribute__ ((visibility ("internal"))) sidpGetDigiInfo(sidDigiInfo &di)
 {
       	short vv=abs(v4outl)>>7;
 	if (vv>di.l)
