@@ -97,6 +97,17 @@ static int sidReadInfo(struct moduleinfostruct *m, FILE *fp, const char *mem, si
 	return 0;
 }
 
-struct mdbreadnforegstruct sidReadInfoReg = {sidReadMemInfo, sidReadInfo};
-char *dllinfo = "readinfos sidReadInfoReg";
+static struct mdbreadinforegstruct sidReadInfoReg = {sidReadMemInfo, sidReadInfo};
+
+static void __attribute__((constructor))init(void)
+{
+	mdbRegisterReadInfo(&sidReadInfoReg);
+}
+
+static void __attribute__((destructor))done(void)
+{
+	mdbUnregisterReadInfo(&sidReadInfoReg);
+}
+
+char *dllinfo = "";
 struct linkinfostruct dllextinfo = {"sidtype", "OpenCP SID Detection (c) 2005 Tammo Hinrichs, Stian Skjelstad", DLLVERSION, 0};
