@@ -66,4 +66,4 @@ static int wavReadInfo(struct moduleinfostruct *m, FILE *fp, const char *mem, si
 	return 0;
 }
 
-struct mdbreadnforegstruct wavReadInfoReg = {wavReadMemInfo, wavReadInfo};
+struct mdbreadinforegstruct wavReadInfoReg = {wavReadMemInfo, wavReadInfo};
