@@ -366,42 +366,42 @@ static int loadmod(struct xmodule *m, FILE *file, int chan, int sig, int opt)
 	return errOk;
 }
 
-int xmpLoadMOD(struct xmodule *m, FILE *file)
+int __attribute__ ((visibility ("internal"))) xmpLoadMOD(struct xmodule *m, FILE *file)
 {
 	return loadmod(m, file, 0, 1, 8);
 }
 
-int xmpLoadMODt(struct xmodule *m, FILE *file)
+int __attribute__ ((visibility ("internal"))) xmpLoadMODt(struct xmodule *m, FILE *file)
 {
 	return loadmod(m, file, 0, 1, 2);
 }
 
-int xmpLoadMODd(struct xmodule *m, FILE *file)
+int __attribute__ ((visibility ("internal"))) xmpLoadMODd(struct xmodule *m, FILE *file)
 {
 	return loadmod(m, file, 0, 1, 1);
 }
 
-int xmpLoadM31(struct xmodule *m, FILE *file)
+int __attribute__ ((visibility ("internal"))) xmpLoadM31(struct xmodule *m, FILE *file)
 {
 	return loadmod(m, file, 4, 2, 0);
 }
 
-int xmpLoadM15(struct xmodule *m, FILE *file)
+int __attribute__ ((visibility ("internal"))) xmpLoadM15(struct xmodule *m, FILE *file)
 {
 	return loadmod(m, file, 4, 0, 0);
 }
 
-int xmpLoadM15t(struct xmodule *m, FILE *file)
+int __attribute__ ((visibility ("internal"))) xmpLoadM15t(struct xmodule *m, FILE *file)
 {
 	return loadmod(m, file, 4, 0, 2);
 }
 
-int xmpLoadWOW(struct xmodule *m, FILE *file)
+int __attribute__ ((visibility ("internal"))) xmpLoadWOW(struct xmodule *m, FILE *file)
 {
 	return loadmod(m, file, 8, 1, 0);
 }
 
-int xmpLoadMODf(struct xmodule *m, FILE *file)
+int __attribute__ ((visibility ("internal"))) xmpLoadMODf(struct xmodule *m, FILE *file)
 {
 	return loadmod(m, file, 0, 1, 4);
 }
