@@ -18,7 +18,7 @@
 #include "xmplay.h"
 #include "stuff/err.h"
 
-int xmpLoadMXM(struct xmodule *m, FILE *file)
+int __attribute__ ((visibility ("internal"))) xmpLoadMXM(struct xmodule *m, FILE *file)
 {
 	uint8_t deltasamps, modpanning;
 
