@@ -224,7 +224,7 @@ static void xmpMark()
 	Mark(plInstUsed, plSampUsed);
 }
 
-void xmpInstClear(void)
+void __attribute__ ((visibility ("internal"))) xmpInstClear(void)
 {
 	memset(plInstUsed, 0, instnum);
 	memset(plSampUsed, 0, sampnum);
@@ -238,7 +238,7 @@ static void Done(void)
 	free(plBigSampNum);
 }
 
-void xmpInstSetup(const struct xmpinstrument *ins, int nins, const struct xmpsample *smp, int nsmp, const struct sampleinfo *smpi, int dummy, int type, void (*MarkyBoy)(char *, char *))
+void __attribute__ ((visibility ("internal"))) xmpInstSetup(const struct xmpinstrument *ins, int nins, const struct xmpsample *smp, int nsmp, const struct sampleinfo *smpi, int dummy, int type, void (*MarkyBoy)(char *, char *))
 {
 	int i,j;
 	int biginstlen=0;
