@@ -409,16 +409,23 @@ static void PlayNote(struct channel *ch)
 				ch->chDefPan=ch->cursamp->stdpan;
 			}
 
-			ch->nextsamp=ch->cursamp->handle;
-
-			nn=ch->cursamp->normnote;
-			if (proccmd==xmpCmdSFinetune)
+			if (ch->cursamp)
 			{
-				nn=ch->cursamp->normtrans-(int16_t)(procdat<<4)+0x80;
-				ch->fx=xfxSetFinetune;
-			}
+				ch->nextsamp=ch->cursamp->handle;
 
-			ch->chCurNormNote=nn;
+				nn=ch->cursamp->normnote;
+				if (proccmd==xmpCmdSFinetune)
+				{
+					nn=ch->cursamp->normtrans-(int16_t)(procdat<<4)+0x80;
+					ch->fx=xfxSetFinetune;
+				}
+
+				ch->chCurNormNote=nn;
+			} else {
+				/* if we have no sample yet, just do as much as we can */
+				if (proccmd==xmpCmdSFinetune)
+					ch->fx=xfxSetFinetune;
+			}
 
 			frq=48*256-(((procnot-1)<<8)-ch->chCurNormNote);
 			if (!linearfreq)
@@ -1321,30 +1328,30 @@ static void xmpPlayTick(void)
 	putque(quePos, -1, curtick|(curord<<16)|(currow<<8));
 }
 
-int xmpGetRealPos(void)
+int __attribute__ ((visibility ("internal"))) xmpGetRealPos(void)
 {
        	ReadQue();
 	return realpos;
 }
 
-int xmpChanActive(int ch)
+int __attribute__ ((visibility ("internal"))) xmpChanActive(int ch)
 {
        	return mcpGet(ch, mcpCStatus)&&channels[ch].cursamp&&channels[ch].chVol&&channels[ch].chFadeVol;
 }
 
-int xmpGetChanIns(int ch)
+int __attribute__ ((visibility ("internal"))) xmpGetChanIns(int ch)
 {
 	return channels[ch].chCurIns;
 }
 
-int xmpGetChanSamp(int ch)
+int __attribute__ ((visibility ("internal"))) xmpGetChanSamp(int ch)
 {
        	if (!channels[ch].cursamp)
 		return 0xFFFF;
 	return channels[ch].cursamp-samples;
 }
 
-int xmpGetDotsData(int ch, int *smp, int *frq, int *voll, int *volr, int *sus)
+int __attribute__ ((visibility ("internal"))) xmpGetDotsData(int ch, int *smp, int *frq, int *voll, int *volr, int *sus)
 {
 	struct channel *c;
 
@@ -1363,17 +1370,17 @@ int xmpGetDotsData(int ch, int *smp, int *frq, int *voll, int *volr, int *sus)
 	return 1;
 }
 
-void xmpGetRealVolume(int ch, int *voll, int *volr)
+void __attribute__ ((visibility ("internal"))) xmpGetRealVolume(int ch, int *voll, int *volr)
 {
 	mcpGetRealVolume(ch, voll, volr);
 }
 
-uint16_t xmpGetPos(void)
+uint16_t __attribute__ ((visibility ("internal"))) xmpGetPos(void)
 {
 	return (curord<<8)|currow;
 }
 
-void xmpSetPos(int ord, int row)
+void __attribute__ ((visibility ("internal"))) xmpSetPos(int ord, int row)
 {
 	int i;
 
@@ -1412,32 +1419,32 @@ void xmpSetPos(int ord, int row)
 	realpos=(curord<<16)|(currow<<8);
 }
 
-int xmpGetLChanSample(int ch, int16_t *b, int len, uint32_t rate, int opt)
+int __attribute__ ((visibility ("internal"))) xmpGetLChanSample(int ch, int16_t *b, int len, uint32_t rate, int opt)
 {
        	return mcpGetChanSample(ch, b, len, rate, opt);
 }
 
-void xmpMute(int i, int m)
+void __attribute__ ((visibility ("internal"))) xmpMute(int i, int m)
 {
 	mutech[i]=m;
 }
 
-int xmpLoop(void)
+int __attribute__ ((visibility ("internal"))) xmpLoop(void)
 {
 	return looped;
 }
 
-void xmpSetLoop(int x)
+void __attribute__ ((visibility ("internal"))) xmpSetLoop(int x)
 {
 	looping=x;
 }
 
-int xmpLoadSamples(struct xmodule *m)
+int __attribute__ ((visibility ("internal"))) xmpLoadSamples(struct xmodule *m)
 {
 	return mcpLoadSamples(m->sampleinfos, m->nsampi);
 }
 
-int xmpPlayModule(struct xmodule *m)
+int __attribute__ ((visibility ("internal"))) xmpPlayModule(struct xmodule *m)
 {
 	int i;
 
@@ -1500,25 +1507,26 @@ int xmpPlayModule(struct xmodule *m)
 	return 1;
 }
 
-void xmpStopModule(void)
+void __attribute__ ((visibility ("internal"))) xmpStopModule(void)
 {
 	mcpClosePlayer();
 	free(que);
 }
 
-void xmpGetGlobInfo(int *tmp, int *bpm, int *gvol)
+void __attribute__ ((visibility ("internal"))) xmpGetGlobInfo(int *tmp, int *bpm, int *gvol)
 {
 	*tmp=realspeed;
 	*bpm=realtempo;
 	*gvol=realgvol;
 }
 
-int xmpGetTime(void)
+/*
+int __attribute__ ((visibility ("internal"))) xmpGetTime(void)
 {
 	return mcpGet(-1, mcpGTimer);
-}
+}*/
 
-/*int xmpGetSync(int ch, int *time)
+/*int __attribute__ ((visibility ("internal"))) xmpGetSync(int ch, int *time)
 {
 	ReadQue();
 	if ((ch<0)||(ch>=nchan))
@@ -1531,19 +1539,19 @@ int xmpGetTime(void)
 	}
 }*/
 
-int xmpGetTickTime(void)
+/*int __attribute__ ((visibility ("internal"))) xmpGetTickTime(void)
 {
 	ReadQue();
 	return 65536*5/(2*realtempo);
-}
+}*/
 
-int xmpGetRowTime(void)
+/*int __attribute__ ((visibility ("internal"))) xmpGetRowTime(void)
 {
 	ReadQue();
 	return 65536*5*realspeed/(2*realtempo);
-}
+}*/
 
-void xmpSetEvPos(int ch, int pos, int modtype, int mod)
+/*void __attribute__ ((visibility ("internal"))) xmpSetEvPos(int ch, int pos, int modtype, int mod)
 {
 	struct channel *c;
        	if ((ch<0)||(ch>=nchan))
@@ -1555,9 +1563,9 @@ void xmpSetEvPos(int ch, int pos, int modtype, int mod)
 	c->evmodpos=0;
 	c->evpos=-1;
 	c->evtime=-1;
-}
+}*/
 
-int xmpGetEvPos(int ch, int *time)
+/*int __attribute__ ((visibility ("internal"))) xmpGetEvPos(int ch, int *time)
 {
 	ReadQue();
 	if ((ch<0)||(ch>=nchan))
@@ -1567,9 +1575,9 @@ int xmpGetEvPos(int ch, int *time)
 	}
 	*time=xmpGetTime()-channels[ch].evtime;
 	return channels[ch].evpos;
-}
+}*/
 
-int xmpFindEvPos(int pos, int *time)
+/*int __attribute__ ((visibility ("internal"))) xmpFindEvPos(int pos, int *time)
 {
 	int i;
 	ReadQue();
@@ -1578,9 +1586,9 @@ int xmpFindEvPos(int pos, int *time)
 			break;
 	*time=xmpGetTime()-channels[i].evtime;
 	return channels[i].evpos;
-}
+}*/
 
-void xmpGetChanInfo(unsigned char ch, struct xmpchaninfo *ci)
+void __attribute__ ((visibility ("internal"))) xmpGetChanInfo(unsigned char ch, struct xmpchaninfo *ci)
 {
 	const struct channel *t=&channels[ch];
 	ci->note=t->curnote+11;
@@ -1598,7 +1606,7 @@ void xmpGetChanInfo(unsigned char ch, struct xmpchaninfo *ci)
 	ci->fx=t->fx;
 }
 
-void xmpGetGlobInfo2(struct xmpglobinfo *gi)
+void __attribute__ ((visibility ("internal"))) xmpGetGlobInfo2(struct xmpglobinfo *gi)
 {
 	gi->globvol=globalvol;
 	gi->globvolslide=globalfx;
