@@ -52,10 +52,6 @@ static long pausetime;
 static struct xmpinstrument *insts;
 static struct xmpsample *samps;
 
-void xmTrkSetup(const struct xmodule *mod);
-void xmpInstSetup(const struct xmpinstrument *ins, int nins, const struct xmpsample *smp, int nsmp, const struct sampleinfo *smpi, int nsmpi, int type, void (*MarkyBoy)(char *, char *));
-void xmpInstClear(void);
-
 static uint32_t pausefadestart;
 static uint8_t pausefaderelspeed;
 static int8_t pausefadedirect;
@@ -120,18 +116,18 @@ static int xmpProcessKey(uint16_t key)
 	/* int row; */
 	int pat, p;
 
-	if (mcpSetProcessKey(key))
-		return 1;
-	if (mcpProcessKey)
-	{
-		int ret=mcpProcessKey(key);
-		if (ret==2)
-			cpiResetScreen();
-		if (ret)
-			return 1;
-	}
 	switch (key)
 	{
+		case KEY_ALT_K:
+			cpiKeyHelp('p', "Start/stop pause with fade");
+			cpiKeyHelp('P', "Start/stop pause with fade");
+			cpiKeyHelp(KEY_CTRL_P, "Start/stop pause");
+			cpiKeyHelp('<', "Jump to previous track");
+			cpiKeyHelp('>', "Jump to next track");
+			mcpSetProcessKey(key);
+			if (mcpProcessKey)
+				mcpProcessKey(key);
+			return 0;
 		case 'p': case 'P':
 			startpausefade();
 			break;
@@ -143,6 +139,7 @@ static int xmpProcessKey(uint16_t key)
 			mcpSet(-1, mcpMasterPause, plPause^=1);
 			plChanChanged=1;
 			break;
+#if 0
 		case 0x7700: /* TODO keys ctrl-home */
 			xmpInstClear();
 			xmpSetPos(0, 0);
@@ -151,6 +148,7 @@ static int xmpProcessKey(uint16_t key)
 			else
 				starttime=dos_clock();
 			break;
+#endif
 		case '<':
 		/*		case 0x7300: //ctrl-left  todo keys */
 			p=xmpGetPos();
@@ -176,6 +174,17 @@ static int xmpProcessKey(uint16_t key)
 			row=p&0xFF;
 			xmpSetPos(pat, row+8);
 			break;*/
+		default:
+			if (mcpSetProcessKey(key))
+				return 1;
+			if (mcpProcessKey)
+			{
+				int ret=mcpProcessKey(key);
+				if (ret==2)
+					cpiResetScreen();
+				if (ret)
+					return 1;
+			}
 	}
 	return 1;
 }
