@@ -196,4 +196,4 @@ static int xmpReadInfo(struct moduleinfostruct *m, FILE *fp, const char *mem, si
 	return 0;
 }
 
-struct mdbreadnforegstruct xmpReadInfoReg = {xmpReadMemInfo, xmpReadInfo};
+struct mdbreadinforegstruct xmpReadInfoReg = {xmpReadMemInfo, xmpReadInfo};
