@@ -442,7 +442,7 @@ static struct cpitrakdisplaystruct xmtrakdisplay=
 	xmgetins, xmgetvol, xmgetpan, xmgetfx, xmgetgcmd
 };
 
-void xmTrkSetup(const struct xmodule *mod)
+void __attribute__ ((visibility ("internal"))) xmTrkSetup(const struct xmodule *mod)
 {
 	plPatterns=mod->patterns;
 	plOrders=mod->orders;
