@@ -28,11 +28,9 @@
 #include "poutput-curses.h"
 #include "poutput-fb.h"
 #ifdef HAVE_X11
-#include "poutput-dga.h"
 #include "poutput-x11.h"
 #endif
 #include "poutput-vcsa.h"
-#include "boot/pmain.h"
 
 static void reset_api(void);
 static void (*console_clean)(void)=NULL;
@@ -77,13 +75,72 @@ static int console_init(void)
 	
 	reset_api();
 	
-	fprintf(stderr, "Initing console... ");
+	fprintf(stderr, "Initing console... \n");
 	fflush(stderr);
+	{
+		const char *driver = cfGetProfileString("CommandLine", "d", NULL);
+		if (driver)
+		{
+			if (!strcmp(driver, "curses"))
+			{
+				if (!curses_init())
+				{
+					console_clean=curses_done;
+					return 0;
+				}
+				fprintf(stderr, "curses init failed\n");
+				return -1;
+			} else if (!strcmp(driver, "x11"))
+			{
+#ifdef HAVE_X11
+				if (!x11_init())
+				{
+					console_clean=x11_done;
+					return 0;
+				}
+				fprintf(stderr, "X11 init failed\n");
+#else
+				fprintf(stderr, "X11 support not compiled in\n");
+#endif
+				return -1;
+			} else if (!strcmp(driver, "vcsa"))
+			{
+#ifdef __linux
+				memset(_stdin, 0, sizeof(_stdin));
+				if (readlink("/proc/self/fd/0", _stdin, sizeof(_stdin)-1)<0)
+				if (readlink("/dev/fd/0", _stdin, sizeof(_stdin)-1)<0)
+				{
+					fprintf(stderr, "Failed to read link /proc/self/fd/0\n");
+					return -1;
+				}
+				if (stat(_stdin, &st))
+				{
+					fprintf(stderr, "stat failed on %s\n", _stdin);
+					return -1;
+				}
+				if (((st.st_rdev&0xff00)>>8)!=TTY_MAJOR)
+				{
+					fprintf(stderr, "stdin is not a tty\n");
+					return -1;
+				}
+				if (!vcsa_init(st.st_rdev&0xff))
+				{
+					console_clean=vcsa_done;
+					fb_init(st.st_rdev&0xff);
+					return 0;
+				}
+				fprintf(stderr, "vcsa init failed\n");
+#else
+				fprintf(stderr, "VCSA (and FB) driver not compiled in\n");
+#endif
+				return -1;
+			}
+		}
+	}
 #ifdef __linux
 	memset(_stdin, 0, sizeof(_stdin));
 	memset(_stdout, 0, sizeof(_stdout));
 	
-
 	if (readlink("/proc/self/fd/0", _stdin, sizeof(_stdin)-1)<0)
 	if (readlink("/dev/fd/0", _stdin, sizeof(_stdin)-1)<0)
 	{
@@ -100,14 +157,17 @@ static int console_init(void)
 	{
 #ifdef HAVE_X11
 		fprintf(stderr, "stdout and stdin does not come from the same device, trying just X\n");
-		if (!x11_init(st.st_rdev&0xff))
+		if (!x11_init())
+		{
+			console_clean=x11_done;
 			return 0;
+		}
 #else
 		fprintf(stderr, "stdout and stdin doesn't come from the same device\n");
 #endif
 		return -1;
 	}
-	
+
 	if (stat(_stdin, &st))
 	{
 		fprintf(stderr, "stat failed on %s\n", _stdin);
@@ -206,7 +266,7 @@ static int console_init(void)
 
 #ifdef HAVE_X11
 	if (test_x11)
-		if (!x11_init(st.st_rdev&0xff))
+		if (!x11_init())
 		{
 			console_clean=x11_done;
 			return 0;
@@ -276,13 +336,6 @@ static int __plSetGraphMode(int size)
 #endif
 	return -1;
 }
-static int  __plSetGraphPage(unsigned char x)
-{
-#ifdef CONSOLE_DEBUG
-	fprintf(stderr, "plSetGraphPage not implemented in this console driver\n");
-#endif
-	return -1;
-}
 static void __gdrawchar(unsigned short x, unsigned short y, unsigned char c, unsigned char f, unsigned char b)
 {
 #ifdef CONSOLE_DEBUG
@@ -427,7 +480,6 @@ static void reset_api(void)
 	_displayvoid=__displayvoid;
 
 	_plSetGraphMode=__plSetGraphMode;
-	_plSetGraphPage=__plSetGraphPage;
 	_gdrawchar=__gdrawchar;
 	_gdrawchart=__gdrawchart;
 	_gdrawcharp=__gdrawcharp;
@@ -457,7 +509,5 @@ static void reset_api(void)
 	_vga13=NULL;
 }
 
-struct initcloseregstruct consoleReg={console_init, console_done};
-
-char *dllinfo = "initcloseafter consoleReg";
-struct linkinfostruct dllextinfo = {"poutput", "OpenCP Output Routines (c) 1994-04 Niklas Beisert, Tammo Hinrichs, Stian Skjelstad", DLLVERSION, 0};
+char *dllinfo = "";
+struct linkinfostruct dllextinfo = {"poutput", "OpenCP Output Routines (c) 1994-04 Niklas Beisert, Tammo Hinrichs, Stian Skjelstad", DLLVERSION, 0, Init: console_init, Close: console_done};
