@@ -248,7 +248,7 @@ static void do_resize(void)
 		if ((Width=plScrWidth=size.ws_col)>CONSOLE_MAX_X)
 			Width=plScrWidth=CONSOLE_MAX_X;
 		else if (plScrWidth<80)
-			Width=plScrWidth=80; /* If a console gets smaller than THIS, the user deserves to get fucked up his ASS */
+			Width=plScrWidth=80; /* If a console gets smaller than THIS, the user deserves to get fucked up his or her ASS */
 	}
 	resized=0;
 }
@@ -470,7 +470,7 @@ int curses_init(void)
 	if ((Width=plScrWidth=COLS)>CONSOLE_MAX_X)
 		Width=plScrWidth=CONSOLE_MAX_X;
 	else if (plScrWidth<80)
-		Width=plScrWidth=80; /* If a console gets smaller than THIS, the user deserves to get fucked up his ASS */
+		Width=plScrWidth=80; /* If a console gets smaller than THIS, the user deserves to get fucked up his or her ASS */
 
 	conRestore();
 
