@@ -413,18 +413,22 @@ static void x11_common_event_loop(void)
 				key=0;
 				if ((n_chars==1)/*&&(buf[0]>=32*/&&ks!=XK_Delete)
 				{
-					if ((event.xkey.state&(ControlMask|Mod1Mask))==ControlMask)
+					if ((event.xkey.state&(ShiftMask|ControlMask|Mod1Mask))==ControlMask)
 					{
 						switch (toupper(buf[0]))
 						{
 							case '\r':
-							case '\n': key=KEY_ALT_ENTER; break;
+							/*case '\n':*/ key=KEY_ALT_ENTER; break;
+							case 4:  key=KEY_CTRL_D; break;
 							case 6: set_state(!do_fullscreen); break;
+							case 10: key=KEY_CTRL_J; break;
+							case 12: key=KEY_CTRL_L; break;
 							case 16: key=KEY_CTRL_P; break;
+							case 17: key=KEY_CTRL_Q; break;
 							case 19: key=KEY_CTRL_S; break;
 							case 26: key=KEY_CTRL_Z; break;
 						}
-					} else if ((event.xkey.state&(ControlMask|Mod1Mask))==Mod1Mask)
+					} else if ((event.xkey.state&(ShiftMask|ControlMask|Mod1Mask))==Mod1Mask)
 					{
 						switch (toupper(buf[0]))
 						{
@@ -435,14 +439,20 @@ static void x11_common_event_loop(void)
 							case 'E': key=KEY_ALT_E; break;
 							case 'G': key=KEY_ALT_G; break;
 							case 'I': key=KEY_ALT_I; break;
+							case 'K': key=KEY_ALT_K; break;
 							case 'L': key=KEY_ALT_L; break;
 							case 'P': key=KEY_ALT_P; break;
+							case 'R': key=KEY_ALT_R; break;
 							case 'S': key=KEY_ALT_S; break;
 							case 'X': key=KEY_ALT_X; break;
 							case 'Z': key=KEY_ALT_Z; break;
 						}
-					} else if (!(event.xkey.state&(ControlMask|Mod1Mask)))
-						___push_key(buf[0]);
+					} else {
+						if (!(event.xkey.state&(ControlMask|Mod1Mask)))
+						{
+							___push_key(buf[0]);
+						}
+					}
 				} else if ((event.xkey.state&(ControlMask|Mod1Mask))==ControlMask)
 				{
 					switch (ks)
@@ -452,6 +462,13 @@ static void x11_common_event_loop(void)
 					}
 				} else if ((event.xkey.state&(ControlMask|Mod1Mask))==Mod1Mask)
 				{	
+				} else if ((event.xkey.state&(ShiftMask|ControlMask|Mod1Mask))==ShiftMask)
+				{
+					switch (ks)
+					{
+						case XK_ISO_Left_Tab:
+						case XK_Tab: ___push_key(KEY_SHIFT_TAB); return;
+					}
 				} else switch (ks)
 				{
 					case XK_Escape:    key=KEY_ESC;    break;
@@ -481,6 +498,7 @@ static void x11_common_event_loop(void)
 					case XK_Return:
 					case XK_Linefeed:  key=_KEY_ENTER; break;
 					case XK_BackSpace: key=KEY_BS;     break;
+					case XK_ISO_Left_Tab:
 					case XK_Tab:       key=KEY_TAB;    break;
 				}
 				if (key)
@@ -603,20 +621,6 @@ static void destroy_window(void)
 
 static void RefreshScreenGraph(void);
 
-static int __plSetGraphPage(unsigned char x)
-{
-	int retval;
-
-	if (virtual_framebuffer)
-	{
-		retval=0;
-		plVidMem=virtual_framebuffer + x * 0x10000;
-	} else {
-		retval=0x10000;
-	}
-	return retval;
-}
-
 static int ekbhit(void);
 
 static int __plSetGraphMode(int high)
@@ -647,25 +651,25 @@ static int __plSetGraphMode(int high)
 	if (high==13)
 	{
 		plScrMode=13;
-		plScrWidth=0;
-		plScrHeight=0;
 		plScrLineBytes=320;
 		plScrLines=200;
 		if (!(modeline=modelines[MODE_320x200]))
 			if ((modeline=modelines[MODE_320x240]))
 				plScrLines=240;
+		plScrWidth=plScrLineBytes/8;
+		plScrHeight=plScrLines/16;
 	} else if (high)
 	{
 		plScrMode=101;
 		plScrWidth=128;
-		plScrHeight=60;
+		plScrHeight=48;
 		plScrLineBytes=1024;
 		plScrLines=768;
 		modeline=modelines[MODE_1024x768];
 	} else {
 		plScrMode=100;
 		plScrWidth=80;
-		plScrHeight=60;
+		plScrHeight=30;
 		plScrLineBytes=640;
 		plScrLines=480;
 		modeline=modelines[MODE_640x480];
@@ -760,6 +764,7 @@ static void plSetTextMode(unsigned char x)
 			XF86VidModeSwitchToMode(mDisplay, mScreen, &default_modeline);
 		}
 		XSync(mDisplay, False);
+		plScrMode=255;
 
 		return; /* gdb helper */
 	}
@@ -1485,7 +1490,7 @@ static void setcurshape(uint16_t shape)
 	curshape=shape;
 }
 
-int x11_init(int ignore)
+int x11_init(void)
 {
 	if (!(framebuffer=cfGetProfileBool("x11", "framebuffer", 0, 0)))
 		return -1;
@@ -1500,7 +1505,6 @@ int x11_init(int ignore)
 	ewmh_init();	
 
 	_plSetGraphMode=__plSetGraphMode;
-	_plSetGraphPage=__plSetGraphPage;
 	_gdrawstr=generic_gdrawstr;
 	_gdrawchar8=generic_gdrawchar8;
 	_gdrawchar8p=generic_gdrawchar8p;
